﻿
/***************************************************************************/
/******     THIS PROGRAM COMPUTES FIRM SPECIFIC QUARTERLY WAGE CHANGES *****/
/******     USING DATA FROM ACEMO QUARTERLY SURVEYS ************************/
/***************************************************************************/

DM 'CLEAR LOG; CLEAR OUTPUT;';

libname ACEMO  'C:\aaa';
libname TEMP  'C:\xxx';

options linesize = 100;
options pagesize = 60;

/***************************************************************************/
/******     THIS PROGRAM COMPUTES FIRM SPECIFIC QUARTERLY WAGE CHANGES *****/
/******     USING DATA FROM ACEMO QUARTERLY SURVEYS ************************/
/***************************************************************************/

proc contents data=acemo.ACEMO_1998_2009_fin  ; run;

/***************************************************************************/
/* - CREATION OF THE FIRM-LEVEL WAGE DATABASE   ****************************/
/***************************************************************************/

/* Merge wage data (ACEMO_1999_2009_FIN) by firm (siret) x year (annee) x skill level (cat)   
   with employment structure (eff_transpo) by firm (siret) x year (annee) x skill level (cat) */

data eff_transpo; set acemo.eff_transpo;
rename datea = annee;
run;

proc sort data=eff_transpo; by siret annee cat ; run;
proc sort data=acemo.ACEMO_1998_2009_FIN out = acemo_1999_2009; by siret annee cat; run;

data ACEMO_1999_2009_FIN ; merge ACEMO_1999_2009(in=in1) eff_transpo(in=in2); by siret annee cat ; 
if in1 & in2;
run; 

/* Computation of weighted mean wage variation by firm x quarter ***/
proc sort data = ACEMO_1999_2009_FIN; by siret date; run;

proc means noprint data = ACEMO_1999_2009_FIN
(where=(r_retour='3' and prest1='O' and indicabermens in (0,2) and indicabermens_new = 0)); by siret date; 
var dlnsalmense;
weight prop_cat;
id efftot nafrev2_new nafrev2 nicgr c_apetd n17recomp;
output out = temp.base_acemo_sal_entreprise mean = isalmtot2;
run;

data temp.base_acemo_sal_entreprise; set temp.base_acemo_sal_entreprise;
length SIREN $ 9; SIREN = substr(SIRET,1,9); 
length ETABL $ 5; ETABL = substr(SIRET,10,5);
siren_acemo=siren;
etabl_acemo=etabl; 

run;

/* Some statistics on the initial wage database*/

proc contents data=temp.base_acemo_sal_entreprise; run;

data stat_acemo_init; set temp.base_acemo_sal_entreprise;
dwage = (isalmtot2 >0) - (isalmtot2<0);
annee = int(date);
run;

proc freq data =  stat_acemo_init;
tables dwage ;
run;

proc freq data =  stat_acemo_init;
tables annee*dwage ;
run;

