﻿
/***************************************************************************/
/******     THIS PROGRAM STACKS BDF BUSINESS SURVEYS FROM 1996 TO 2010 *****/
/******     AND REDEFINES IN A HOMOGENEOUS WAY  QUALITATIVE VARIATIONS *****/
/******     OBTAINED FROM DIFFERENT SURVEY WAVES                       *****/
/***************************************************************************/

DM 'CLEAR LOG; CLEAR OUTPUT;';

libname ec 'C:\bbb';
libname temp 'C:\xxx';

options linesize = 100;
options pagesize = 72;

proc contents data=  ec.empiles_1996_2005; run;

/* Elimination of missing values for price variations */
data temp.empiles_1996_2005; set ec.empiles_1996_2005; 
rename siren=siret;
if evprpf ne . ;
/* NB. Until 2005, 0 = missing => these are discarded */
if annee <= 2005 and evprpf = 0 then delete;
run;

proc contents data=ec.emc_industrie; run;

data temp.emc_industrie_1996_2008_NEW ;set ec.emc_industrie;
rename	SIREN	=	SIRET	;
rename	ANNEE	=	ANNEE	;
rename	MOIS	=	MOIS	;
rename	NAF700	=	APE	;
rename	PRTEM1	=	EVPRO	;
rename	LITEM1	=	EVLIV	;
rename	CRTEM1	=	EVCOM	;
rename	CRFEM1	=	EVCOMI	;
rename	CREEM1	=	EVCOME	;
rename	CRUEM1	=	EVCOMUE	;
rename	PVTEM1	=	EVSTPF	;
rename	MPTEM1	=	EVPRMP	;
rename	PPTEM1	=	EVPRPF	;
rename	EFTEM1	=	EVEFF	;
rename	PRTEMA	=	EVPROA1	;
rename	LITEMA	=	EVLIVA1	;
rename	CRTEMA	=	EVCOMA1	;
rename	CRFEMA	=	EVCOMIA1	;
rename	CREEMA	=	EVCOMEA1	;
rename	CRUEMA	=	EVCOMUEA1	;
rename	PVTEMA	=	STPFA1	;
rename	MPTEMA	=	PRMPA1	;
rename	PPTEMA	=	PRPFA1	;
rename	EFTEMA	=	EFFA1	;
rename	PVTSM0	=	STPF	;
rename	MVTSM0	=	STMP	;
rename	CCTSM0	=	ETCC	;
rename	SATSM0	=	CSEMA	;
rename	TUTSM0	=	TUC	;
rename	PRTPM1	=	PREVPRO	;
rename	STTPM1	=	PREVSTPF	;
rename	PPTPM1	=	PREVPRPF	;
rename	EFTPM1	=	PREVEFF	;
rename	EFF	=	EFF	;
drop dates;
run;

proc freq data = temp.emc_industrie_1996_2008_NEW; tables ANNEE * MOIS; run; 

/** There is a specific problem for some years in the updated dataset (emc_industrie_1996_2008_NEW) 
=> we take the new one for recent years only and keep the old one (empiles_1996_2005) for previous years */
proc sort data = temp.emc_industrie_1996_2008_NEW; by siret ape annee mois; run;
proc sort data = temp.empiles_1996_2005; by siret ape annee mois; run;

/*
data verif1; merge temp.emc_industrie_1996_2008_NEW(in=in1) temp.empiles_1996_2005(in=in2); if in1 & in2; run;
data verif2; merge temp.emc_industrie_1996_2008_NEW(in=in1) temp.empiles_1996_2005(in=in2); if in1 ; run;
data verif3; merge temp.emc_industrie_1996_2008_NEW(in=in1) temp.empiles_1996_2005(in=in2); if in2; run;
*/

proc contents data=  ec.emc_2008_2010; run;

data temp.emc_2008_2010_NEW; set ec.emc_2008_2010;

rename	SIREN	=	SIRET	;
rename	ANNEE	=	ANNEE	;
rename	MOIS	=	MOIS	;
rename	NAF700	=	APE	;
rename	PRTEM1	=	EVPRO	;
rename	LITEM1	=	EVLIV	;
rename	CRTEM1	=	EVCOM	;
rename	CRFEM1	=	EVCOMI	;
rename	CREEM1	=	EVCOME	;
rename	CRUEM1	=	EVCOMUE	;
rename	PVTEM1	=	EVSTPF	;
rename	MPTEM1	=	EVPRMP	;
rename	PPTEM1	=	EVPRPF	;
rename	EFTEM1	=	EVEFF	;
rename	PRTEMA	=	EVPROA1	;
rename	LITEMA	=	EVLIVA1	;
rename	CRTEMA	=	EVCOMA1	;
rename	CRFEMA	=	EVCOMIA1	;
rename	CREEMA	=	EVCOMEA1	;
rename	CRUEMA	=	EVCOMUEA1	;
rename	PVTEMA	=	STPFA1	;
rename	MPTEMA	=	PRMPA1	;
rename	PPTEMA	=	PRPFA1	;
rename	EFTEMA	=	EFFA1	;
rename	PVTSM0	=	STPF	;
rename	MVTSM0	=	STMP	;
rename	CCTSM0	=	ETCC	;
rename	SATSM0	=	CSEMA	;
rename	TUTSM0	=	TUC	;
rename	PRTPM1	=	PREVPRO	;
rename	STTPM1	=	PREVSTPF	;
rename	PPTPM1	=	PREVPRPF	;
rename	EFTPM1	=	PREVEFF	;
rename	EFF	=	EFF	;
run;


data temp.empiles_aout_2005; set temp.emc_industrie_1996_2008_NEW (where = (annee = 2005 and mois = 8)); run;
data temp.empiles_2006_2007; set temp.emc_industrie_1996_2008_NEW (where = (2006 <= annee <= 2007)); run;
data temp.empiles_2008_jan_jul; set temp.emc_industrie_1996_2008_NEW (where = (annee = 2008 and mois <= 7)); run;
data temp.empiles_2008_aug_dec; set temp.emc_2008_2010_NEW (where = (annee = 2008 and mois >= 8)); run;
data temp.empiles_2009_2009; set temp.emc_2008_2010_NEW (where = (annee = 2009 or (annee=2010 & mois <=1))); run;

data verif; set temp.empiles_1996_2005(where = (annee = 2005 and mois = 8)); run;
data verif; set temp.empiles_1996_2005(where = (annee = 2005 and mois = 9)); run;

proc contents data = temp.empiles_1996_2005; run;
proc contents data = temp.empiles_2006_2007; run;
proc contents data = temp.empiles_2008_jan_jul;  run;
proc contents data = temp.empiles_2008_aug_dec;  run;
proc contents data = temp.empiles_2009_2009;  run;

proc sort data = temp.empiles_1996_2005; by annee mois; run;
proc sort data = temp.empiles_2006_2007; by annee mois; run;
proc sort data = temp.empiles_2008_jan_jul; by annee mois;  run;
proc sort data = temp.empiles_2008_aug_dec; by annee mois;  run;
proc sort data = temp.empiles_2009_2009; by annee mois;  run;

proc freq data = temp.empiles_1996_2005; tables annee*mois; run;
proc freq data = temp.empiles_aout_2005; tables annee*mois; run;
proc freq data = temp.empiles_2006_2007; tables annee*mois; run;
proc freq data = temp.empiles_2008_jan_jul; tables annee*mois; run;
proc freq data = temp.empiles_2008_aug_dec; tables annee*mois; run;
proc freq data = temp.empiles_2009_2009; tables annee*mois; run;

data temp.emc_1996_2009; set temp.empiles_1996_2005 temp.empiles_aout_2005 
                          temp.empiles_2006_2007 temp.empiles_2008_jan_jul
                          temp.empiles_2008_aug_dec temp.empiles_2009_2009;  
run;

proc freq data = temp.emc_1996_2009; tables annee * mois; run;

proc sort nodupkey data = temp.emc_1996_2009 out=verif; by siret ape annee mois; run;

data temp.emc_1996_2009; set temp.emc_1996_2009; 
length SIREN $ 9; SIREN = substr(SIRET,1,9); 
length ETABL $ 5; ETABL = substr(SIRET,10,5);  
siren_ec = siren;
etabl_ec = etabl;
length_siret = length(siret);

APE_EC=APE;
if APE='A159' then APE_EC='159F'; 
if APE='A193' then APE_EC='193Z'; 
if APE='A201' then APE_EC='201A'; 
if APE='A204' then APE_EC='204Z'; 
if APE='A211' then APE_EC='211C';
if APE='A222' then APE_EC='222C'; 
if APE='A245' then APE_EC='245C'; 
if APE='A251' then APE_EC='251A'; 
if APE='A261' then APE_EC='261E';
if APE='A271' then APE_EC='271Y'; 
if APE='A341' then APE_EC='341Z'; 
if APE='A361' then APE_EC='361A';
if APE='B159' then APE_EC='159F'; 
if APE='B193' then APE_EC='193Z'; 
if APE='B201' then APE_EC='201A'; 
if APE='B204' then APE_EC='204Z'; 
if APE='B211' then APE_EC='211C';
if APE='B222' then APE_EC='222C'; 
if APE='B245' then APE_EC='245C'; 
if APE='B261' then APE_EC='261E';
if APE='B271' then APE_EC='271Y'; 
if APE='B341' then APE_EC='341Z'; 
if APE='B361' then APE_EC='361A';
if APE='C201' then APE_EC='201A'; 
if APE='C211' then APE_EC='211C'; 
if APE='C222' then APE_EC='222C'; 
if APE='C261' then APE_EC='261E';
if APE='C271' then APE_EC='271Y'; 
if APE='C283' then APE_EC='283C'; 
if APE='D222' then APE_EC='222C';
if APE='D271' then APE_EC='271Y'; 
if APE='E222' then APE_EC='222C'; 

run;


/* Elinination of duplicates associated with the redefinition of industry categories */
proc sort nodupkey data = temp.emc_1996_2009 ; by siret ape_ec annee mois; run;

data temp.EC; set temp.emc_1996_2009;
DATE = ANNEE + (0.25 * (INT((MOIS-1)/3))) ;
run;

proc freq data = temp.EC; tables annee * mois; run; 

* recoding of explanatory variables from the econometric model; 

data temp.EC; set temp.EC(keep = SIRET SIREN ETABL  DATE ANNEE MOIS EFF APE APE_EC 
                      EVCOM  EVPRMP EVPRPF EVPRO  EVEFF EVSTPF 
                      EVLIV PREVSTPF 
	                  PREVPRPF PREVPRO PREVEFF 
	                  PRPFA1 EVPROA1 PRMPA1 EFFA1 LENGTH_SIRET );

array VARQUAL(15)     EVCOM  EVPRMP EVPRPF EVPRO  EVEFF EVSTPF  
                      EVLIV PREVSTPF 
	                  PREVPRPF PREVPRO PREVEFF 
	                  PRPFA1 EVPROA1 PRMPA1 EFFA1;

array NEW_VARQUAL(15) NEW_EVCOM  NEW_EVPRMP NEW_EVPRPF NEW_EVPRO  NEW_EVEFF NEW_EVSTPF   
                      NEW_EVLIV NEW_PREVSTPF 
	                  NEW_PREVPRPF NEW_PREVPRO NEW_PREVEFF 
	                  NEW_PRPFA1 NEW_EVPROA1 NEW_PRMPA1 NEW_EFFA1;

array CHGT_VARQUAL(15) CHGT_EVCOM  CHGT_EVPRMP CHGT_EVPRPF CHGT_EVPRO  CHGT_EVEFF CHGT_EVSTPF  
                      CHGT_EVLIV CHGT_PREVSTPF 
	                  CHGT_PREVPRPF CHGT_PREVPRO CHGT_PREVEFF 
	                  CHGT_PRPFA1 CHGT_EVPROA1 CHGT_PRMPA1 CHGT_EFFA1;

array HAUSSE_VARQUAL(15) HAUSSE_EVCOM  HAUSSE_EVPRMP HAUSSE_EVPRPF HAUSSE_EVPRO  HAUSSE_EVEFF HAUSSE_EVSTPF 
                      HAUSSE_EVLIV HAUSSE_PREVSTPF  
	                  HAUSSE_PREVPRPF HAUSSE_PREVPRO HAUSSE_PREVEFF 
	                  HAUSSE_PRPFA1 HAUSSE_EVPROA1 HAUSSE_PRMPA1 HAUSSE_EFFA1;

array BAISSE_VARQUAL(15) BAISSE_EVCOM  BAISSE_EVPRMP BAISSE_EVPRPF BAISSE_EVPRO  BAISSE_EVEFF BAISSE_EVSTPF 
                      BAISSE_EVLIV BAISSE_PREVSTPF 
	                  BAISSE_PREVPRPF BAISSE_PREVPRO BAISSE_PREVEFF 
	                  BAISSE_PRPFA1 BAISSE_EVPROA1 BAISSE_PRMPA1 BAISSE_EFFA1;

do I = 1 to 15; 

	if      VARQUAL(I) in (5, -200.0) then NEW_VARQUAL(I) = -3;   
	else if VARQUAL(I) in (4, -100.0) then NEW_VARQUAL(I) = -2;   
	else if VARQUAL(I) in (3.5,  -50.0) then NEW_VARQUAL(I) = -1;
	else if VARQUAL(I) in (3, 0.0) then NEW_VARQUAL(I) = +0;   
	else if VARQUAL(I) in (2.5, 50.0) then NEW_VARQUAL(I) = 1;   
 	else if VARQUAL(I) in (2, 100.0) then NEW_VARQUAL(I) = 2;   
	else if VARQUAL(I) in (1, 200.0) then NEW_VARQUAL(I) = 3;   
	
	if NEW_VARQUAL(I) = +0                   then CHGT_VARQUAL(I) = 0;
	if NEW_VARQUAL(I) in (-3,-2,-1,+1,+2,+3) then CHGT_VARQUAL(I) = 1;

    HAUSSE_VARQUAL(I) = (NEW_VARQUAL(I) in (+1,+2,+3)) ;
    BAISSE_VARQUAL(I) = (NEW_VARQUAL(I) in (-1,-2,-3)) ;

end;

run;


data temp.EC; set temp.EC;
drop  EVCOM  EVPRMP EVPRPF EVPRO  EVEFF EVSTPF EVLIV PREVSTPF 
	                  PREVPRPF PREVPRO PREVEFF 
	                  PRPFA1 EVPROA1 PRMPA1 EFFA1;
run;

data temp.EC; set temp.EC;
rename  NEW_EVCOM = EVCOM;
rename  NEW_EVPRMP = EVPRMP; 
rename  NEW_EVPRPF = EVPRPF ;
rename  NEW_EVPRO = EVPRO;  
rename  NEW_EVLIV = EVLIV;
rename  NEW_EVEFF = EVEFF;
rename  NEW_EVSTPF = EVSTPF;
rename  NEW_PREVPRPF = PREVPRPF;
rename  NEW_PREVPRO = PREVPRO;
rename  NEW_PREVSTPF = PREVSTPF;
rename  NEW_PREVEFF = PREVEFF;
rename  NEW_PRPFA1 = PRPFA1;
rename  NEW_EVPROA1 = EVPROA1;
rename  NEW_PRMPA1 = PRMPA1;
rename  NEW_EFFA1 = EFFA1;
run;

proc means data = temp.EC; run;

proc sort data = temp.EC; by SIREN ETABL APE_EC DATE; run;

proc contents data=temp.ec; run;

