/*********************************************************************************************************/
/******  THIS PROGRAM :                                                                      *************/
/******  - CREATES A MONTHLY DATASET OF WAGE CHANGES FROM THE INITAL QUARTERLY ACEMO DATA    *************/
/******  - MERGES THE RESULTING WAGE CHANGE DATA WITH BUSINESS SURVEYS (EC)                  *************/
/******                                           AND PRODUCTION PRICE INDICES (IPP) *********************/
/*********************************************************************************************************/

DM 'CLEAR LOG; CLEAR OUTPUT;';

libname IPP 'C:\ccc';
libname temp 'C:\xxx';

options linesize = 132;
options pagesize = 72;


/*********************************************/
/*    CREATION OF A MONTHLY ACEMO DATASET    */ 
/*********************************************/

proc contents data=temp.base_acemo_sal_entreprise; run;

data TEMP.ACEMO2; set temp.base_acemo_sal_entreprise(rename=(C_APETD=APE)); 
length annee 8. mois 8. ;
annee = int(date);
if date-annee = 0 then mois=1;
else if date-annee = 0.25 then mois=4;
else if date-annee = 0.50 then mois=7;
else if date-annee = 0.75 then mois=10;

* CREATION OF SEPARATE IDENTIFIERS FOR FIRMS (SIREN) and PLANTS (ETABL); 
length siren $9. etabl $5. ;
	SIREN  = substr(SIRET,1,9); 
    ETABL  = substr(SIRET,10,5);  
    ETABL2 = NICGR; 
	ETABL  = compress(ETABL);  
    ETABL2 = compress(ETABL2);  
	if length(ETABL2) ne 5 then ETABL2 = ""; 
    if length(ETABL) ne 5 then ETABL = ""; 
	if ETABL2 ne "" & ETABL = "" then ETABL = ETABL2; 
run; 

* CREATION OF MONTHLY OBSERVATIONS FROM THE QUARTERLY SURVEY; 
data TEMP.ACEMO2; set TEMP.ACEMO2; 
	ANNEE = int(DATE); 
	if DATE-ANNEE=0.00 then do;
		do I=1 to 3; MOIS=I; output; end; 
		end;  
	if DATE-ANNEE=0.25 then do;
		do I=4 to 6; MOIS=I; output; end; 
		end;  
	if DATE-ANNEE=0.50 then do;
		do I=7 to 9; MOIS=I; output; end; 
		end;  
	if DATE-ANNEE=0.75 then do;
		do I=10 to 12; MOIS=I; output; end; 
		end;  
run;
 
data TEMP.ACEMO2; set TEMP.ACEMO2; 
if mois in (2,3,5,6,8,9,11,12) then isalmtot2 = 0;
run; 

/*********************/
/* FILES MERGING ... */ 
/*********************/

DATA TEMP.EC_a; set TEMP.EC(where=(ETABL NE "")) ; run;
DATA TEMP.EC_b; set TEMP.EC(where=(ETABL EQ "")) ; run;

* SIREN ETABL IS AN IDENTIFIER FOR FIRMS IN EC WHERE ETABL NE . / ETABL ALWAYS PRESENT IN ACEMO ; 
proc sort data = TEMP.EC_a; by SIREN ETABL ANNEE MOIS APE_EC; run;
proc sort data = TEMP.ACEMO2; by SIREN ETABL ANNEE MOIS; run; 
data ACEMO_EC_a; merge 
	 TEMP.ACEMO2(in=DSACEMO) 
	 TEMP.EC_a(in=DSEC ); 
by SIREN ETABL ANNEE MOIS; if DSEC /*and DSACEMO*/;
run; 

* FOR FIRMS IN EC WITH NO INFO ABOUT ETABL, SIREN IS THE IDENTIFIER;
* WE FIRST COMPUTE AVERAGE VARIATIONS OF WAGES OVER ESTABLISHMENTS IN ACEMO;

* computation of average level of employment over the period of presence;
proc sort data=temp.ACEMO2; by SIREN ; run;

proc means noprint data=temp.ACEMO2; by SIREN ; 
var efftot;
output out = effectif_moyen mean=effmoy;
run;

data temp.ACEMO2; merge temp.ACEMO2 effectif_moyen; by siren ; run;
 
proc sort data=temp.ACEMO2; by SIREN ANNEE MOIS; run;


proc means noprint data=temp.ACEMO2; by SIREN ANNEE MOIS;
weight effmoy;
var isalmtot2;
output out = temp.acemo3  mean = isalmtot2; 
id nafrev2_new;
run;


* SIREN IS AN IDENTIFIER FOR FIRMS WITH NO INFO ABOUT ESTABLISHMENT; 
proc sort data = TEMP.EC_b; by SIREN ANNEE MOIS APE_EC; run;
proc sort data = TEMP.ACEMO3; by SIREN ANNEE MOIS ; run;

data acemo_ec_b; merge 
	 TEMP.ACEMO3(in=DSACEMO ) 
	 TEMP.EC_b (in=DSEC ); 
	by SIREN ANNEE MOIS; if DSEC /*and DSACEMO*/; 	
run; 


/** STACKING OF THE TWO DATABASES */
data TEMP.ACEMO_EC; set ACEMO_EC_a ACEMO_EC_b ; run; 

proc sort nodupkey data = TEMP.ACEMO_EC out = verif; by siren etabl ape_ec annee mois ;  run;


***
*** IMPORT OF PRODUCTION PRICES INDICES, OBTAINED FROM INSEE (cpf from 08 to 24)
***;
/*
PROC IMPORT OUT= temp.IPP_c08_24 
            DATAFILE= "C:\IPP_CPF_REV2_NEW_08_24.xls" 
            DBMS=EXCEL REPLACE;
     SHEET="'series MEF$'"; 
     GETNAMES=YES;
     MIXED=NO;
     SCANTEXT=YES;
     USEDATE=YES;
     SCANTIME=YES;
RUN;
*/
data temp.IPP_c08_24; set IPP.IPP_c08_24;
	if ANNEE = 1995 & MOIS = 1 then delete;
run;

proc transpose data = temp.IPP_c08_24 out = temp.IPP_c02_24_transp; by annee mois;
run;

data temp.IPP_c02_24_transp(drop = _NAME_ _LABEL_); set temp.IPP_c02_24_transp;
	rename COL1 = IPP;

	length CPF_rev2 $6;
	CPF_rev2 = substr(_LABEL_, 5, 6);
	CPF_rev2 = TRANWRD(CPF_rev2, '#', '.'); 
	CPF_rev2 = compress(CPF_rev2);
run;

proc freq data = temp.IPP_c02_24_transp(where = (IPP ne .)); tables ANNEE*MOIS; run;

***
*** IMPORT OF PRODUCTION PRICES INDICES, OBTAINED FROM INSEE (cpf from 25 to 32)
***;
/*
PROC IMPORT OUT= temp.IPP_c25_32 
            DATAFILE= "C:\IPP_CPF_REV2_NEW_25_32.xls" 
            DBMS=EXCEL REPLACE;
     SHEET="'series MEF$'"; 
     GETNAMES=YES;
     MIXED=NO;
     SCANTEXT=YES;
     USEDATE=YES;
     SCANTIME=YES;
RUN;
*/

data temp.IPP_c25_32; set IPP.IPP_c25_32;
	if ANNEE = 1996 & MOIS = 1 then delete;
run;

proc transpose data = temp.IPP_c25_32 out = temp.IPP_c25_32_transp; by annee mois; run;

data temp.IPP_c25_32_transp(drop = _NAME_ _LABEL_); set temp.IPP_c25_32_transp;
	rename COL1 = IPP;

	length CPF_rev2 $6;
	CPF_rev2 = substr(_LABEL_, 5, 6);
	CPF_rev2 = TRANWRD(CPF_rev2, '#', '.'); 
	CPF_rev2 = compress(CPF_rev2);
run;

proc freq data = temp.IPP_c25_32_transp(where = (IPP ne .)); tables ANNEE*MOIS; run;

data temp.IPP_transp; set 	temp.IPP_c02_24_transp(where = (IPP ne .))
							temp.IPP_c25_32_transp(where = (IPP ne .));
run;
proc freq data = temp.IPP_transp; tables ANNEE*MOIS; run;

***
*** IMPORT OF THE CORRESPONDENCE TABLES FOR INDUSTRY CLASSIFICATIONS NAF rev2 <-> CPF rev2
***;
/*
PROC IMPORT OUT= temp.nafv2_cpfv2 
            DATAFILE= "C:\table_passage_NAFv2_CPFv2.xls" 
            DBMS=EXCEL REPLACE;
     SHEET="Feuil3$"; 
     GETNAMES=YES;
     MIXED=NO;
     SCANTEXT=YES;
     USEDATE=YES;
     SCANTIME=YES;
RUN;
*/

proc transpose data = ipp.nafv2_cpfv2 out = temp.nafv2_cpfv2_transp;
	by NAF_rev_2;
	VAR F2-F35;
run;

data temp.nafv2_cpfv2_transp(where = (CPFv2 ne "")); set temp.nafv2_cpfv2_transp(drop = _NAME_ _LABEL_);
	rename COL1 = CPFv2;
run;

data temp.nafv2_cpfv2_transp; set temp.nafv2_cpfv2_transp;
	length nafrev2_NEW $ 5. ; 
    NAF_rev_2 = compress(NAF_rev_2);
	nafrev2_NEW = compress(TRANWRD(NAF_rev_2, '.', '')); 
	CPFv2 = compress(CPFv2);
	CPF_rev2 = substr(CPFv2, 1, 5);
run;

proc sort data = temp.nafv2_cpfv2_transp; by cpf_rev2; run;

data temp.nafv2_cpfv2_final; set temp.nafv2_cpfv2_transp; by cpf_rev2;
	if first.cpf_rev2;
run;

***
*** MERGING OF PRODUCER PRICE INDICES (IPP) WITH INDUSTRY CLASSIFICATION CORRESPONDENCE TABLE rev2 <-> CPF rev 2
***;
proc sort data = temp.nafv2_cpfv2_final; by cpf_rev2; run;
proc sort data = temp.IPP_transp; by cpf_rev2 annee mois; run;
data temp.ipp_naf_rev2; merge temp.nafv2_cpfv2_final temp.IPP_transp(in = in1); by cpf_rev2;
	if in1;
run;

proc sort data = temp.ipp_naf_rev2; by cpf_rev2; run;
data temp.ipp_naf_rev2; set temp.ipp_naf_rev2; 
	l1_IPP = lag(IPP);
 	l1_cpf_rev2 = lag(cpf_rev2);

	if cpf_rev2= l1_cpf_rev2 then TXIPP2 = log(IPP / l1_IPP);
run;

/* Computation of fractiles for industry-level inflation (to be used later for shocks definition) */
data temp.ipp_naf_rev2; set temp.ipp_naf_rev2;
nace2digits = substr(nafrev2_NEW,1,2);
run;

proc sort data=temp.ipp_naf_rev2; by nace2digits; run;
proc means noprint data=temp.ipp_naf_rev2; by nace2digits; 
var txipp2 ;
output out = fractiles_ipp median = med_txipp2 q3 = q3_txipp2 p90 = p90_txipp2; 
run;

data temp.ipp_naf_rev2; merge temp.ipp_naf_rev2 fractiles_ipp; by nace2digits; run;


***
*** MERGING OF PRODUCTION PRICES WITH MERGED DATASETS FROM ACEMO SURVEYS AND BDF BUSINESS SURVEYS
***;
data temp.EC_NAFREV2_NEW; set temp.ACEMO_EC; run;

proc sort data = temp.ipp_naf_rev2 nodupkeys; by NAFREV2_NEW ANNEE mois; run;

proc sort data = temp.EC_NAFREV2_NEW; by NAFREV2_NEW ANNEE mois ; run;
proc sort data = temp.ipp_naf_rev2; by nafrev2_NEW ANNEE mois ; run;
data temp.ACEMO_EC_ipp;
	merge temp.EC_NAFREV2_NEW(in=in_EC) temp.ipp_naf_rev2(keep = ANNEE mois IPP txipp2 nafrev2_NEW med_txipp2 q3_txipp2 p90_txipp2);
	by nafrev2_NEW ANNEE mois;
	if in_EC;
run;

* COMPUTING SOME STATISTICS  ;
proc sort data = temp.ACEMO_EC_ipp; by SIREN ETABL APE_EC DATE; run;  

proc contents data = temp.ACEMO_ec_IPP; run;

proc freq data = temp.ACEMO_ec_IPP; tables annee ; run;

proc means data = temp.ACEMO_EC_ipp;
run;  

* SAVING DATA ;
data TEMP.ACEMO_EC_IPP; set temp.ACEMO_EC_IPP(keep = SIREN ETABL ANNEE MOIS EFF APE APE_EC EVCOM EVPRMP EVPRPF PREVPRPF 
PREVPRO EVPRO EVSTPF txipp2 EVLIV PREVSTPF med_txipp2 q3_txipp2 p90_txipp2 isalmtot2 nafrev2_new); 
run;


