﻿/*** THIS PROGRAM AIMS AT:
- REDEFINING ALL VARIATIONS INTO THREE OUTCOMES: DECREASE, NO CHANGE, INCREASE;
- IDENTIFYING PRICE TRAJECTORIES AND PRICE SPELLS;
- COMPUTING CUMULATIVE SUMS AND LAGGED VALUES OF INPUT PRICE CHANGES, PRODUCTION CHANGES,ETC. OVER PRICE SPELLS;
- COMPUTING LAGGED VALUES OF VARIABLES USED AS INSTRUMENTS IN THE ESTIMATION PROCEDURE;
- DEFININING OBSERVED INCREASES AND DECREASES AS PERMANENT OR TRANSITORY; 

The input from Laurent Baudry, Thomas Heckel and Sylvie Tarrieu is gratefully aknowledged. 
****/ 

DM 'CLEAR LOG; CLEAR OUTPUT;';

libname temp 'xxx';

options linesize = 100;
options pagesize = 72;


proc sort data=TEMP.ACEMO_EC_IPP; by siren etabl ape_EC annee mois; run;

/***************************************************************************/
/* REDEFINITION OF VARIATIONS INTO EITHER DECREASE, NO CHANGE OR INCREASE  */
/***************************************************************************/

data TEMP.ACEMO_EC_NEW; set TEMP.ACEMO_EC_IPP;
if EVPRPF ne . ; 
ident =siren||etabl||ape_EC;

array VARQUAL5(10) EVCOM_5 EVPRMP_5 EVPRPF_5 PREVPRO_5 EVPRO_5 EVSTPF_5 EVLIV_5 PREVSTPF_5 TXIPP2_5 ISALMTOT2_5;
array VARQUAL(10) EVCOM EVPRMP EVPRPF PREVPRO EVPRO EVSTPF EVLIV PREVSTPF TXIPP2 ISALMTOT2;
	do I = 1 to 10; 
        varqual5(i) = varqual(i); 
		if VARQUAL(I) NE . THEN DO;
		if      VARQUAL(I)  > 0 then VARQUAL(I) = +1;   
		else if VARQUAL(I) = 0.0 then VARQUAL(I) = +0;   
		else if VARQUAL(I) < 0 then VARQUAL(I) = -1;   
		end;
        END; 
	 run; 

proc sort data=TEMP.ACEMO_EC_NEW; by ident annee mois; run;


/*******************************************/
/*  IDENTIFICATION OF PRICE TRAJECTORIES   */
/*******************************************/

* ANY GROUP OF STRICTLY SUCCESSIVE OBSERVATIONS FOR A GIVEN FIRM/PLANT/INDUSTRY(PRODUCT) IS A PRICE TRAJECTORY;

data TEMP.ACEMO_EC2; set TEMP.ACEMO_EC_NEW; by SIREN ETABL APE_EC ANNEE MOIS; 
	LANNEE = lag(ANNEE); LMOIS = lag(MOIS);
	if first.APE_EC then do; 
		DEB_ANNEE = ANNEE; DEB_MOIS = MOIS; 
		FIN_ANNEE = ANNEE; FIN_MOIS = MOIS; 
		end; 
	if not(first.APE_EC) 
	   and ((ANNEE=LANNEE and MOIS=LMOIS+1) or 
		    (ANNEE=LANNEE+1 and MOIS=1 and LMOIS=12) or 
			(ANNEE=LANNEE   and MOIS=9 and LMOIS=6 and ANNEE< 1998) or 
			(ANNEE=LANNEE   and MOIS=9 and LMOIS=7 and 1998 <= ANNEE < 2005)) then do; 
		FIN_ANNEE = ANNEE; FIN_MOIS = MOIS; 
		end; 
	if not(first.APE_EC) 
	   and not((ANNEE=LANNEE and MOIS=LMOIS+1) or 
		       (ANNEE=LANNEE+1 and MOIS=1 and LMOIS=12) or 
			   (ANNEE=LANNEE   and MOIS=9 and LMOIS=6 and ANNEE< 1998) or 
			   (ANNEE=LANNEE   and MOIS=9 and LMOIS=7 and 1998 <= ANNEE < 2005)) then do; 
		DEB_ANNEE = ANNEE; DEB_MOIS = MOIS; 
		FIN_ANNEE = ANNEE; FIN_MOIS = MOIS; 
		end; 
	retain DEB_ANNEE DEB_MOIS;
	run; 

data TEMP.DEB_FIN; set TEMP.ACEMO_EC2(keep = SIREN ETABL APE_EC DEB_ANNEE DEB_MOIS FIN_ANNEE FIN_MOIS); by SIREN ETABL APE_EC DEB_ANNEE DEB_MOIS; 
	if last.DEB_MOIS; 
	run;

data TEMP.DEB_FIN2; set TEMP.DEB_FIN(where=((FIN_ANNEE-DEB_ANNEE)*12+FIN_MOIS-DEB_MOIS+1>=12)); 
	ANNEE = DEB_ANNEE; MOIS = DEB_MOIS; 
	do while (ANNEE<FIN_ANNEE or (ANNEE=FIN_ANNEE and MOIS<=FIN_MOIS)); 
		output; 
		if MOIS=6 and ANNEE<1998 then MOIS=9; 
		else if MOIS=7 and 1998 <= ANNEE < 2005 then MOIS=9; 
		else if MOIS=12 then do; MOIS=1; ANNEE=ANNEE+1; end; 
		else MOIS=MOIS+1; 
		end; 
	run;

data TEMP.ACEMO_EC3; merge TEMP.ACEMO_EC_NEW TEMP.DEB_FIN2(in=AGARDER); 
	by SIREN ETABL APE_EC ANNEE MOIS; if AGARDER; 
	run;  

proc sort data=TEMP.ACEMO_EC3; by  SIREN ETABL APE_EC annee mois; run;

data TEMP.ACEMO_EC3; set TEMP.ACEMO_EC3; 
duree_traj=(fin_annee-deb_annee)*12+ Fin_mois-deb_mois+1;
duree_t = (annee-deb_annee)*12+mois-deb_mois+1;
debut_traj=deb_annee||deb_mois;
fin_traj=fin_annee|fin_mois;
ident_traj=SIREN||ETABL||APE_EC||debut_traj;
run;

data TEMP.nb_traj; set TEMP.ACEMO_EC3; by ident_traj;
if first.ident_traj;
run;

Proc sort data= TEMP.ACEMO_EC3; by ident_traj;run;

data TEMP.first_obs(keep=duree_traj ident_traj y_null); set TEMP.ACEMO_EC3; by ident_traj;
if first.ident_traj;
y_null=evprpf;
run;

data TEMP.ACEMO_EC3BIS ; merge TEMP.first_obs TEMP.ACEMO_EC3; by ident_traj;
run;


/*******************************************/
/*  IDENTIFICATION OF PRICE SPELLS         */
/*******************************************/

proc sort data = TEMP.ACEMO_EC3BIS; 
	by SIREN ETABL APE_EC DEB_ANNEE DEB_MOIS FIN_ANNEE FIN_MOIS ANNEE MOIS; 
	run;  


data TEMP.ACEMO_EC4; set TEMP.ACEMO_EC3BIS; 
	by SIREN ETABL APE_EC DEB_ANNEE DEB_MOIS FIN_ANNEE FIN_MOIS ANNEE MOIS; 
	LEVPRPF = lag(evprpf);
 
	if first.DEB_MOIS then do; 
		DEB2_ANNEE = ANNEE; DEB2_MOIS = MOIS; 
		FIN2_ANNEE = ANNEE; FIN2_MOIS = MOIS; 
		end; 
	if not(first.DEB_MOIS) and LEVPRPF = 0 then do; 
		FIN2_ANNEE = ANNEE; FIN2_MOIS = MOIS; 
		end; 
	if not(first.DEB_MOIS) and LEVPRPF ne 0 then do; 
		DEB2_ANNEE = ANNEE; DEB2_MOIS = MOIS; 
		FIN2_ANNEE = ANNEE; FIN2_MOIS = MOIS; 
		end; 
	retain DEB2_ANNEE DEB2_MOIS; 
	run;

data TEMP.DEB2_FIN2; set TEMP.ACEMO_EC4(keep = SIREN ETABL APE_EC DEB_ANNEE DEB_MOIS FIN_ANNEE FIN_MOIS DEB2_ANNEE DEB2_MOIS FIN2_ANNEE FIN2_MOIS); 
	by SIREN ETABL APE_EC DEB_ANNEE DEB_MOIS DEB2_ANNEE DEB2_MOIS; 
	if last.DEB2_MOIS; 
	run;

data TEMP.DEB2_FIN2_2; set TEMP.DEB2_FIN2; 
	ANNEE = DEB2_ANNEE; MOIS = DEB2_MOIS; 
	do while (ANNEE<FIN2_ANNEE or (ANNEE=FIN2_ANNEE and MOIS<=FIN2_MOIS)); 
		output; 
		if MOIS=6  and ANNEE<1998  then MOIS=9; 
		else if MOIS=7  and 1998 <= ANNEE < 2005 then MOIS=9; 
		else if MOIS=12 then do; MOIS=1; ANNEE=ANNEE+1; end; 
		else MOIS=MOIS+1; 
		end; 
	run;



data TEMP.ACEMO_EC5; merge TEMP.ACEMO_EC3BIS TEMP.DEB2_FIN2_2; 
	by SIREN ETABL APE_EC DEB_ANNEE DEB_MOIS FIN_ANNEE FIN_MOIS ANNEE MOIS;
	DUREE = (ANNEE-DEB2_ANNEE)*12+MOIS-DEB2_MOIS+1;
	run;  

data temp.acemo_ec5; set temp.acemo_ec5;
duree_spell=(fin2_annee-deb2_annee)*12+ Fin2_mois-deb2_mois+1;
debut_spell=deb2_annee||deb2_mois;
fin_spell=fin2_annee|fin2_mois;
ident_spell=SIREN||ETABL||APE_EC||debut_spell;
run;


/******************************************************************/
/*  COMPUTATION OF CUMULATIVE SUMS OF CHANGES OVER PRICE SPELLS   */
/******************************************************************/

proc sort data = TEMP.ACEMO_EC5; by SIREN ETABL APE_EC DEB_ANNEE DEB_MOIS FIN_ANNEE FIN_MOIS DEB2_ANNEE DEB2_MOIS FIN2_ANNEE FIN2_MOIS ANNEE MOIS; run;  

data TEMP.ACEMO_EC7; set TEMP.ACEMO_EC5; 
	by SIREN ETABL APE_EC DEB_ANNEE DEB_MOIS FIN_ANNEE FIN_MOIS DEB2_ANNEE DEB2_MOIS FIN2_ANNEE FIN2_MOIS ANNEE MOIS; 

    if first.DEB2_MOIS then do; 
		CUM_ISALMTOT = ISALMTOT2; 
		CUM_EVPRMP = EVPRMP; 
		CUM_EVCOM = EVCOM; 
		CUM_IPP2 = TXIPP2;
		CUM_EVPRO = EVPRO; 
		CUM_EVSTPF = EVSTPF; 
		CUM_EVLIV = EVLIV; 
  		end; 
   if not(first.DEB2_MOIS) then do; 
		CUM_ISALMTOT = CUM_ISALMTOT+ISALMTOT2; 
		CUM_EVPRMP = CUM_EVPRMP+EVPRMP;
		CUM_EVCOM = CUM_EVCOM+EVCOM;
		CUM_IPP2 = CUM_IPP2+TXIPP2; 
		CUM_EVPRO = CUM_EVPRO+EVPRO; 
 		CUM_EVSTPF = CUM_EVSTPF+EVSTPF; 
		CUM_EVLIV = CUM_EVLIV+EVLIV; 
		end; 
	retain CUM_ISALMTOT CUM_EVPRMP CUM_EVCOM CUM_IPP2 CUM_EVPRO CUM_EVSTPF CUM_EVLIV ;  
	
run;


/*********************************************************************************************************/
/*  COMPUTATION OF LEAD VALUES, LAGGED VALUES AND PARTIAL CUMULATIVE SUMS OF CHANGES OVER PRICE SPELLS   */
/*********************************************************************************************************/

proc sort data = TEMP.ACEMO_EC7; 
by SIREN ETABL APE_EC DEB_ANNEE DEB_MOIS FIN_ANNEE FIN_MOIS DEB2_ANNEE DEB2_MOIS FIN2_ANNEE FIN2_MOIS ANNEE MOIS; run;  
data TEMP.LX; set TEMP.ACEMO_EC7
(keep=	SIREN ETABL APE_EC DEB_ANNEE DEB_MOIS FIN_ANNEE FIN_MOIS DEB2_ANNEE DEB2_MOIS FIN2_ANNEE FIN2_MOIS ANNEE MOIS
		ISALMTOT2 EVPRMP EVCOM TXIPP2 EVPRO EVSTPF EVLIV );
	run;  
		
data TEMP.L1; set TEMP.LX; 
		if MOIS=6 and ANNEE<1998 then MOIS=9; 
		else if MOIS=7 and 1998 <= ANNEE < 2005 then MOIS=9; 
		else if MOIS=12 then do; MOIS=1; ANNEE=ANNEE+1; end; 
		else MOIS=MOIS+1; 
	run;  
data TEMP.L2; set TEMP.L1; 
		if MOIS=6 and ANNEE<1998 then MOIS=9; 
		else if MOIS=7 and 1998 <= ANNEE < 2005 then MOIS=9; 
		else if MOIS=12 then do; MOIS=1; ANNEE=ANNEE+1; end; 
		else MOIS=MOIS+1; 
	run;  
data TEMP.L3; set TEMP.L2; 
		if MOIS=6 and ANNEE<1998 then MOIS=9; 
		else if MOIS=7 and 1998 <= ANNEE < 2005 then MOIS=9; 
		else if MOIS=12 then do; MOIS=1; ANNEE=ANNEE+1; end; 
		else MOIS=MOIS+1; 
	run;  
data TEMP.L4; set TEMP.L3; 
		if MOIS=6 and ANNEE<1998 then MOIS=9; 
		else if MOIS=7 and 1998 <= ANNEE < 2005 then MOIS=9; 
		else if MOIS=12 then do; MOIS=1; ANNEE=ANNEE+1; end; 
		else MOIS=MOIS+1; 
	run;  
data TEMP.L5; set TEMP.L4; 
		if MOIS=6 and ANNEE<1998 then MOIS=9; 
		else if MOIS=7 and 1998 <= ANNEE < 2005 then MOIS=9; 
		else if MOIS=12 then do; MOIS=1; ANNEE=ANNEE+1; end; 
		else MOIS=MOIS+1; 
	run;  
data TEMP.L6; set TEMP.L5; 
		if MOIS=6 and ANNEE<1998 then MOIS=9; 
		else if MOIS=7 and 1998 <= ANNEE < 2005 then MOIS=9; 
		else if MOIS=12 then do; MOIS=1; ANNEE=ANNEE+1; end; 
		else MOIS=MOIS+1; 
	run;  

data TEMP.ACEMO_EC8; merge TEMP.ACEMO_EC7(in=DS_ACEMO_EC) 
TEMP.L1(rename=(ISALMTOT2=ISALMTOT2_L1 EVPRMP=EVPRMP_L1 EVCOM=EVCOM_L1 TXIPP2=TXIPP2_L1 EVPRO=EVPRO_L1 EVSTPF=EVSTPF_L1 EVLIV=EVLIV_L1  ))
TEMP.L2(rename=(ISALMTOT2=ISALMTOT2_L2 EVPRMP=EVPRMP_L2 EVCOM=EVCOM_L2 TXIPP2=TXIPP2_L2 EVPRO=EVPRO_L2 EVSTPF=EVSTPF_L2 EVLIV=EVLIV_L2  ))
TEMP.L3(rename=(ISALMTOT2=ISALMTOT2_L3 EVPRMP=EVPRMP_L3 EVCOM=EVCOM_L3 TXIPP2=TXIPP2_L3 EVPRO=EVPRO_L3 EVSTPF=EVSTPF_L3 EVLIV=EVLIV_L3  ))
TEMP.L4(rename=(ISALMTOT2=ISALMTOT2_L4 EVPRMP=EVPRMP_L4 EVCOM=EVCOM_L4 TXIPP2=TXIPP2_L4 EVPRO=EVPRO_L4 EVSTPF=EVSTPF_L4 EVLIV=EVLIV_L4  ))
TEMP.L5(rename=(ISALMTOT2=ISALMTOT2_L5 EVPRMP=EVPRMP_L5 EVCOM=EVCOM_L5 TXIPP2=TXIPP2_L5 EVPRO=EVPRO_L5 EVSTPF=EVSTPF_L5 EVLIV=EVLIV_L5  ))
TEMP.L6(rename=(ISALMTOT2=ISALMTOT2_L6 EVPRMP=EVPRMP_L6 EVCOM=EVCOM_L6 TXIPP2=TXIPP2_L6 EVPRO=EVPRO_L6 EVSTPF=EVSTPF_L6 EVLIV=EVLIV_L6  )); 
by SIREN ETABL APE_EC DEB_ANNEE DEB_MOIS FIN_ANNEE FIN_MOIS DEB2_ANNEE DEB2_MOIS FIN2_ANNEE FIN2_MOIS ANNEE MOIS; 
if DS_ACEMO_EC; 
run;  

data TEMP.FX; set TEMP.LX
(keep= SIREN ETABL APE_EC DEB_ANNEE DEB_MOIS FIN_ANNEE FIN_MOIS ANNEE MOIS ISALMTOT2 EVPRMP EVCOM TXIPP2 EVPRO EVSTPF EVLIV);
run;  

data TEMP.F1; set TEMP.FX; 
		if MOIS=9 and ANNEE<1998 then MOIS=6; 
		else if MOIS=9 and 1998 <= ANNEE < 2005 then MOIS=7; 
		else if MOIS=1 then do; MOIS=12; ANNEE=ANNEE-1; end; 
		else MOIS=MOIS-1; 
	run;  

data TEMP.ACEMO_EC9; merge TEMP.ACEMO_EC8(in=DS_ACEMO_EC) 
TEMP.F1(rename=(ISALMTOT2=ISALMTOT2_F1 EVPRMP=EVPRMP_F1 EVCOM=EVCOM_F1 TXIPP2=TXIPP2_F1 EVPRO=EVPRO_F1 EVSTPF=EVSTPF_F1 EVLIV=EVLIV_F1)); 
by SIREN ETABL APE_EC DEB_ANNEE DEB_MOIS FIN_ANNEE FIN_MOIS ANNEE MOIS; 
if DS_ACEMO_EC; 
run;  

data TEMP.ACEMO_EC10; set TEMP.ACEMO_EC9; 
	array VAR1(6) ISALMTOT2_L1-ISALMTOT2_L6; 	do I=1 to 6; if VAR1(I)=. then VAR1(I)=0; end; 
	array VAR5(6) EVPRMP_L1-EVPRMP_L6; 			do I=1 to 6; if VAR5(I)=. then VAR5(I)=0; end; 
	array VAR6(6) EVCOM_L1-EVCOM_L6;			do I=1 to 6; if VAR6(I)=. then VAR6(I)=0; end; 
	array VAR7(6) TXIPP2_L1-TXIPP2_L6; 			do I=1 to 6; if VAR7(I)=. then VAR7(I)=0; end; 
    array VAR9(6) EVPRO_L1-EVPRO_L6; 			do I=1 to 6; if VAR9(I)=. then VAR9(I)=0; end; 
    array VAR10(6) EVSTPF_L1-EVSTPF_L6; 		do I=1 to 6; if VAR10(I)=. then VAR10(I)=0; end; 
    array VAR11(6) EVLIV_L1-EVLIV_L6; 			do I=1 to 6; if VAR11(I)=. then VAR11(I)=0; end; 

    CUM_ISALMTOT_L1 = CUM_ISALMTOT-ISALMTOT2-ISALMTOT2_L1; 
    CUM_EVPRMP_L1 = CUM_EVPRMP-EVPRMP-EVPRMP_L1; 
	CUM_EVPRO_L1 = CUM_EVPRO-EVPRO-EVPRO_L1; 
	CUM_EVCOM_L1 = CUM_EVCOM-EVCOM-EVCOM_L1; 
	CUM_IPP2_L1 = CUM_IPP2-TXIPP2-TXIPP2_L1; 
	CUM_EVLIV_L1 = CUM_EVLIV-EVLIV-EVLIV_L1; 
	CUM_EVSTPF_L1 = CUM_EVSTPF-EVSTPF-EVSTPF_L1; 

    CUM_ISALMTOT_L0 = CUM_ISALMTOT-ISALMTOT2; 
    CUM_EVPRMP_L0 = CUM_EVPRMP-EVPRMP; 
	CUM_EVPRO_L0 = CUM_EVPRO-EVPRO; 
	CUM_EVCOM_L0 = CUM_EVCOM-EVCOM; 
	CUM_IPP2_L0 = CUM_IPP2-TXIPP2; 
	CUM_EVLIV_L0 = CUM_EVLIV; 
	CUM_EVSTPF_L0 = CUM_EVSTPF-EVSTPF; 
	run;

/******************************************************************/
/*  COMPUTATION OF LAGGED VALUES TO BE USED AS INSTRUMENTS        */
/******************************************************************/

proc sort data = TEMP.ACEMO_EC10; by SIREN ETABL APE_EC ANNEE MOIS; run; 

data TEMP.ACEMO_EC10; set TEMP.ACEMO_EC10;
numenq=0;
if annee= 1996 & mois = 1 then numenq=1;
if annee= 1996 & mois = 2 then numenq=2;
if annee= 1996 & mois = 3 then numenq=3;
if annee= 1996 & mois = 4 then numenq=4;
if annee= 1996 & mois = 5 then numenq=5;
if annee= 1996 & mois = 6 then numenq=6;
if annee= 1996 & mois = 9 then numenq=7;
if annee= 1996 & mois = 10 then numenq=8;
if annee= 1996 & mois = 11 then numenq=9;
if annee= 1996 & mois = 12 then numenq=10;


if annee= 1997 & mois = 1 then numenq=11;
if annee= 1997 & mois = 2 then numenq=12;
if annee= 1997 & mois = 3 then numenq=13;
if annee= 1997 & mois = 4 then numenq=14;
if annee= 1997 & mois = 5 then numenq=15;
if annee= 1997 & mois = 6 then numenq=16;
if annee= 1997 & mois = 9 then numenq=17;
if annee= 1997 & mois = 10 then numenq=18;
if annee= 1997 & mois = 11 then numenq=19;
if annee= 1997 & mois = 12 then numenq=20;

if annee= 1998 & mois = 1 then numenq=21;
if annee= 1998 & mois = 2 then numenq=22;
if annee= 1998 & mois = 3 then numenq=23;
if annee= 1998 & mois = 4 then numenq=24;
if annee= 1998 & mois = 5 then numenq=25;
if annee= 1998 & mois = 6 then numenq=26;
if annee= 1998 & mois = 7 then numenq=27;
if annee= 1998 & mois = 9 then numenq=28;
if annee= 1998 & mois = 10 then numenq=29;
if annee= 1998 & mois = 11 then numenq=30;
if annee= 1998 & mois = 12 then numenq=31;

if annee= 1999 & mois = 1 then numenq=32;
if annee= 1999 & mois = 2 then numenq=33;
if annee= 1999 & mois = 3 then numenq=34;
if annee= 1999 & mois = 4 then numenq=35;
if annee= 1999 & mois = 5 then numenq=36;
if annee= 1999 & mois = 6 then numenq=37;
if annee= 1999 & mois = 7 then numenq=38;
if annee= 1999 & mois = 9 then numenq=39;
if annee= 1999 & mois = 10 then numenq=40;
if annee= 1999 & mois = 11 then numenq=41;
if annee= 1999 & mois = 12 then numenq=42;

if annee= 2000 & mois = 1 then numenq=43;
if annee= 2000 & mois = 2 then numenq=44;
if annee= 2000 & mois = 3 then numenq=45;
if annee= 2000 & mois = 4 then numenq=46;
if annee= 2000 & mois = 5 then numenq=47;
if annee= 2000 & mois = 6 then numenq=48;
if annee= 2000 & mois = 7 then numenq=49;
if annee= 2000 & mois = 9 then numenq=50;
if annee= 2000 & mois = 10 then numenq=51;
if annee= 2000 & mois = 11 then numenq=52;
if annee= 2000 & mois = 12 then numenq=53;

if annee= 2001 & mois = 1 then numenq=54;
if annee= 2001 & mois = 2 then numenq=55;
if annee= 2001 & mois = 3 then numenq=56;
if annee= 2001 & mois = 4 then numenq=57;
if annee= 2001 & mois = 5 then numenq=58;
if annee= 2001 & mois = 6 then numenq=59;
if annee= 2001 & mois = 7 then numenq=60;
if annee= 2001 & mois = 9 then numenq=61;
if annee= 2001 & mois = 10 then numenq=62;
if annee= 2001 & mois = 11 then numenq=63;
if annee= 2001 & mois = 12 then numenq=64;

if annee= 2002 & mois = 1 then numenq=65;
if annee= 2002 & mois = 2 then numenq=66;
if annee= 2002 & mois = 3 then numenq=67;
if annee= 2002 & mois = 4 then numenq=68;
if annee= 2002 & mois = 5 then numenq=69;
if annee= 2002 & mois = 6 then numenq=70;
if annee= 2002 & mois = 7 then numenq=71;
if annee= 2002 & mois = 9 then numenq=72;
if annee= 2002 & mois = 10 then numenq=73;
if annee= 2002 & mois = 11 then numenq=74;
if annee= 2002 & mois = 12 then numenq=75;

if annee= 2003 & mois = 1 then numenq=76;
if annee= 2003 & mois = 2 then numenq=77;
if annee= 2003 & mois = 3 then numenq=78;
if annee= 2003 & mois = 4 then numenq=79;
if annee= 2003 & mois = 5 then numenq=80;
if annee= 2003 & mois = 6 then numenq=81;
if annee= 2003 & mois = 7 then numenq=82;
if annee= 2003 & mois = 9 then numenq=83;
if annee= 2003 & mois = 10 then numenq=84;
if annee= 2003 & mois = 11 then numenq=85;
if annee= 2003 & mois = 12 then numenq=86;

if annee= 2004 & mois = 1 then numenq=87;
if annee= 2004 & mois = 2 then numenq=88;
if annee= 2004 & mois = 3 then numenq=89;
if annee= 2004 & mois = 4 then numenq=90;
if annee= 2004 & mois = 5 then numenq=91;
if annee= 2004 & mois = 6 then numenq=92;
if annee= 2004 & mois = 7 then numenq=93;
if annee= 2004 & mois = 9 then numenq=94;
if annee= 2004 & mois = 10 then numenq=95;
if annee= 2004 & mois = 11 then numenq=96;
if annee= 2004 & mois = 12 then numenq=97;

if annee= 2005 & mois = 1 then numenq=98;
if annee= 2005 & mois = 2 then numenq=99;
if annee= 2005 & mois = 3 then numenq=100;
if annee= 2005 & mois = 4 then numenq=101;
if annee= 2005 & mois = 5 then numenq=102;
if annee= 2005 & mois = 6 then numenq=103;
if annee= 2005 & mois = 7 then numenq=104;
if annee= 2005 & mois = 8 then numenq=105;
if annee= 2005 & mois = 9 then numenq=106;
if annee= 2005 & mois = 10 then numenq=107;
if annee= 2005 & mois = 11 then numenq=108;
if annee= 2005 & mois = 12 then numenq=109;

if annee >= 2006 then numenq=109+(annee-2006)*12+mois;
run;

data TEMP.ACEMO_EC10; set TEMP.ACEMO_EC10;
l1_ident =lag( ident );  l1_numenq=lag(numenq);
l2_ident =lag2( ident ); l2_numenq=lag2(numenq);
l3_ident =lag3( ident ); l3_numenq=lag3(numenq);
l4_ident =lag4( ident ); l4_numenq=lag4(numenq);
l5_ident =lag5( ident ); l5_numenq=lag5(numenq);
l6_ident =lag6( ident ); l6_numenq=lag6(numenq);
l7_ident =lag7( ident ); l7_numenq=lag7(numenq);
l8_ident =lag8( ident ); l8_numenq=lag8(numenq);
run;

proc sort data = TEMP.ACEMO_EC10; by SIREN ETABL APE_EC descending ANNEE descending MOIS; run; 

data TEMP.ACEMO_EC10; set TEMP.ACEMO_EC10;
f1_ident =lag( ident );
f1_numenq=lag(numenq);
run;

proc sort data = TEMP.ACEMO_EC10; by SIREN ETABL APE_EC ANNEE MOIS; run; 

data TEMP.ACEMO_EC10; set TEMP.ACEMO_EC10;
lead1_ok = 0;
lag1_ok = 0;
lag2_ok = 0;
lag3_ok = 0;
lag4_ok = 0;
lag5_ok = 0;
lag6_ok = 0;

IF ( ident =f1_ident  & numenq=f1_numenq-1) then lead1_ok=1;
IF ( ident =l1_ident  & numenq=l1_numenq+1) then lag1_ok=1;
IF ( ident =l2_ident  & numenq=l2_numenq+2) then lag2_ok=1;
IF ( ident =l3_ident  & numenq=l3_numenq+3) then lag3_ok=1;
IF ( ident =l4_ident  & numenq=l4_numenq+4) then lag4_ok=1;
IF ( ident =l5_ident  & numenq=l5_numenq+5) then lag5_ok=1;
IF ( ident =l6_ident  & numenq=l6_numenq+6) then lag6_ok=1;
run;

data TEMP.ACEMO_EC10; set TEMP.ACEMO_EC10;
L1_EVPRPF=lag(evprpf);
L1_evcom=lag(evcom);
L1_evliv=lag(evliv);
L1_evpro=lag(evpro);
L1_evprmp=lag(evprmp);
L1_ISALMTOT2=lag(isalmtot2);
L1_EVSTPF = lag(evstpf);
L1_txipp2=lag(txipp2);

L2_EVPRPF=lag2(evprpf);
L2_evcom=lag2(evcom);
L2_evliv=lag2(evliv);
L2_evpro=lag2(evpro);
L2_evprmp=lag2(evprmp);
L2_ISALMTOT2=lag2(isalmtot2);
L2_EVSTPF = lag2(evstpf);
L2_txipp2=lag2(txipp2);

L3_EVPRPF=lag3(evprpf);
L3_evcom=lag3(evcom);
L3_evliv=lag3(evliv);
L3_evpro=lag3(evpro);
L3_evprmp=lag3(evprmp);
L3_ISALMTOT2=lag3(isalmtot2);
L3_EVSTPF = lag3(evstpf);
L3_txipp2=lag3(txipp2);

L4_EVPRPF=lag4(evprpf);
L4_evcom=lag4(evcom);
L4_evliv=lag4(evliv);
L4_evpro=lag4(evpro);
L4_evprmp=lag4(evprmp);
L4_ISALMTOT2=lag4(isalmtot2);
L4_EVSTPF = lag4(evstpf);
L4_txipp2=lag4(txipp2);

L5_EVPRPF=lag5(evprpf);
L5_evcom=lag5(evcom);
L5_evliv=lag5(evliv);
L5_evpro=lag5(evpro);
L5_evprmp=lag5(evprmp);
L5_ISALMTOT2=lag5(isalmtot2);
L5_EVSTPF = lag5(evstpf);
L5_txipp2=lag5(txipp2);

L6_EVPRPF=lag6(evprpf);
L6_evcom=lag6(evcom);
L6_evliv=lag6(evliv);
L6_evpro=lag6(evpro);
L6_evprmp=lag6(evprmp);
L6_ISALMTOT2=lag6(isalmtot2);
L6_EVSTPF = lag6(evstpf);
L6_txipp2=lag6(txipp2);

run;

data temp.acemo_EC10; set temp.acemo_EC10;
left_censor = (debut_traj = debut_spell );
nace2digits = substr(nafrev2_NEW,1,2);
run;

/*************************************************************************************************/
/*  ELIMINATION OF ALL OBSERVATIONS CORRESPONDING TO LEFT-CENSORED SPELLS, OF SHORT TRAJECTORIES,*/ 
/*  OR FOR WHICH LEADS OR LAGS ARE MISSING OR NOT PROPERLY DEFINED                               */
/*************************************************************************************************/

data temp.complet ; set temp.acemo_EC10;
if lead1_ok = 1  & lag1_ok=1 & lag2_ok=1 & lag3_ok=1 & lag4_ok=1 & lag5_ok=1 & lag6_ok=1 ;
if evprpf ne . & evprmp ne . & evpro ne . & evcom ne . & evstpf ne . & txipp2 ne . & isalmtot2 ne . &
l1_evprmp ne . & l2_evprmp ne . & l3_evprmp ne . & l4_evprmp ne . & l5_evprmp ne . & l6_evprmp ne . &
l1_evstpf ne . & l2_evstpf ne . & l3_evstpf ne . & l4_evstpf ne . & l5_evstpf ne . & l6_evstpf ne . &
l1_evpro ne . & l2_evpro ne . & l3_evpro ne . & l4_evpro ne . & l5_evpro ne . & l6_evpro ne .  &
l1_evcom ne . & l2_evcom ne . & l3_evcom ne . & l4_evcom ne . & l5_evcom ne . & l6_evcom ne .  &
l1_txipp2 ne . & l2_txipp2 ne . & l3_txipp2 ne . & l4_txipp2 ne . & l5_txipp2 ne . & l6_txipp2 ne . & 
l1_isalmtot2 ne . & l2_isalmtot2 ne . & l3_isalmtot2 ne . & l4_isalmtot2 ne . & l5_isalmtot2 ne . & l6_isalmtot2 ne .  & 
prevpro ne . & evprmp_f1 ne . & evcom_f1 ne . & prevstpf ne . & isalmtot2_f1 ne . & txipp2_f1 ne . ; 

IF CUM_ISALMTOT_L0 NE .;
IF CUM_EVPRMP_L0 NE .;
IF CUM_EVCOM_L0 NE .; 
IF CUM_IPP2_L0 NE .;
IF CUM_EVPRO_L0 NE .; 
IF CUM_EVSTPF_L0 NE .; 
if duree_traj >= 12;
if left_censor=0;
if nace2digits in ('05','08','35', '41','43','45','46','47','49','52','56','58','59',
                         '61','62','64','70','71','72','73','74','82','94','95') then delete;
run;

proc means data = temp.complet ; run;
