/*** THIS PROGRAM AIMS AT:
- CREATING INDUSTRY DUMMIES, MONTH DUMMIES, YEAR DUMMIES, DUMMIES FOR SPELL DURATIONS 
AS WELL AS SOME SUPPLEMENTARY VARIABLES FOR SHOCKS 
- DEFINING OBSERVED INCREASES AND DECREASES AS PERMANENT OR TRANSITORY; 
- COMPUTING INDICATORS REGARDING FIRMS' ENVIRONMENT VARIABILITY
- MERGING THE DATA WITH THE IPN SPECIFIC SURVEY ABOUT PRICING BEHAVIORS TO GET THE MARKET COMPETITION MEASURE
- EXPORTING DATA TO STATA IN ORDER TO COMPUTE GENERALIZED RESIDUALS FOR INSTRUMENTING ENDOGENOUS REGRESSORS
***/

DM 'CLEAR LOG; CLEAR OUTPUT;';


libname EC 'yyy';
libname temp 'xxx';

options linesize = 100;
options pagesize = 72;

proc contents data=TEMP.complet; run;

/***********************************/
/*  CREATION OF SPECIFIC DUMMIES   */
/***********************************/

data TEMP.ACEMO_EC11; set TEMP.complet;

ind_10 = (nace2digits in ('10'));
ind_11 = (nace2digits in ('11'));
ind_13 = (nace2digits in ('13', '14'));
ind_15 = (nace2digits in ('15'));
ind_16 = (nace2digits in ('16'));
ind_17 = (nace2digits in ('17'));
ind_18 = (nace2digits in ('18','19'));
ind_20 = (nace2digits in ('20'));
ind_21 = (nace2digits in ('21'));
ind_22 = (nace2digits in ('22'));
ind_23 = (nace2digits in ('23'));
ind_24 = (nace2digits in ('24'));
ind_25 = (nace2digits in ('25'));
ind_26 = (nace2digits in ('26'));
ind_27 = (nace2digits in ('27'));
ind_28 = (nace2digits in ('28'));
ind_29 = (nace2digits in ('29'));
ind_30 = (nace2digits in ('30'));
ind_31 = (nace2digits in ('31'));
ind_32 = (nace2digits in ('32'));
ind_33 = (nace2digits in ('33'));

DUR_1  = (DUREE=1); 
DUR_2  = (DUREE=2); 
DUR_3  = (DUREE=3); 
DUR_4  = (DUREE=4); 
DUR_5  = (DUREE=5); 
DUR_6  = (DUREE=6); 
DUR_7  = (DUREE=7); 
DUR_8  = (DUREE=8); 
DUR_9  = (DUREE=9); 
DUR_10 = (DUREE=10); 
DUR_11 = (DUREE=11); 
DUR_12 = (DUREE=12); 
DUR_13 = (DUREE=13); 
DUR_14 = (DUREE=14); 
DUR15_24 = (DUREE>=15 and DUREE<=24); 
DUR25_00 = (DUREE>24); 

MOIS_1  = (MOIS=1); 
MOIS_2  = (MOIS=2); 
MOIS_3  = (MOIS=3); 
MOIS_4  = (MOIS=4); 
MOIS_5  = (MOIS=5); 
MOIS_6  = (MOIS=6); 
MOIS_7  = (MOIS=7); 
MOIS_8  = (MOIS=8); 
MOIS_9  = (MOIS=9); 
MOIS_10 = (MOIS=10); 
MOIS_11 = (MOIS=11); 
MOIS_12 = (MOIS=12); 

Y_1999  = (ANNEE=1999); 
Y_2000  = (ANNEE=2000); 
Y_2001  = (ANNEE=2001); 
Y_2002  = (ANNEE=2002); 
Y_2003  = (ANNEE=2003); 
Y_2004  = (ANNEE=2004); 
Y_2005  = (ANNEE=2005); 
Y_2006  = (ANNEE=2006); 
Y_2007  = (ANNEE=2007); 
Y_2008  = (ANNEE=2008); 
Y_2009  = (ANNEE=2009); 

trim1=mois_1+mois_2+mois_3;
trim2=mois_4+mois_5+mois_6;
trim3=mois_7+mois_8+mois_9;
trim4=mois_10+mois_11+mois_12;

id_tva1=(mois=4 & annee=2000);
id_tva2=(mois<=4 & annee=2000);

id_euro=(mois=1 & annee=2002);
id_euro2=(mois>=7 & annee=2001)+(mois<=6 & annee=2002);

run;

data  TEMP.ACEMO_EC11; set temp.acemo_ec11;

delta_p = (evprpf ne 0);
delta_pip = (evprmp ne 0);
delta_wag = (isalmtot2 ne 0);
delta_pro = (evpro ne 0);
wage_inc = (isalmtot2 >0);
wage_dec = (isalmtot2 <0);
price_inc = (evprpf>0);
price_dec = (evprpf <0);

iip_lshk = (abs(evprmp_5) >= 2); 
iip_sshk = (abs(evprmp_5) =1);

wag_lshk = (abs(isalmtot2_5) >= 0.03); 
wag_sshk = ( 0 < abs(isalmtot2_5) < 0.03);

pro_lshk = (abs(evpro_5) >= 2); 
pro_sshk = (abs(evpro_5) =1);

ipp_lshk = (abs(txipp2_5) >= p90_txipp2); 
ipp_sshk = (0 < abs(txipp2_5) < p90_txipp2);

iip_perm = ( ((evprmp ne 0 ) & (evprmp*l1_evprmp>0)) + ((evprmp ne 0 ) & (evprmp*l2_evprmp>0)) ) >0;
l1_iip_perm = ( ((l1_evprmp ne 0 ) & (l1_evprmp*l2_evprmp>0)) + ((l1_evprmp ne 0 ) & (l1_evprmp*l3_evprmp>0)) ) >0;
prod_perm = ( ((evpro ne 0 ) & (evpro*l1_evpro>0)) + ((evpro ne 0 ) & (evpro*l2_evpro>0)) ) >0;
l1_prod_perm = ( ((l1_evpro ne 0 ) & (l1_evpro*l2_evpro>0)) + ((l1_evpro ne 0 ) & (l1_evpro*l3_evpro>0)) ) >0;
inv_perm = ( ((evstpf ne 0 ) & (evstpf*l1_evstpf>0)) + ((evstpf ne 0 ) & (evstpf*l2_evstpf>0)) ) >0;
l1_inv_perm = ( ((l1_evstpf ne 0 ) & (l1_evstpf*l2_evstpf>0)) + ((l1_evstpf ne 0 ) & (l1_evstpf*l3_evstpf>0)) ) >0;
ord_perm = ( ((evcom ne 0 ) & (evcom*l1_evcom>0)) + ((evcom ne 0 ) & (evcom*l2_evcom>0)) ) >0;
l1_ord_perm = ( ((l1_evcom ne 0 ) & (l1_evcom*l2_evcom>0)) + ((l1_evcom ne 0 ) & (l1_evcom*l3_evcom>0)) ) >0;
ipp_perm = ( ((txipp2 ne 0 ) & (txipp2*l1_txipp2>0)) + ((txipp2 ne 0 ) & (txipp2*l2_txipp2>0)) ) >0;
l1_ipp_perm = ( ((l1_txipp2 ne 0 ) & (l1_txipp2*l2_txipp2>0)) + ((l1_txipp2 ne 0 ) & (l1_txipp2*l3_txipp2>0)) ) >0;
w_perm = (isalmtot2 ne 0);
run;

proc freq data=  TEMP.ACEMO_EC11;
tables evprmp iip_lshk iip_sshk wag_lshk wag_sshk evpro pro_lshk pro_sshk ipp_lshk ipp_sshk
       iip_perm l1_iip_perm prod_perm l1_prod_perm ipp_perm l1_ipp_perm;
run;

/****************************************************************************/
/* MERGE DATA WITH DATA FROM THE IPN SPECIFIC SURVEY ABOUT PRICING BEHAVIORS*/
/****************************************************************************/

proc contents data=ec.enquete_specifique_new_ape; run;

data enquete_specifique; set  ec.enquete_specifique_new_ape;
length siren $9. ;
siren=substr(siret,1,9);
length etabl $5. ;
etabl = substr(siret,10,5);
run;

proc contents data=enquete_specifique; run;

proc sort data=enquete_specifique; by siren etabl; run;
proc sort data=temp.acemo_EC11; by siren etabl; run;

data acemo_ec11a; merge enquete_specifique(in=in1 where=(ETABL ne "")) temp.acemo_EC11(in=in2 where=(ETABL ne "")); by siren etabl; 
if in1 & in2;
run;

data acemo_ec11b; merge enquete_specifique(in=in1 where=(ETABL eq "")) temp.acemo_EC11(in=in2 where=(ETABL eq "")); by siren ; 
if in1 & in2;
run;

data TEMP.ACEMO_EC12; set acemo_ec11a acemo_ec11b; run;

proc sort data=temp.acemo_EC11; by siren etabl ape_ec annee mois; run;
proc sort data=temp.acemo_EC12; by siren etabl ape_ec annee mois; run;

data acemo_ec_11c; merge TEMP.ACEMO_EC12(in=in1) temp.acemo_EC11(in=in2); by siren etabl ape_ec annee mois;  
if in2 & not(in1);
run;

data acemo_ec_11d; merge enquete_specifique(in=in1) acemo_ec_11c(in=in2); by siren ;if in1 & in2; run;

data TEMP.ACEMO_EC12; set TEMP.ACEMO_EC12 acemo_ec_11d; run;

proc sort nodupkey data=TEMP.ACEMO_EC12 out=verif; by siren etabl ape_ec annee mois; run;

data TEMP.ACEMO_EC12; set TEMP.ACEMO_EC12;
if q10 in (. , 0, 9) then delete;
if q03 in (. , 9) then delete;
compet0 = .;
compet1 = .;
compet2 = .;
compet3 = .;
compet4 = .;
compet5 = .;
compet6 = .;
compet9 = .;
if q03 = 0 then compet0=1; else compet0=0;
if q03 = 1 then compet1=1; else compet1=0;
if q03 = 2 then compet2=1; else compet2=0;
if q03 = 3 then compet3=1; else compet3=0;
if q03 = 4 then compet4=1; else compet4=0;
if q03 = 5 then compet5=1; else compet5=0;
if q03 = 6 then compet6=1; else compet6=0;
if q03 = 9 then compet9=1; else compet9=0;
compet_low = (0 <= q03 <= 3);
compet = (4 <= q03 <= 6);
run;

/* Computing indicators regarding firms'environment variability */
proc sort data=TEMP.ACEMO_EC12; by siren;run;

proc univariate noprint data=TEMP.ACEMO_EC12; by siren;
var isalmtot2_5 txipp2_5 evprmp evpro delta_pip delta_wag delta_pro wage_inc wage_dec price_inc price_dec;
output out = temp.deciles_id
p10 = p10_isalmtot2 p10_txipp2 p10_evprmp p10_evpro p10_delta_pip p10_delta_wag p10_delta_pro p10_wage_inc p10_wage_dec p10_price_inc p10_price_dec
q1 = p25_isalmtot2 p25_txipp2 p25_evprmp p25_evpro p25_delta_pip p25_delta_wag p25_delta_pro p25_wage_inc p25_wage_dec p25_price_inc p25_price_dec
median = p50_isalmtot2 p50_txipp2 p50_evprmp p50_evpro p50_delta_pip p50_delta_wag p50_delta_pro p50_wage_inc p50_wage_dec p50_price_inc p50_price_dec
q3 = p75_isalmtot2 p75_txipp2 p75_evprmp p75_evpro p75_delta_pip p75_delta_wag p75_delta_pro p75_wage_inc p75_wage_dec p75_price_inc p75_price_dec
p90 = p90_isalmtot2 p90_txipp2 p90_evprmp p90_evpro p90_delta_pip p90_delta_wag p90_delta_pro p90_wage_inc p90_wage_dec p90_price_inc p90_price_dec
mean = mean_isalmtot2 mean_txipp2 mean_evprmp mean_evpro m_d_pip m_d_wag m_d_pro mean_wage_inc mean_wage_dec mean_price_inc mean_price_dec
std = std_isalmtot2 std_txipp2 std_evprmp std_evpro std_delta_pip std_delta_wag std_delta_pro std_wage_inc std_wage_dec std_price_inc std_price_dec;
run; 

data TEMP.ACEMO_EC12; merge TEMP.ACEMO_EC12 temp.deciles_id; by siren; run;

proc sort data=TEMP.ACEMO_EC12; by nace2digits annee mois;run;

proc means noprint data=TEMP.ACEMO_EC12; by nace2digits annee ;
var isalmtot2_5 txipp2_5 evprmp evpro ;
output out = temp.mean_sect
median = p50st_isalmtot2 p50st_txipp2 p50st_evprmp p50st_evpro 
mean = meanst_isalmtot2 meanst_txipp2 meanst_evprmp meanst_evpro 
p10 = p10st_isalmtot2 p10st_txipp2 p10st_evprmp p10st_evpro 
p25 = p25st_isalmtot2 p25st_txipp2 p25st_evprmp p25st_evpro 
p75 = p75st_isalmtot2 p75st_txipp2 p75st_evprmp p75st_evpro 
p90 = p90st_isalmtot2 p90st_txipp2 p90st_evprmp p90st_evpro ;
run; 

data TEMP.ACEMO_EC12; merge TEMP.ACEMO_EC12 temp.mean_sect; by nace2digits annee ; run;

proc univariate noprint data=TEMP.ACEMO_EC12; by nace2digits;
var meanst_isalmtot2 meanst_txipp2 meanst_evprmp meanst_evpro ;
output out = temp.deciles_sect
p10 = p10s_isalmtot2 p10s_txipp2 p10s_evprmp p10s_evpro 
q1 = p25s_isalmtot2 p25s_txipp2 p25s_evprmp p25s_evpro 
median = p50s_isalmtot2 p50s_txipp2 p50s_evprmp p50s_evpro 
q3 = p75s_isalmtot2 p75s_txipp2 p75s_evprmp p75s_evpro 
p90 = p90s_isalmtot2 p90s_txipp2 p90s_evprmp p90s_evpro 
mean = means_isalmtot2 means_txipp2 means_evprmp means_evpro 
std = stds_isalmtot2 stds_txipp2 stds_evprmp stds_evpro ;
run; 

data TEMP.ACEMO_EC12; merge TEMP.ACEMO_EC12 temp.deciles_sect; by nace2digits; run;

data TEMP.ACEMO_EC12; set TEMP.ACEMO_EC12;
m_d_spi = std_txipp2;
run;

data TEMP.ACEMO_EC12; set TEMP.ACEMO_EC12;
if m_d_spi ne . ;
run;

proc sort data =  TEMP.ACEMO_EC12; by ident; run;

DATA TEMP.STATA_BASE_Q3_CHOCS; SET  TEMP.ACEMO_EC12; 
retain num_entr 0;
num_entr=num_entr+(1-(ident=lag(ident)));
date = annee*1000+mois;
keep num_entr siren etabl ape_ec annee mois date numenq poids_eff 
DUR_1-DUR_14 DUR15_24 DUR25_00 MOIS_1-MOIS_12 Y_1999-Y_2009 TRIM1-TRIM4
id_tva1 id_tva2 id_euro id_euro2 
delta_p evprpf   evprmp   evpro   evcom   evstpf   txipp2   isalmtot2  
l1_evprmp l2_evprmp l3_evprmp l4_evprmp l5_evprmp   l6_evprmp   
l1_evpro   l2_evpro l3_evpro l4_evpro l5_evpro   l6_evpro    
l1_evcom   l2_evcom l3_evcom l4_evcom l5_evcom   l6_evcom    
l1_evstpf   l2_evstpf l3_evstpf l4_evstpf l5_evstpf   l6_evstpf   
l1_txipp2   l2_txipp2 l3_txipp2 l4_txipp2 l5_txipp2   l6_txipp2   
l1_isalmtot2   l2_isalmtot2 l3_isalmtot2 l4_isalmtot2 l5_isalmtot2 l6_isalmtot2  
y_null prevpro evprmp_f1 evcom_f1 prevstpf isalmtot2_f1 txipp2_f1 
CUM_ISALMTOT CUM_ISALMTOT_L0 CUM_ISALMTOT_L1 ISALMTOT2_L1 ISALMTOT2_L2 ISALMTOT2_L3
CUM_EVPRMP CUM_EVPRMP_L0 CUM_EVPRMP_L1 EVPRMP_L1 EVPRMP_L2 EVPRMP_L3
CUM_EVCOM CUM_EVCOM_L0 CUM_EVCOM_L1 EVCOM_L1 EVCOM_L2 EVCOM_L3 
CUM_IPP2 CUM_IPP2_L0 CUM_IPP2_L1 TXIPP2_L1 TXIPP2_L2 TXIPP2_L3 
CUM_EVPRO CUM_EVPRO_L0 CUM_EVPRO_L1 EVPRO_L1 EVPRO_L2 EVPRO_L3 
CUM_EVSTPF CUM_EVSTPF_L0 CUM_EVSTPF_L1 EVSTPF_L1 EVSTPF_L2 EVSTPF_L3
iip_lshk iip_sshk wag_lshk wag_sshk evpro pro_lshk pro_sshk ipp_lshk ipp_sshk
iip_perm prod_perm ord_perm inv_perm ipp_perm w_perm
l1_iip_perm l1_prod_perm l1_ord_perm l1_inv_perm l1_ipp_perm 
compet q03 q10 q17a lib10
m_d_spi m_d_pip m_d_wag m_d_pro

ind_10 ind_11 ind_13 ind_15 ind_16 ind_17 ind_18 
ind_20 ind_21 ind_22 ind_23 ind_24 ind_25 ind_26 ind_27 ind_28 ind_29 
ind_30 ind_31 ind_32 ind_33;
run;

proc means data=TEMP.STATA_BASE_Q3_CHOCS; run;

data TEMP.STATA_instruments(keep= num_entr date ind_10 ind_11 ind_13 ind_15 ind_16 ind_17 ind_18 
ind_20 ind_21 ind_22 ind_23 ind_24 ind_25 ind_26 ind_27 ind_28 ind_29 
ind_30 ind_31 ind_32 ind_33 
id_tva1 id_tva2 id_euro id_euro2 
mois_1 mois_7 trim1 trim2 trim3 trim4 Y_1999-Y_2009 
pr_rm pr_rm1 pr_rmc pr_rmc1 pr_rmc0 prod prod1 prodc prodc1 prodc0 wage wage1 wagec wagec1 wagec0 wag_lshk w_perm ppi1 ppic ppic1 ppic0 
l1_evprmp l2_evprmp l3_evprmp l4_evprmp l5_evprmp   l6_evprmp   
l1_evpro   l2_evpro l3_evpro l4_evpro l5_evpro   l6_evpro    
l1_evcom   l2_evcom l3_evcom l4_evcom l5_evcom   l6_evcom    
l1_evstpf   l2_evstpf l3_evstpf l4_evstpf l5_evstpf   l6_evstpf   
l1_txipp2   l2_txipp2 l3_txipp2 l4_txipp2 l5_txipp2   l6_txipp2   
l1_isalmtot2   l2_isalmtot2 l3_isalmtot2 l4_isalmtot2 l5_isalmtot2 l6_isalmtot2  
);
set TEMP.STATA_BASE_Q3_CHOCS;
rename evprmp= pr_rm;
rename evprmp_L1= pr_rm1;
rename cum_evprmp = pr_rmc;
rename cum_evprmp_L1 = pr_rmc1;
rename cum_evprmp_L0 = pr_rmc0;

rename evpro= prod;
rename evpro_L1= prod1;
rename cum_evpro = prodc;
rename cum_evpro_L1 = prodc1;
rename cum_evpro_L0 = prodc0;

rename isalmtot2= wage;
rename isalmtot2_L1= wage1;
rename cum_isalmtot = wagec;
rename cum_isalmtot_L1 = wagec1;
rename cum_isalmtot_L0 = wagec0;

rename txipp2_L1= ppi1;
rename cum_ipp2 = ppic;
rename cum_ipp2_L1 = ppic1;
rename cum_ipp2_L0 = ppic0;

run;

/* Export data to stata */
PROC EXPORT DATA= TEMP.STATA_instruments 
            OUTFILE= "C:\STATA_INSTRUMENTS" 
            DBMS=STATA REPLACE;
RUN;

