* This program computes the IV residuals (resp. the generalized residuals) 
* stemming from the first step regression of continuous regressors (resp. the three outcome regressors) 
* on instruments. 

capture clear
capture log close

clear

set memory 800m
set more off

* define the dataset to be used

use "C:\www" 


preserve

tsset num_entr date

sum  l1_evprmp l2_evprmp l3_evprmp l4_evprmp l5_evprmp   l6_evprmp ///  
                   l1_evpro   l2_evpro l3_evpro l4_evpro l5_evpro   l6_evpro    ///
                   l1_txipp2   l2_txipp2 l3_txipp2 l4_txipp2 l5_txipp2   l6_txipp2   ///
                    l1_isalmtot2    l2_isalmtot2 l3_isalmtot2 l4_isalmtot2 l5_isalmtot2 l6_isalmtot2  ///
                  
local instruments  l2_evprmp l3_evprmp l4_evprmp l5_evprmp   l6_evprmp ///  
                   l2_evpro l3_evpro l4_evpro l5_evpro   l6_evpro    ///
                   l2_txipp2 l3_txipp2 l4_txipp2 l5_txipp2   l6_txipp2   ///
                   l2_isalmtot2 l3_isalmtot2 l4_isalmtot2 l5_isalmtot2 l6_isalmtot2  ///
                   ind_10 ind_11 ind_13 ind_15 ind_16 ind_17 ind_18 ind_20 ind_21 ind_22 ind_23 ///
                   ind_24 ind_25 ind_26 ind_27 ind_28 ind_29 ind_30 ind_31 ind_32 /*ind_33*/ /// 
                   id_tva1 id_tva2 id_euro id_euro2  ///
                    mois_1 mois_7   trim1 trim2 trim3 ///
                   y_1999 y_2000 y_2001 y_2002 y_2003 y_2004 y_2005 y_2006 y_2007 y_2008 /*y_2009*/


/**INSTRUMENTATION OF TOTAL AND PARTIAL CUMULATIVE SUMS **/

regress pr_rmc  `instruments'  
predict rpr_rmc, residual 

regress prodc `instruments'   
predict rprodc, residual 

regress wagec `instruments'
predict rwagec, residual 

regress ppic  `instruments'   
predict rppic, residual 

regress pr_rmc1  `instruments'  
predict rpr_rmc1, residual 

regress prodc1 `instruments'   
predict rprodc1, residual 

regress wagec1 `instruments'
predict rwagec1, residual 

regress ppic1  `instruments'   
predict rppic1, residual 

regress pr_rmc0  `instruments'  
predict rpr_rmc0, residual 

regress prodc0 `instruments'   
predict rprodc0, residual 

regress wagec0 `instruments'
predict rwagec0, residual 

regress ppic0  `instruments'   
predict rppic0, residual 



/**INSTRUMENTATION (generalized residuals) OF CHANGES IN T OR T-1 **/

oprobit pr_rm `instruments'   
predict p_pr_rm, xb 
gen w0_pr_rm =    -p_pr_rm + _b[cut1:_cons]
gen w1_pr_rm =    -p_pr_rm + _b[cut2:_cons]
generate rpr_rm = (-normalden(w0_pr_rm))/(normal(w0_pr_rm)) if (pr_rm == -1)
replace rpr_rm = (normalden(w0_pr_rm) - normalden(w1_pr_rm))/ (normal(w1_pr_rm)-normal(w0_pr_rm)) if (pr_rm == 0)
replace rpr_rm = normalden(w1_pr_rm)/(1-normal(w1_pr_rm)) if (pr_rm == 1)
// diagnostics
sum pr_rm rpr_rm

oprobit pr_rm1  `instruments'
predict p_pr_rm1, xb 
gen w0_pr_rm1 =    -p_pr_rm1 + _b[cut1:_cons]
gen w1_pr_rm1 =    -p_pr_rm1 + _b[cut2:_cons]
generate rpr_rm1 = (-normalden(w0_pr_rm1))/(normal(w0_pr_rm1)) if (pr_rm1 == -1)
replace rpr_rm1 = (normalden(w0_pr_rm1) - normalden(w1_pr_rm1))/ (normal(w1_pr_rm1)-normal(w0_pr_rm1)) if (pr_rm1 == 0)
replace rpr_rm1 = normalden(w1_pr_rm1)/(1-normal(w1_pr_rm1)) if (pr_rm1 == 1)
// diagnostics
sum pr_rm1 rpr_rm1

oprobit prod `instruments'   
predict p_prod, xb 
gen w0_prod =    -p_prod + _b[cut1:_cons]
gen w1_prod =    -p_prod + _b[cut2:_cons]
generate rprod = (-normalden(w0_prod))/(normal(w0_prod)) if (prod == -1)
replace rprod = (normalden(w0_prod) - normalden(w1_prod))/ (normal(w1_prod)-normal(w0_prod)) if (prod == 0)
replace rprod = normalden(w1_prod)/(1-normal(w1_prod)) if (prod == 1)
// diagnostics
sum prod rprod

oprobit prod1 `instruments' 
predict p_prod1, xb 
gen w0_prod1 =    -p_prod1 + _b[cut1:_cons]
gen w1_prod1 =    -p_prod1 + _b[cut2:_cons]
generate rprod1 = (-normalden(w0_prod1))/(normal(w0_prod1)) if (prod1 == -1)
replace rprod1 = (normalden(w0_prod1) - normalden(w1_prod1))/ (normal(w1_prod1)-normal(w0_prod1)) if (prod1 == 0)
replace rprod1 = normalden(w1_prod1)/(1-normal(w1_prod1)) if (prod1 == 1)
// diagnostics
sum prod1 rprod1

oprobit wage `instruments'   
predict p_wage, xb 
gen w0_wage =    -p_wage + _b[cut1:_cons]
gen w1_wage =    -p_wage + _b[cut2:_cons]
generate rwage = (-normalden(w0_wage))/(normal(w0_wage)) if (wage == -1)
replace rwage = (normalden(w0_wage) - normalden(w1_wage))/ (normal(w1_wage)-normal(w0_wage)) if (wage == 0)
replace rwage = normalden(w1_wage)/(1-normal(w1_wage)) if (wage == 1)
// diagnostics
sum wage rwage

oprobit wage1 `instruments' 
predict p_wage1, xb 
gen w0_wage1 =    -p_wage1 + _b[cut1:_cons]
gen w1_wage1 =    -p_wage1 + _b[cut2:_cons]
generate rwage1 = (-normalden(w0_wage1))/(normal(w0_wage1)) if (wage1 == -1)
replace rwage1 = (normalden(w0_wage1) - normalden(w1_wage1))/ (normal(w1_wage1)-normal(w0_wage1)) if (wage1 == 0)
replace rwage1 = normalden(w1_wage1)/(1-normal(w1_wage1)) if (wage1 == 1)
// diagnostics
sum wage1 rwage1

probit wag_lshk `instruments' 
predict p_w_lshk, xb 
generate rw_lshk = cond(wag_lshk == 1, normalden(p_w_lshk)/normal(p_w_lshk), -normalden(p_w_lshk)/(1-normal(p_w_lshk))) 
// diagnostics
sum wag_lshk rw_lshk

probit w_perm `instruments' 
predict p_w_perm, xb 
generate rw_perm = cond(w_perm == 1, normalden(p_w_perm)/normal(p_w_perm), -normalden(p_w_perm)/(1-normal(p_w_perm))) 
// diagnostics
sum w_perm rw_perm

oprobit ppi1 `instruments' 
predict p_ppi1, xb 
gen w0_ppi1 =    -p_ppi1 + _b[cut1:_cons]
gen w1_ppi1 =    -p_ppi1 + _b[cut2:_cons]
generate rppi1 = (-normalden(w0_ppi1))/(normal(w0_ppi1)) if (ppi1 == -1)
replace rppi1 = (normalden(w0_ppi1) - normalden(w1_ppi1))/ (normal(w1_ppi1)-normal(w0_ppi1)) if (ppi1 == 0)
replace rppi1 = normalden(w1_ppi1)/(1-normal(w1_ppi1)) if (ppi1 == 1)
// diagnostics
sum ppi1 rppi1


sum rpr_rm rpr_rm1 rpr_rmc rpr_rmc1 rprod rprod1 rprodc rprodc1 rwage rwage1 rwagec rwagec1 rw_lshk rppi1 rppic rppic1 rw_perm

keep num_entr date rpr_rm rpr_rm1 rpr_rmc rpr_rmc1 rpr_rmc0 rprod rprod1 rprodc rprodc1 rprodc0 rwage rwage1 rwagec rwagec1 rwagec0 ///
rw_lshk rw_perm rppi1 rppic rppic1 rppic0

save "C:\resids.dta", replace 

