library cml;
#include cml.ext;

                        /* INFL_OP.PRC: ZERO INFLATED ORDERED PROBABILITY CHOICE MODELS */

/* 
** Estimates: Ordered Probit and Zero-Inflated Ordered Probit                                       **
** Takes form:                                                                                      **
**      {ordered,logo,retord,pord,iop,logziop,LR1,piop,retiop,xvec,zvec,Voung1,Voung2} =            **
**    mnmodels("dataset",model,stopb,stiop,eqns,eqnXs);                                             **    
** Input:       dataset         - first column is y                                                 **
**                  stopb       - optional - user supplied starting values, a 0 takes defaults      **
**                  stiop      - optional - user supplied starting values, a 0 takes defaults       **
**          xvec        - vector defining which of the datset is to be used for the 0/1 decision    **
**          zvec        - vector defining which of the datset is to be used for the "how much"      **
**          index       - scalar, with j = 0,...J-1 indicating which choice to inflate on           **
** Output: all model types give ols and ordered probit                                              **
**                      - ordered: parameter estimates and t-stats                                  **
**                      - logo: maximised LogL                                                      **
**                      - pord: n by J matrix of estimated probablilities for choice j              **
**                      - retord: string - return code                                              **
**                      - iop: parameter estimates and t-stats                                     **
**                      - logziop: maximised LogL                                                   **
**          - LR1 - likelihood ratio test iop vs OP                                                **
**                      - piop: n by J matrix of estimated probablilities for choice j             **
**                      - iopc: parameter estimates and t-stats                                    **
**                      - logziopc: maximised LogL                                                  **
**          - LR2 - likelihood ratio test iopc vs OP                                               **
**                      - piopc: n by J matrix of estimated probablilities for choice j            **
**                      - retiopc: string - return code                                            **
**          - Vuong1 - Vuong's (1989) test for non-nested models iop vs OP                         **
**          - Vuong2 - Vuong's (1989) test for non-nested models iopc vs OP                        **
**                                                                                                  **
*/

               
cls;
trap 0;                                                                                                     
 
proc 191 = inf_opRE(dset,model,stopb,stgop,stpbt,stiop,stgiop,stiopREZ,stiopREX,stiopRE,stiopREfull,stiopc,stiopcRE,stiopcREfull,stgiopcREfull,
                        x_vec,z_vec,w_vec,j_index,MM,sim_ME_0_1,skip_RE,tol,cluster_se);
local infile1, fh, varsz, y, yxz, ytemp, z, xzall, x, n, zcheck, zchkvec, cdo; 
local zrep, vnames, capJall, jrep, yj, btmp, zvars, xvars, fail; 
local ordpbt, opbse, topb, maxfopb, gopb, covopb, retopb, mu;
local gamp, maxfp, gp, gampcov,rep, olsgam;
local eqnrep, iop, iopse, tiop, maxfiop, g_iop, coviop, retiop, piop, muall;
local d_ij, phat, startmu1, startmu, startrep, mark, startcon;
local betahat, plgt; 
local pordp, zbetahat, muhat, p_ij, jrep2, check, varstmp;
local noxs, ztemp, cov;
local CC, DD, c, c_old, col, ctemp;
local beta, gama, muiop, xbeta, zgama; 
local ordtmp, maxftmp, gtmp, covtmp, rettmp, starttmp;
local muiopc, iopc, iopcse, tiopc, maxfiopc, giopc, coviopc, retiopc, piopc;
local fail_c, rho, nocon, nocon_c;
local LR1, LR2, Vuong1, Vuong2, f1, f2, mi, vtop, vbot;
local logltmp, loglrep, startmp, q1, q2, v1, v2, h_sel1, h_sel2, p_aug;
local me_op, me_opse, me_model, V_op, AICop, BICop, CAICop, popxbar, pop_se;
local me_iop, me_iopse, V_iop, AICiop, BICiop, CAICiop, piopxbar,piop_se;
local me_iopc, me_iopcse, V_iopc, AICiopc, BICiopc, CAICiopc, piopcxbar, piopc_se;
local retprobit, probitse, tprobit, maxfprobit, pprobit, V_probit, AICprobit, BICprobit, CAICprobit, me_probit, me_probitse;
local pprobitxbar, pprobit_se, test, H;
local me0_op, me0se_op, me0_pbt, me0se_pbt, me0_iop, me0se_iop, me0_iopc, me0se_iopc; 
local idvec, N_panel, myprime, prim, hm1, hm2;
local et_start, et_op, et_probit, et_iop, et_iop_REX, et_iop_REZ, et_iop_RE, et_iopc;
local v_cov_RE, v_cov_REc, se_cov_RE, se_cov_REc, G_cov, cov_se, covc_se;
local var_tmp, chol_tmp, logL, prob, r, chol_cov, ai_ei, sig_zRE, sig_xRE;
local prob_temp, p_vec, sel, sigma, stopRE, opRE, maxfopRE, gopRE, covopRE, retopRE;
local P0, P1, Ptmp, HU, HC, PJ, p_all, var_e_i, chol_e, A, U, parm, var_e, B, P0x; 
local var_a, chol_a, var_a_i, Ptmpa, Ptmpb, prob_i, limits, ti, di, limits_i, P, omega, lower_l, upper_l, chol_21, chol_22, chol_check;
local tmp, g, opREse, p_temp, xn, wn, prob_all, theta, panel_r_z, panel_r_x, sig_z, sig_x, M_half, sig_rep, sig_ae, et_iop_REfull, sig_zx;
local iopREZ, iopREZse, retiopREZ, maxfiopREZ, giopREZ, coviopREZ, tiopREZ, piopREZ, V_iopREZ, AICiopREZ, BICiopREZ, CAICiopREZ, me_iopREZ, me_iopREZse, me0_iopREZ, me0se_iopREZ, piopREZxbar, piopREZ_se;
local iopREX, iopREXse, retiopREX, maxfiopREX, giopREX, coviopREX, tiopREX, piopREX, V_iopREX, AICiopREX, BICiopREX, CAICiopREX, me_iopREX, me_iopREXse, me0_iopREX, me0se_iopREX, piopREXxbar, piopREX_se;
local iopRE, iopREse, retiopRE, maxfiopRE, giopRE, coviopRE, tiopRE, piopRE, V_iopRE, AICiopRE, BICiopRE, CAICiopRE, me_iopRE, me_iopREse, me0_iopRE, me0se_iopRE, piopRExbar, piopRE_se;
local iopREfull, iopREfullse, retiopREfull, maxfiopREfull, giopREfull, coviopREfull, tiopREfull, piopREfull, V_iopREfull, AICiopREfull, BICiopREfull, CAICiopREfull, 
                    me_iopREfull, me_iopREfullse, me0_iopREfull, me0se_iopREfull, piopREfullxbar, piopREfull_se, V_cov_REfull;
local iopcRE, iopcREse, retiopcRE, maxfiopcRE, giopcRE, coviopcRE, tiopcRE, piopcRE, V_iopcRE, AICiopcRE, BICiopcRE, CAICiopcRE, et_iopcRE, me_iopcRE, me_iopcREse, me0_iopcRE, me0se_iopcRE, piopcRExbar, piopcRE_se, covcRE_se;
local iopcREfull, iopcREfullse, tiopcREfull, v_cov_REcfull, me_iopcREfull, me_iopcREfullse, me0_iopcREfull, V_iopcREfull, logliopcREfull, AICiopcREfull, BICiopcREfull, CAICiopcREfull, 
                    piopcREfull, retiopcREfull, et_iopcREfull;
local maxfiopcREfull, g_iopcREfull, coviopcREfull, me0se_iopcREfull, piopcREfullxbar, piopcREfull_se, covcREfull_se, ggiopcREfull;
local maxfgiop, ggiop, et_giop, covgiop, giopse, tgiop, mu_param, mugiop, pgiop, V_giop, AICgiop, BICgiop, CAICgiop, giop;
local me_giop, me_giopse, me0_giop, me0se_giop, pgiopxbar, pgiop_se, av_w, w, kw, wvars, av_x, b_ols, st_mu, retgiop, av_z;
local meWop, meWpbt, meWiop, meWgiop, meWiopREZ, meWiopREX, meWiopRE, meWiopREFULL, meWiopc, meWiopcRE, meWiopcREfull;
local meWopse, meWgiopse, meWpbtse, meWiopse, meWiopREZse, meWiopREXse, meWiopREse, meWiopREFULLse, meWiopcse, meWiopcREse, meWiopcREFULLse;
local giopcREfullse, tgiopcREfull, v_cov_gREcfull, me_giopcREfull, me_giopcREfullse, me0_giopcREfull, V_giopcREfull, loglgiopcREfull, maxfgiopcREfull, giopcREfull;
local covgiopcREfull, mugiopg, me0se_giopcREfull, meWgiopcREfull, meWgiopcREfullse, pgiopcREfullxbar, pgiopcREfull_se, covgcREfull_se;
local AICgiopcREfull, BICgiopcREfull, CAICgiopcREfull, pgiopcREfull, retgiopcREfull, et_giopcREfull;
local me_sim, me_sim_se, me0_sim, me0_sim_se, meW_sim, meW_sim_se;
local sel_i, xz_i, xz_it, cz, yvars, yzvars;
local p_aug_pred, p_aug_pred0;
local p0_iop, p0_giop, p0_iopREZ, p0_iopREX, p0_iopRE, p0_iopREfull, p0_iopc, p0_iopcRE, p0_iopcREfull, p0_giopcREfull;
local mu_temp, opnames, op_mu, start_mu, gopnames, ts;
local gop_et, gop, maxfgop, ggop, V_gop, retgop, gopse, tgop, me_gop, megopse, pgop, AICgop, BICgop, CAICgop, gop_theta;
local gop_delta, mu_ij, pgopxbar, pgop_se, op_b, wxvec, av_wx;
local ai_mat_Z, ai_mat_X, ai_X, ai_Z;
local me_cond_op, me_cond_op_se,
me_cond_probit, me_cond_probit_se,
me_cond_iop, me_cond_iop_se,    
me_cond_giop, me_cond_giop_se,
me_cond_iopREZ, me_cond_iopREZ_se, 
me_cond_iopREX, me_cond_iopREX_se,
me_cond_iopRE, me_cond_iopRE_se,
me_cond_iopREfull, me_cond_iopREfull_se,
me_cond_iopc, me_cond_iopc_se,
me_cond_iopcRE, me_cond_iopcRE_se,
me_cond_iopcREfull, me_cond_iopcREfull_se,
me_cond_giopcREfull, me_cond_giopcREfull_se;

local outer_g_iopcREfull,outer_ggiop,outer_ggiopcREfull,outer_ggop,outer_giop,outer_giopRE,outer_giopREX,outer_giopREZ,outer_giopREfull,
outer_giopc,outer_giopcRE,outer_gopb,outer_gp;

clear gamp, probitse, tprobit, me_probit, me_probitse, V_probit, maxfprobit, AICprobit, BICprobit, CAICprobit, pprobit, retprobit, et_probit;
clear ordpbt, opbse, topb, me_op, me_opse, V_op, maxfopb, AICop, BICop, CAICop, pordp, retopb, et_op;
clear iop, iopse, tiop, me_iop, me_iopse, me0_iop, me0se_iop, V_iop, maxfiop, AICiop, BICiop, CAICiop, piop, retiop, et_iop;
clear iopREZ, iopREZse, tiopREZ, me_iopREZ, me_iopREZse, me0_iopREZ, me0se_iopREZ, V_iopREZ, maxfiopREZ, AICiopREZ, BICiopREZ, CAICiopREZ, piopREZ, retiopREZ, et_iop_REZ;
clear iopREX, iopREXse, tiopREX, me_iopREX, me_iopREXse, me0_iopREX, me0se_iopREX, V_iopREX, maxfiopREX, AICiopREX, BICiopREX, CAICiopREX, piopREX, retiopREX, et_iop_REX;
clear iopRE, iopREse, tiopRE, v_cov_RE, me_iopRE, me_iopREse, me0_iopRE, me0se_iopRE, V_iopRE, maxfiopRE, AICiopRE, BICiopRE, CAICiopRE, piopRE, retiopRE, et_iop_RE;
clear iopREfull, iopREfullse, tiopREfull, v_cov_REfull, me_iopREfull, me_iopREfullse, me0_iopREfull, me0se_iopREfull, V_iopREfull, maxfiopREfull, AICiopREfull, BICiopREfull, CAICiopREfull, piopREfull, retiopREfull, et_iop_REfull;
clear iopc, iopcse, tiopc, me_iopc, me_iopcse, me0_iopc, me0se_iopc, V_iopc, maxfiopc, AICiopc, BICiopc, CAICiopc, piopc, retiopc, et_iopc;
clear iopcRE, iopcREse, tiopcRE, v_cov_REc, me_iopcRE, me_iopcREse, me0_iopcRE, me0se_iopcRE, V_iopcRE, maxfiopcRE, AICiopcRE, BICiopcRE, CAICiopcRE, piopcRE, retiopcRE, et_iopcRE;
clear iopcREfull, iopcREfullse, tiopcREfull, v_cov_REcfull, me_iopcREfull, me_iopcREfullse, me0_iopcREfull, V_iopcREfull, logliopcREfull, AICiopcREfull, BICiopcREfull, CAICiopcREfull, piopcREfull, retiopcREfull, et_iopcREfull;
clear maxfiopcREfull, giopcREfull, coviopcREfull, me0se_iopcREfull, piopcREfullxbar, piopcREfull_se, covcREfull_se;
clear giop, giopse, tgiop, me_giop, me_giopse, me0_giop, me0se_giop, meWgiop, meWgiopse, V_giop, maxfgiop, AICgiop, BICgiop, CAICgiop, pgiop, retgiop, et_giop;
clear giopcREfull, giopcREfullse, tgiopcREfull, v_cov_gREcfull, me_giopcREfull, me_giopcREfullse, me0_giopcREfull, me0se_giopcREfull, meWgiopcREfull, meWgiopcREfullse;
clear V_giopcREfull, maxfgiopcREfull, AICgiopcREfull, BICgiopcREfull, CAICgiopcREfull, pgiopcREfull, retgiopcREfull, et_giopcREfull;
clear p0_iop, p0_giop, p0_iopREZ, p0_iopREX, p0_iopRE, p0_iopREfull, p0_iopc, p0_iopcRE, p0_iopcREfull, p0_giopcREfull;

clear me_cond_iop, me_cond_iop_se,    
me_cond_giop, me_cond_giop_se,
me_cond_iopREZ, me_cond_iopREZ_se, 
me_cond_iopREX, me_cond_iopREX_se,
me_cond_iopRE, me_cond_iopRE_se,
me_cond_iopREfull, me_cond_iopREfull_se,
me_cond_iopc, me_cond_iopc_se,
me_cond_iopcRE, me_cond_iopcRE_se,
me_cond_iopcREfull, me_cond_iopcREfull_se,
me_cond_giopcREfull, me_cond_giopcREfull_se;


clear gamp, probitse, tprobit, me_probit, me_probitse, V_probit, maxfprobit, AICprobit, BICprobit, CAICprobit, pprobit, retprobit, et_probit,
    ordpbt, opbse, topb, me_op, me_opse, V_op, maxfopb, AICop, BICop, CAICop, pordp, retopb, et_op,
    iop, iopse, tiop, me_iop, me_iopse, me0_iop, me0se_iop, V_iop, maxfiop, AICiop, BICiop, CAICiop, piop, p0_iop, retiop, et_iop, 
    giop, giopse, tgiop, me_giop, me_giopse, me0_giop, me0se_giop, meWgiop, meWgiopse, V_giop, maxfgiop, AICgiop, BICgiop, CAICgiop, pgiop, p0_giop, retgiop, et_giop, 
    iopREZ, iopREZse, tiopREZ, me_iopREZ, me_iopREZse, me0_iopREZ, me0se_iopREZ, V_iopREZ, maxfiopREZ, AICiopREZ, BICiopREZ, CAICiopREZ, 
            piopREZ, p0_iopREZ, retiopREZ, et_iop_REZ,
    iopREX, iopREXse, tiopREX, me_iopREX, me_iopREXse, me0_iopREX, me0se_iopREX, V_iopREX, maxfiopREX, AICiopREX, BICiopREX, CAICiopREX, 
            piopREX, p0_iopREX, retiopREX, et_iop_REX,
    iopRE, iopREse, tiopRE, v_cov_RE, me_iopRE, me_iopREse, me0_iopRE, me0se_iopRE, V_iopRE, maxfiopRE, AICiopRE, BICiopRE, CAICiopRE, 
        piopRE, p0_iopRE, retiopRE, et_iop_RE,
    iopREfull, iopREfullse, tiopREfull, v_cov_REfull, me_iopREfull, me_iopREfullse, me0_iopREfull, me0se_iopREfull, V_iopREfull, maxfiopREfull, 
            AICiopREfull, BICiopREfull, CAICiopREfull, piopREfull, p0_iopREfull, retiopREfull, et_iop_REfull,
    iopc, iopcse, tiopc, me_iopc, me_iopcse, me0_iopc, me0se_iopc, V_iopc, maxfiopc, AICiopc, BICiopc, CAICiopc, piopc, p0_iopc, retiopc, et_iopc,
    iopcRE, iopcREse, tiopcRE, v_cov_REc, me_iopcRE, me_iopcREse, me0_iopcRE, me0se_iopcRE, V_iopcRE, maxfiopcRE, AICiopcRE, BICiopcRE, CAICiopcRE, 
            piopcRE, p0_iopcRE, retiopcRE, et_iopcRE,
    iopcREfull, iopcREfullse, tiopcREfull, v_cov_REcfull, me_iopcREfull, me_iopcREfullse, me0_iopcREfull, me0se_iopcREfull, V_iopcREfull, maxfiopcREfull, 
        AICiopcREfull, BICiopcREfull, CAICiopcREfull, piopcREfull, p0_iopcREfull, retiopcREfull, et_iopcREfull,
    giopcREfull, giopcREfullse, tgiopcREfull, v_cov_gREcfull, me_giopcREfull, me_giopcREfullse, me0_giopcREfull, me0se_giopcREfull, meWgiopcREfull, meWgiopcREfullse,
            V_giopcREfull, maxfgiopcREfull, AICgiopcREfull, BICgiopcREfull, CAICgiopcREfull, pgiopcREfull, p0_giopcREfull, retgiopcREfull, et_giopcREfull;

clear outer_g_iopcREfull,outer_ggiop,outer_ggiopcREfull,outer_ggop,outer_giop,outer_giopRE,outer_giopREX,outer_giopREZ,outer_giopREfull,
outer_giopc,outer_giopcRE,outer_gopb,outer_gp;

clearg jj, kx, kz, kw, kall, RE, xbar_me, zbar_me, mtype, xvec, zvec, wvec, wxvec, capJ, index, M, sim_ME, xbar, mtype_me, p_0;

/* WHICH MODELS? */

let mtype = ordered iop giop iop_REZ iop_REX iop_RE iop_REfull iopc iopc_RE iopc_REfull giopc_REfull; 
mtype = indcv(model,mtype); 


/* READ IN FULL DATA SET */

infile1 = dset;
open fh = ^infile1 varindxi;
varsz   = getname(infile1);
yvars   = varsz[1];
varsz   = varsz[3:rows(varsz)];

yxz     = readr(fh,rowsf(fh)); 
yxz     = packr(yxz);

xzall   = yxz[.,3:cols(yxz)];
y       = yxz[.,1];
y       = y - minc(y);                                      
capJ    = maxc(y) - minc(y) + 1;

idvec   = yxz[.,2];
idvec   = idvec - minc(idvec) + 1;
N       = rows(idvec);

fh      = close(fh);

wvec    = w_vec;
zvec    = z_vec;
xvec    = x_vec;
index   = j_index;
M       = MM;
sim_ME  = sim_ME_0_1;



//data_bhhh = y~idvec~xzall;

if capJ lt 3;
        "ERROR: too few categories for estimation (3 minimum). # is";;capJ;stop;
endif;


                        /* CHECK FOR SUFFICIENT VARIATION IN Z */

if cols(xzall) gt 1;
        zcheck  = stdc(xzall[.,2:cols(xzall)]);
        zchkvec = (zcheck .le 0.1);

        zrep=1;
        do until zrep>cols(xzall)-1;    
                if zchkvec[zrep] eq 1;
                        "Potentially Insufficient Variation in:";$varsz[zrep+1];
                        zrep = zrep + 1;
                else;
                        zrep =zrep+1;
                endif;
        endo;
endif;

/* ENSURE CONTIGUOUS ID AND CREATE STANDARD RANDOM NUMBERS */

rndseed 1013904223;
N_panel	= maxc(idvec);


/* DEFINE DATA */

// let mtype = ordered iop giop iop_REZ iop_REX iop_RE iop_REfull iopc iopc_RE iopc_REfull giopc_REfull; 

if mtype eq 1;

    z           = selif(xzall',zvec')';
    kz          = cols(z);
    zvars       = selif(varsz,zvec');

elseif mtype eq 2 or mtype eq 4 or mtype eq 5 or mtype eq 6 or mtype eq 7 or mtype eq 8 or mtype eq 9 or mtype eq 10;

    x           = selif(xzall',xvec')'; 
    kx          = cols(x);
    xbar_me     = meanc(x);
    z           = selif(xzall',zvec')';
    kz          = cols(z);
    zbar_me     = meanc(z);
    xvars       = selif(varsz,xvec');
    zvars       = selif(varsz,zvec');
    av_x        = meanc(x);
    av_z        = meanc(z);
    clear av_w;

elseif mtype eq 3 or mtype eq 11;

    x           = selif(xzall',xvec')'; 
    kx          = cols(x);
    xbar_me     = meanc(x);
    z           = selif(xzall',zvec')';
    kz          = cols(z);
    zbar_me     = meanc(z);
    w           = selif(xzall',wvec')'; 
    kw          = cols(w);
    xvars       = selif(varsz,xvec');
    zvars       = selif(varsz,zvec');
    wvars       = selif(varsz,wvec');
    av_w        = meanc(w);
    av_x        = meanc(x);
    av_z        = meanc(z);

endif;

kall    = cols(xzall);

wxvec   = (xvec + wvec) .ge 1;
av_wx   = selif(meanc(xzall),wxvec')'; 

cz = corrx(y~z);
cz = vec(cz);
yzvars  = yvars|zvars;
yzvars  = (ones(rows(yzvars),1) .*. yzvars)~(yzvars .*. ones(rows(yzvars),1));
cz = sortc(cz~yzvars,1);
cz = delif(cz,cz[.,1] .gt 0.999999);

if cz[rows(cz),1] .ge 0.9;

    ?;
    "       MULTICOLINEARITY WARNING!!!";?;
    "TOP CORRELATION IS";;cz[rows(cz),1];
    "BETWEEN VARIABLES" 
    $cz[rows(cz),2:3]; 
    ?;
    
endif;



/* CREATE STANDARD RANDOM NUMBERS USING HALTON DRAWS */

if M gt 1;


    rndseed 1013904223;

    myprime = { 2  3};

    prim = { 2 3 5 7 11 13 17 19 23 29 31 37 41 43 47 53 59 61 67 71
                    73 79 83 89 97 101 103 107 109 113 };

    hm1 = halton(10+(M*N_panel),prim[1]);
    hm1 = hm1[11:rows(hm1)];
    hm1 = cdfni(hm1);
    hm1 = hm1.*(hm1 .le 10) + 10 .* (hm1 .gt 10);
    hm1 = hm1.*(hm1 .ge -10) -10 .* (hm1 .lt -10);
    hm1 = reshape(hm1,N_panel,M);

    hm2 = halton(10+(M*N_panel),prim[2]);
    hm2 = hm2[11:rows(hm2)];
    hm2 = cdfni(hm2);
    hm2 = hm2.*(hm2 .le 10) + 10 .* (hm2 .gt 10);
    hm2 = hm2.*(hm2 .ge -10) -10 .* (hm2 .lt -10);
    hm2 = reshape(hm2,N_panel,M);
  

    rep = 2;
    i   = 2;

    ai_mat_Z = hm2[1,.];
    ai_mat_X = hm1[1,.];

    do while rep le rows(y); 
	    if idvec[rep] eq idvec[rep-1];
            ai_mat_Z      = ai_mat_Z|ai_mat_Z[rep-1,.];
            ai_mat_X      = ai_mat_X|ai_mat_X[rep-1,.];
	    else;
            ai_mat_Z      = ai_mat_Z|hm2[i,.];	
            ai_mat_X      = ai_mat_X|hm1[i,.];
            i           = i+1;
        endif;
        rep = rep + 1;
    endo;

/*
    ai_mat_Z = ai_mat_Z~(ai_mat_Z .* -1);
    ai_mat_X = ai_mat_X~(ai_mat_X .* -1);
*/

save ai_mat_Z, ai_mat_X;

endif;

                        /* CONSTRUCT INDICATOR VARIABLE FOR j=J */

d_ij    = zeros(N,1);

for jrep (0,capJ-1,1);
    d_ij = d_ij~(y .eq jrep);
endfor;

d_ij = d_ij[.,2:capJ+1];
phat = meanc(d_ij);

                        /* ESTIMATE ORDERED PROBIT MODEL */

if capJ lt 3;
    ?;"ERROR: too few observed outcomes for ordered probit estimation - minimum # is:";;capJ;
endif;

if rows(stopb) eq 1;

    if no_con eq 1;

        startmu1    = meanc(d_ij);
        startmu     = startmu1[1];

        for startrep (2,capJ-1,1);
            mu_temp = ((startmu[startrep-1] + startmu1[startrep]));
            startmu  = startmu|mu_temp;
        endfor;


    elseif no_con eq 0;

        startmu1    = meanc(d_ij);
        startmu     = cdfni(startmu1[2]+startmu1[1]);

        for startrep (3,capJ-1,1);
            mark    = startmu1[startrep] + cdfn(startmu[rows(startmu)]);
            startmu = startmu|cdfni(mark);
        endfor;

    endif;

    startmu  = cdfn(startmu); 
    stopb    = (inv(z'z)*z'y)|startmu;

endif;

cmlset;
let mu          = mu;

if no_con eq 0;

    if capJ gt 3;

        c               = ((eye(capJ-3) .*-1)~zeros(capJ-3,1)) + (zeros(capJ-3,1)~eye(capJ-3));
        _cml_c          = zeros(capJ-3,cols(z))~c;
        _cml_d          = zeros(rows(_cml_c),1);

    endif;

    _cml_Bounds     = ((ones(cols(z),1)*-1000)~(ones(cols(z),1)*1000))|
                                    ((zeros(capJ-2,1)+0.00001)~(ones(capJ-2,1).*10000));
    opnames         = zvars|(mu .*. ones(capJ-2,1));  

elseif no_con eq 1;

    c               = ((eye(capJ-2) .*-1)~zeros(capJ-2,1)) + (zeros(capJ-2,1)~eye(capJ-2));
    _cml_c          = zeros(capJ-2,cols(z))~c;
    _cml_d          = zeros(rows(_cml_c),1);

    opnames         = zvars|(mu .*. ones(capJ-1,1));  

endif;

if tol ne -1;
    _cml_dirTol     = tol;
endif;


_cml_maxIters   = 100;
_cml_parnames   = opnames;  
_cml_covpar     = 2;
_cml_algorithm  = 4;            /* 1 = BFGS, 2=DFP, 3= NEWTON, 4=BHHH */
__title         = "Ordered Probit";
__output        = 0;

et_start    = timeutc;

{ ordpbt,maxfopb,gopb,covopb,retopb } = cmlprt(cml(dset,0,&oprobit,stopb));

betahat = ordpbt[1:kz];
op_b    = betahat;
muhat   = ordpbt[kz+1:rows(ordpbt)]; 
op_mu   = muhat;

if rows(ordpbt) ne (rows(betahat)+rows(muhat));
        "error line 456";stop;
endif;

/* CLUSTER THE STANDARD ERRORS */
            
if cluster_se;

    struct PV pOPROBIT_cluster;
    pOPROBIT_cluster = pvCreate;
    pOPROBIT_cluster = pvPack(pOPROBIT_cluster,op_b,"op_b");
    pOPROBIT_cluster = pvPack(pOPROBIT_cluster,op_mu,"op_mu");

    struct DS dOPROBIT_cluster;
    dOPROBIT_cluster = reshape(dsCreate,2,1);
    dOPROBIT_cluster[1].DataMatrix = d_ij;
    dOPROBIT_cluster[2].DataMatrix = z;

    G = gradMT(&OPROBIT_se_proc,pOPROBIT_cluster,dOPROBIT_cluster);
    H = hessMT(&OPROBIT_se_proc,pOPROBIT_cluster,dOPROBIT_cluster);

    {covopb} = _cluster_se(G,-H,idvec);

endif;

if ismiss(covopb);
    
    outer_gopb = gopb*gopb';

    if det(outer_gopb) gt 0;
        covopb = eye(rows(outer_gopb))/outer_gopb;
    else;
        covopb = 1;
        covopb = miss(covopb,1);
    endif;

endif;


et_op       = timeutc;
et_op       = (et_op - et_start) / 3600;        @ estimation in hours @ 


@ et_probit, et_iop, et_iop_REX, et_iop_REZ, et_iop_RE, et_iopc;@

if ismiss(ordpbt) eq 1;
        ordpbt  = ones(rows(stopb),1).*-999;
        opbse   = ordpbt;
        topb    = ordpbt;
        maxfopb = -999;
else;
        opbse   = sqrt(diag(covopb));
        if rows(opbse) eq 1;
                opbse = opbse .* ones(rows(stopb),1);
        endif;
        opbse   = missrv(opbse,10000);
        topb    = abs(ordpbt ./ opbse);
        maxfopb = maxfopb*N;
endif;

if retopb eq 0;
        let retopb = normal convergence;
elseif retopb eq 1;
        let retopb = forced exit;
elseif retopb eq 2;
        let retopb = max iters exceeded;
elseif retopb eq 3;
        let retopb = function failed;
elseif retopb eq 4;
        let retopb = gradient failed;
elseif retopb eq 5;
        let retopb = Hessian failed;
elseif retopb eq 6;
        let retopb = line search failed;
elseif retopb eq 7;
        let retopb = bad starting values;
elseif retopb eq 8;
        let retopb = error with gradient;
elseif retopb eq 9;
        let retopb = error with constraints;
elseif retopb eq 10;
        let retopb = secant update failed;
elseif retopb eq 11;
        let retopb = max time exceeded;
elseif retopb eq 12;
        let retopb = error with weights;
elseif retopb eq 13;
        let retopb = quadratic program failed;
elseif retopb eq 20;
        let retopb = Hessian failed to invert;
elseif retopb eq 34;
        let retopb = couldn't open data set;
else;
        let retopb = unknown;
endif;


                        /* CONSTRUCT ORDERED PROBIT PROBABLITIES */

zbetahat = z*betahat;

if no_con eq 0;

    p_ij    = 1-(cdfn(zbetahat));
    p_ij    = p_ij~(cdfn(muhat[1]-zbetahat) - cdfn(-zbetahat));
    jrep2= 2;

    for jrep2 (2,capJ-2,1);
        p_ij = p_ij~(cdfn(muhat[jrep2]-zbetahat) -
                            cdfn(muhat[jrep2-1]-zbetahat));
    endfor;

    pordp = p_ij~(1 - cdfn(muhat[capJ-2]-zbetahat));

elseif no_con eq 1;

    p_ij	= cdfn(muhat[1]-zbetahat);

    jrep2= 2;
    do while jrep2 le capJ-1;
        p_ij = p_ij~(cdfn(muhat[jrep2]-zbetahat) -
                        cdfn(muhat[jrep2-1]-zbetahat));
        jrep2 = jrep2 + 1;
    endo;

    pordp = p_ij~(1 - cdfn(muhat[capJ-1]-zbetahat));

endif;

check = meanc(sumc(pordp'));
if check gt 1.00001 or check lt (1-0.00001);
        errorlog "ORDERED PROBIT PROBABILITIES DON'T SUM TO 1: AVERAGE PROB IS";check;stop;
endif;

/* CALL ME PROCEDURE AND CALCULATE INFORMATION CRITERIA */

V_op = covopb;

AICop   = (-2*maxfopb) + rows(ordpbt);  
BICop   = (-2*maxfopb) + (ln(N)*rows(ordpbt));  
CAICop  = (-2*maxfopb) + ((1+ln(N))*rows(ordpbt));  

let me_model = ordered;

{me_op, me_opse, me0_op, me0se_op, meWop, meWopse, me_cond_op, me_cond_op_se, popxbar, pop_se} = mes(V_op,ordpbt,capJ,me_model,meanc(z));


if mtype eq 1;
    goto finish;
endif;    


if mtype eq 3 or mtype eq 11;
 
                        /* ESTIMATE GENERALISED ORDERED PROBIT MODEL */

    if rows(stgop) eq 1;

        if no_con eq 1;

            if gop_flex eq 0;

                if minc(op_mu[2:rows(op_mu)]) gt 0;
                    stgop   = op_b|op_mu[1]|ln(op_mu[2:rows(op_mu)])|zeros(cols(w)-1,1);
                else;
                    stgop   = op_b|op_mu|zeros(cols(w)-1,1);
                endif;    
                  
            elseif gop_flex eq 1;

                start_mu    = op_mu[1]|(zeros(cols(w)-1,1)-0);

                if minc(op_mu[2:rows(op_mu)]) gt 0;

                    for j (2,capJ-1,1);

                        start_mu = start_mu|ln(op_mu[j])|(zeros(cols(w)-1,1)-0);            
    
                    endfor;

                else;

                    for j (2,capJ-1,1);

                        start_mu = start_mu|(op_mu[j] ./10)|zeros(cols(w)-1,1);            
    
                    endfor;

                endif;

                stgop   = op_b|start_mu;

            endif;

        elseif no_con eq 0;
   
            if gop_flex eq 0;
     
                startmu  = cdfn(startmu); 
                stopb    = (inv(w'w)*w'y)|startmu;
                stgop   = op_b|ln(op_mu)|zeros(cols(w)-1,1);

            elseif gop_flex eq 1;

                start_mu    = op_mu[1]|zeros(cols(w)-1,1);

                if minc(op_mu[2:rows(op_mu)]) gt 0;

                    for j (2,capJ-2,1);

                        start_mu = start_mu|ln(op_mu[j])|zeros(cols(w)-1,1);            
    
                    endfor;

                else;

                    for j (2,capJ-2,1);

                        start_mu = start_mu|(op_mu[j] ./10)|zeros(cols(w)-1,1);            
    
                    endfor;

                endif;

                stgop   = op_b|start_mu;

            endif;

        endif;
        
    endif;

    cmlset;

    if no_con eq 0;

        if gop_flex eq 0;

            if capJ gt 3;
                c               = ((eye(capJ-3) .*-1)~zeros(capJ-3,1)) + (zeros(capJ-3,1)~eye(capJ-3));
                _cml_c          = zeros(capJ-3,cols(z))~c~zeros(capJ-3,cols(w)-1);
                _cml_d          = zeros(rows(_cml_c),1);
            endif;

            gopnames         = zvars|("theta" .*. ones(capJ-2,1))|wvars[2:rows(wvars)];  

        elseif gop_flex eq 1;

            gopnames         = zvars|(ones(capJ-2,1) .*. wvars );

        endif;

    elseif no_con eq 1;

        if gop_flex eq 0;

            gopnames         = zvars|("theta" .*. ones(capJ-1,1))|wvars[2:rows(wvars)];

        elseif gop_flex eq 1;

            gopnames         = zvars|(ones(capJ-1,1) .*. wvars );

        endif;

    endif;

    _cml_maxIters   = 100;
    __output        = 1;
    _cml_dirTol     = 0.0001;
    _cml_parnames   = gopnames;  
    _cml_covpar     = 2;
    _cml_algorithm  = 3;            /* 1 = BFGS, 2=DFP, 3= NEWTON, 4=BHHH */
    __title         = "Generalised Ordered Probit";

    ts = hsec;      @ set timer for ML estimation @


    { gop,maxfgop,ggop,V_gop,retgop } = cmlprt(cml(dset,0,&gopMLE,stgop)); 

if ismiss(V_gop);
    
    outer_ggop = ggop*ggop';

    if det(outer_ggop) gt 0;
        V_gop = eye(rows(outer_ggop))/outer_ggop;
    else;
        V_gop = 1;
        V_gop = miss(V_gop,1);
    endif;

endif;

    gop_et = hsec-ts;

    gop_et = gop_et / 100;    @ time in seconds @
    gop_et = gop_et / 60;     @ time in minutes @


    if ismiss(gop) eq 1;

        gop     = ones(rows(stgop),1).*-999;
        gopse   = gop;
        tgop    = gop;
        maxfgop = -999;
        me_gop  = -999;
        megopse = -999;
        pgop    = -999;
        let retgop  = convergence problems;
        gop_et      = -999;
          
        clear AICgop, BICgop, CAICgop;

    else;

        gopse   = sqrt(diag(V_gop));
        if rows(gopse) eq 1;
            gopse = gopse .* ones(rows(stgop),1);
        endif;
        gopse   = missrv(gopse,10000);
        tgop    = abs(gop ./ gopse);
        maxfgop = maxfgop*n;

    endif;


    /* INFORMATION CRITERIA */

    AICgop   = (-2*maxfgop) + rows(gop);  
    BICgop   = (-2*maxfgop) + (ln(n)*rows(gop));  
    CAICgop  = (-2*maxfgop) + ((1+ln(n))*rows(gop));  


    if retgop eq 0;
        let retgop = normal convergence;
    else;
        let retgop = abnormal convergence;
    endif;


                        /* CONSTRUCT GENERALISED ORDERED PROBIT PROBABLITIES */

    gama        = gop[1:kz];

    if gop_flex eq 0;
    
        if no_con eq 0;
 
            gop_theta   = gop[kz+1:kz+capJ-2];   
            gop_delta   = gop[kz+capJ-2+1:rows(gop)];

        elseif no_con eq 1;

            gop_theta   = gop[kz+1:kz+capJ-1];   
            gop_delta   = gop[kz+capJ-1+1:rows(gop)];

        endif;

        mu_ij   = _mu_ij(gop_theta|gop_delta,w,capJ);  
    

    elseif gop_flex eq 1;

        mu_ij   = _mu_ij(gop[kz+1:rows(gop)],w,capJ);  

    endif;


    /* DETERMINISTIC PART & PROBABILITIES */

    zgama = z*gama;

    if no_con eq 0;

        p_ij        = 1-(cdfn(zgama));
        p_ij        = p_ij~(cdfn(mu_ij[.,1]-zgama) - cdfn(-zgama));

        for jrep2 (2,capJ-2,1);
            p_ij = p_ij~(cdfn(mu_ij[.,jrep2]-zgama) -
                            cdfn(mu_ij[.,jrep2-1]-zgama));
        endfor;

        pgop = p_ij~(1 - cdfn(mu_ij[.,capJ-2]-zgama));

    elseif no_con eq 1;

        p_ij	= cdfn(mu_ij[.,1]-zgama);

        for jrep2 (2,capJ-1,1);
	        p_ij = p_ij~(cdfn(mu_ij[.,jrep2]-zgama) -
                        cdfn(mu_ij[.,jrep2-1]-zgama));
        endfor;

        pgop = p_ij~(1 - cdfn(mu_ij[.,capJ-1]-zgama));

    endif;

    check = meanc(sumc(pgop'));
    if check gt 1.00001 or check lt (1-0.00001);
        errorlog "GENERALISED ORDERED PROBIT PROBABILITIES DON'T SUM TO 1: AVERAGE PROB IS";check;stop;
    endif;


    /* USE GENERIC METHOD FOR MARGINAL EFFECTS */
 
    let me_model = GOP;

    {me_gop, megopse, pgopxbar, pgop_se} = mes(V_gop,gop,capJ,me_model,av_wx);

endif;


inflated:

/* ESTIMATE ZERO INFLATED ORDERED PROBIT MODEL */

/* get start values by estimating independent probit and ordered probits */

/* ESTIMATE OLS STARTING VALUES FOR PROBIT */

if rows(stpbt) eq 1;
    stpbt  = invpd(x'x)*x'(y .eq index);
endif;
        
/* ESTIMATE USUAL PROBIT MODEL */

cmlset;
if tol ne -1;
    _cml_dirTol     = tol;
endif;
_cml_maxIters       = 30;
_cml_parnames       = xvars; 
_cml_covpar         = 1;
__title                         = "Cross Section Probit: Start Values";

__output            = 0;

et_start    = timeutc;

{ gamp,maxfp,gp,gampcov,retprobit } = cmlprt(cml(dset,0,&probml,stpbt));
//{ gamp,maxfp,gp,gampcov,retprobit } = cml(dset,0,&probml,stpbt);

if ismiss(gampcov);
    
    outer_gp = gp*gp';

    if det(outer_gp) gt 0;
        gampcov = eye(rows(outer_gp))/outer_gp;
    else;
        gampcov = 1;
        gampcov = miss(gampcov,1);
    endif;

endif;

et_probit   = timeutc;
et_probit   = (et_probit - et_start) / 3600;        @ estimation in hours @ 

if ismiss(gamp) eq 1;
        gamp        = ones(rows(stpbt),1).*-999;
        probitse    = gamp;
        tprobit     = gamp;
        maxfprobit  = -999;
else;
        probitse   = sqrt(diag(gampcov));
        if rows(probitse) eq 1;
                probitse = probitse .* ones(rows(stpbt),1);
        endif;
        probitse   = missrv(probitse,10000);
        tprobit    = abs(gamp ./ probitse);
        maxfprobit = maxfp*N;
endif;

if retprobit eq 0;
        let retprobit = normal convergence;
elseif retprobit eq 1;
        let retprobit = forced exit;
elseif retprobit eq 2;
        let retprobit = max iters exceeded;
elseif retprobit eq 3;
        let retprobit = function failed;
elseif retprobit eq 4;
        let retprobit = gradient failed;
elseif retprobit eq 5;
        let retprobit = Hessian failed;
elseif retprobit eq 6;
        let retprobit = line search failed;
elseif retprobit eq 7;
        let retprobit = bad starting values;
elseif retprobit eq 8;
        let retprobit = error with gradient;
elseif retprobit eq 9;
        let retprobit = error with constraints;
elseif retprobit eq 10;
        let retprobit = secant update failed;
elseif retprobit eq 11;
        let retprobit = max time exceeded;
elseif retprobit eq 12;
        let retprobit = error with weights;
elseif retprobit eq 13;
        let retprobit = quadratic program failed;
elseif retprobit eq 20;
        let retprobit = Hessian failed to invert;
elseif retprobit eq 34;
        let retprobit = couldn't open data set;
else;
        let retprobit = unknown;
endif;

                        /* CONSTRUCT PROBIT PROBABLITIES */

pprobit = cdfn(x*gamp);

/* CALL ME PROCEDURE AND CALCULATE INFORMATION CRITERIA */

V_probit = gampcov;

AICprobit   = (-2*maxfprobit) + rows(gamp);  
BICprobit   = (-2*maxfprobit) + (ln(N)*rows(gamp));  
CAICprobit  = (-2*maxfprobit) + ((1+ln(N))*rows(gamp));  

let me_model = probit;

{me_probit, me_probitse, me0_pbt, me0se_pbt, meWpbt, meWpbtse, me_cond_probit, me_cond_probit_se, pprobitxbar, pprobit_se} = mes(V_probit,gamp,capJ,me_model,meanc(x));


if rows(stiop) eq 1;    
    stiop = (-gamp)|ordpbt;
endif;


/* INFLATED ORDERED PROBIT */

cmlset;

if no_con eq 0;
	
	if capJ gt 3;
		c               = ((eye(capJ-3) .*-1)~zeros(capJ-3,1)) + (zeros(capJ-3,1)~eye(capJ-3));
		_cml_c          = zeros(capJ-3,cols(z)+cols(x))~c;
		_cml_d          = zeros(rows(_cml_c),1);
	endif;

	_cml_bounds     = ((ones(cols(z)+cols(x),1) .* -10000)~(ones(cols(z)+cols(x),1) .* 10000))|
                            ((zeros(capJ-2,1)+0.00001)~(ones(capJ-2,1) .* 10000));
	_cml_parnames   = xvars|zvars|(mu .*. ones(capJ-2,1));  

elseif no_con eq 1;

	if capJ gt 3;
		c               = ((eye(capJ-2) .*-1)~zeros(capJ-2,1)) + (zeros(capJ-2,1)~eye(capJ-2));
		_cml_c          = zeros(capJ-2,cols(z)+cols(x))~c;
		_cml_d          = zeros(rows(_cml_c),1);
	endif;

		_cml_parnames   = xvars|zvars|(mu .*. ones(capJ-1,1));  

endif;


if tol ne -1;
    _cml_dirTol     = tol;
endif;

_cml_maxIters   = 250;
_cml_covpar     = 1;
_cml_algorithm  = 3;            /* 1 = BFGS, 2=DFP, 3= NEWTON, 4=BHHH */
__title                 = "Inflated Ordered Probit";
__output        = 0;  

et_start    = timeutc;

{ iop,maxfiop,g_iop,coviop,retiop } = cmlprt(cml(dset,0,&iopb_ml,stiop));
//{ iop,maxfiop,g_iop,coviop,retiop } = cml(dset,0,&iopb_ml,stiop);

?;sqrt(diag(coviop));

beta    = iop[1:kx];
gama    = iop[kx+1:kx+kz];     
muiop   = iop[kx+kz+1:rows(iop)]; 
op_b    = beta;

/* CLUSTER THE STANDARD ERRORS */
            
if cluster_se;

    struct PV pIOP_cluster;
    pIOP_cluster = pvCreate;
    pIOP_cluster = pvPack(pIOP_cluster,gama,"gama");    
    pIOP_cluster = pvPack(pIOP_cluster,op_b,"op_b");
    pIOP_cluster = pvPack(pIOP_cluster,muiop,"muiop");

    struct DS dIOP_cluster;
    dIOP_cluster = reshape(dsCreate,3,1);
    dIOP_cluster[1].DataMatrix = d_ij;
    dIOP_cluster[2].DataMatrix = x;
    dIOP_cluster[3].DataMatrix = z;

    G = gradMT(&IOP_se_proc,pIOP_cluster,dIOP_cluster);
    H = hessMT(&IOP_se_proc,pIOP_cluster,dIOP_cluster);

    {coviop} = _cluster_se(G,-H,idvec);

endif;

//?;sqrt(diag(coviop));stop;


if ismiss(coviop);
    
    outer_giop = giop*giop';

    if det(outer_giop) gt 0;
        coviop = eye(rows(outer_giop))/outer_giop;
    else;
        coviop = 1;
        coviop = miss(coviop,1);
    endif;

endif;


et_iop      = timeutc;
et_iop      = (et_iop - et_start) / 3600;        @ estimation in hours @ 

if ismiss(iop) eq 1;
    iop    = ones(rows(stiop),1).*-999;
    iopse  = iop;
    tiop   = iop;
    maxfiop= -999;
else;
    iopse  = sqrt(diag(coviop));
    iopse  = missrv(iopse,10000);
    if rows(iopse) eq 1;
            iopse = iopse .* ones(rows(stiop),1);
    endif;
    tiop   = abs(iop ./ iopse);
    maxfiop= maxfiop*N;
endif;


if retiop eq 0;
        let retiop = normal convergence;
elseif retiop eq 1;
        let retiop = forced exit;
elseif retiop eq 2;
        let retiop = max iters exceeded;
elseif retiop eq 3;
        let retiop = function failed;
elseif retiop eq 4;
        let retiop = gradient failed;
elseif retiop eq 5;
        let retiop = Hessian failed;
elseif retiop eq 6;
        let retiop = line search failed;
elseif retiop eq 7;
        let retiop = bad starting values;
elseif retiop eq 8;
        let retiop = error with gradient;
elseif retiop eq 9;
        let retiop = error with constraints;
elseif retiop eq 10;
        let retiop = secant update failed;
elseif retiop eq 11;
        let retiop = max time exceeded;
elseif retiop eq 12;
        let retiop = error with weights;
elseif retiop eq 13;
        let retiop = quadratic program failed;
elseif retiop eq 20;
        let retiop = Hessian failed to invert;
elseif retiop eq 34;
        let retiop = couldn't open data set;
else;
        let retiop = unknown;
endif;


                        /* CONSTRUCT INFLATED ORDERED PROBIT PROBABLITIES */

beta    = iop[1:kx];
gama    = iop[kx+1:kx+kz];     
muiop   = iop[kx+kz+1:rows(iop)]; 

if rows(iop) ne (rows(beta)+rows(muiop)+rows(gama));
   "error line 630";stop;
endif;

/* DETERMINISTIC PARTs & PROBABILITIES */

xbeta = x*beta;
zgama = z*gama; 

piop   = 1-(cdfn(zgama));
piop   = piop~(cdfn(muiop[1]-zgama) - cdfn(-zgama));

if capJ gt 3;

    for jrep2 (2,capJ-2,1);
            piop = piop~(cdfn(muiop[jrep2]-zgama) -
                        cdfn(muiop[jrep2-1]-zgama));
    endfor;

endif;

piop        = piop~(1 - cdfn(muiop[capJ-2]-zgama));
p_aug       = (1-cdfn(xbeta)) + (piop[.,index+1] .* (cdfn(xbeta)));

p_aug_pred0 = (1-cdfn(xbeta)) .ge (piop[.,index+1] .* (cdfn(xbeta)));
 
piop    = piop .* ((cdfn(xbeta)) .*. ones(1,capJ));
piop[.,index+1] = p_aug;
p_aug_pred  = (index+1) .eq maxindc(piop'); 

p_aug_pred0 = selif(p_aug_pred~p_aug_pred0,p_aug_pred);
p_aug_pred0 = meanc(prodc(p_aug_pred0'));

if meanc(sumc(piop')) gt 1.0001 or meanc(sumc(piop')) lt .9999;
            errorlog "ERROR IN DEFINING INFLATED ORDERED PROBIT PROBABILITIES; PROGRAM TERMINATED";
                        "mean probablitiy =";;meanc(sumc(piop'));stop;
endif;

?;
"           ****Split of Probabilities for Augmented Outcome****";?;
"   Av Total Prob; Of which from 1st stage; Total % Predicted; % of Total from 1st Stage";
?;
p0_iop = meanc(piop[.,index+1])~meanc(1-cdfn(xbeta))~meanc(p_aug_pred)~p_aug_pred0;
?;
p0_iop;
?;

/* CALL ME PROCEDURE AND CALCULATE INFORMATION CRITERIA */

V_iop   = coviop;

AICiop  = (-2*maxfiop) + rows(iop);  
BICiop  = (-2*maxfiop) + (ln(N)*rows(iop));  
CAICiop = (-2*maxfiop) + ((1+ln(N))*rows(iop));  

let me_model = op_infl;

{me_iop,me_iopse,me0_iop, me0se_iop, meWiop, meWiopse, me_cond_iop, me_cond_iop_se, piopxbar, piop_se} = mes(V_iop,iop,capJ,me_model,meanc(xzall));


if mtype eq 2;
    goto finish;
endif;

if mtype eq 8;
    goto correlated;
endif;    


if mtype eq 3 or mtype eq 11;

    /* ESTIMATE GENERALISED INFLATED ORDERED PROBIT */

    if rows(stgiop) eq 1;

        b_ols   = inv(w'w)*w'y; 

        if minc(muiop) gt 0;
            st_mu = ln(muiop);
        else;
            st_mu = muiop;
        endif;
    
        stgiop = beta|gama|st_mu|b_ols[2:rows(b_ols)];    

    endif;

    cmlset;

    if capJ gt 3;
        c               = ((eye(capJ-3) .*-1)~zeros(capJ-3,1)) + (zeros(capJ-3,1)~eye(capJ-3));
        _cml_c          = zeros(capJ-3,cols(z)+cols(x))~c~(zeros(capJ-3,cols(w)-1));
        _cml_d          = zeros(rows(_cml_c),1);
    endif;

    let theta   = theta;
    theta       = theta .*. ones(capJ-2,1);

    _cml_parnames   = xvars|zvars|theta|wvars[2:rows(wvars)];  
    if tol ne -1;
        _cml_dirTol     = tol;
    endif;
    _cml_maxIters   = 250;
    __output        = 1;  
    _cml_covpar     = 1;
    _cml_algorithm  = 3;            /* 1 = BFGS, 2=DFP, 3= NEWTON, 4=BHHH */
    __title                 = "Generalised Inflated Ordered Probit";

    et_start    = timeutc;

    { giop,maxfgiop,ggiop,covgiop,retgiop } = cmlprt(cml(dset,0,&giopb_ml,stgiop));

if ismiss(covgiop);
    
    outer_ggiop = ggiop*ggiop';

    if det(outer_ggiop) gt 0;
        covgiop = eye(rows(outer_ggiop))/outer_ggiop;
    else;
        covgiop = 1;
        covgiop = miss(covgiop,1);
    endif;

endif;

    et_giop      = timeutc;
    et_giop      = (et_giop - et_start) / 3600;        @ estimation in hours @ 

    if ismiss(giop) eq 1;

        giop    = ones(rows(stgiop),1).*-999;
        giopse  = iop;
        tgiop   = iop;
        maxfgiop= -999;

    else;

        giopse  = sqrt(diag(covgiop));
        giopse  = missrv(giopse,10000);

        if rows(giopse) eq 1;
            giopse = giopse .* ones(rows(stgiop),1);
        endif;

        tgiop   = abs(giop ./ giopse);
        maxfgiop= maxfgiop*N;
    
    endif;

    if retgiop eq 0;
        let retgiop = normal convergence;
    else;
        let retgiop = convergence problems;
    endif;

                        /* CONSTRUCT INFLATED ORDERED PROBIT PROBABLITIES */

    beta        = giop[1:kx];
    gama        = giop[kx+1:kx+kz];
    mu_param    = giop[kx+kz+1:rows(giop)];
    mugiop      = _mu_ij(mu_param,w,capJ);     

    if rows(giop) ne (rows(beta)+rows(mu_param)+rows(gama));
        "error - GIOP probs post estimations";
    endif;

    /* DETERMINISTIC PARTs & PROBABILITIES */

    xbeta = x*beta;
    zgama = z*gama; 

    pgiop   = 1-(cdfn(zgama));
    pgiop   = pgiop~(cdfn(mugiop[.,1]-zgama) - cdfn(-zgama));

    if capJ gt 3;

        for jrep2 (2,capJ-2,1);
            pgiop = pgiop~(cdfn(mugiop[.,jrep2]-zgama) -
                        cdfn(mugiop[.,jrep2-1]-zgama));
        endfor;

    endif;

    pgiop   = pgiop~(1 - cdfn(mugiop[.,capJ-2]-zgama));
    p_aug   = (1-cdfn(xbeta)) + (pgiop[.,index+1] .* (cdfn(xbeta))); 

    p_aug_pred0 = (1-cdfn(xbeta)) .ge (pgiop[.,index+1] .* (cdfn(xbeta)));

    pgiop   = pgiop .* ((cdfn(xbeta)) .*. ones(1,capJ));

    pgiop[.,index+1] = p_aug;
    p_aug_pred  = (index+1) .eq maxindc(pgiop'); 

    p_aug_pred0 = selif(p_aug_pred~p_aug_pred0,p_aug_pred);
    p_aug_pred0 = meanc(prodc(p_aug_pred0'));



    if meanc(sumc(pgiop')) gt 1.0001 or meanc(sumc(pgiop')) lt .9999;
            errorlog "ERROR IN DEFINING INFLATED ORDERED PROBIT PROBABILITIES; PROGRAM TERMINATED";
                        "mean probablitiy =";;meanc(sumc(pgiop'));stop;
    endif;

    ?;
    "***** SAMPLE PROPORTIONS *****";?;
    phat';?;
    "***** AVERAGE PREDICTED PROBABILITIES (GENERALISED ZERO INFLATED ORDERED PROBIT) *****";?;
    meanc(pGIOP)';
    ?;


    ?;
    "           ****Split of Probabilities for Augmented Outcome****";?;
    "   Av Total Prob; Of which from 1st stage; Total % Predicted; % of Total from 1st Stage";
    ?;
    p0_giop = meanc(piop[.,index+1])~meanc(1-cdfn(xbeta))~meanc(p_aug_pred)~p_aug_pred0;
    ?;
    p0_giop;
    ?;

    /* CALL ME PROCEDURE AND CALCULATE INFORMATION CRITERIA */

    V_giop   = covgiop;

    AICgiop  = (-2*maxfgiop) + rows(giop);  
    BICgiop  = (-2*maxfgiop) + (ln(N)*rows(giop));  
    CAICgiop = (-2*maxfgiop) + ((1+ln(N))*rows(giop));  

    let me_model = gop_infl;

    {me_giop, me_giopse, me0_giop, me0se_giop, meWgiop, meWgiopse, me_cond_giop, me_cond_giop_se, pgiopxbar, pgiop_se} = mes(V_giop, giop, capJ, me_model, meanc(xzall));

endif;


if mtype eq 3;
    goto finish;
endif;


        /* ESTIMATE INFLATED ORDERED PROBIT MODEL WITH ONE RANDOM EFFECT IN THE Z'S */

xn = -4.4688738939305818~
	        4.4688738939305818~
		    -3.8694479048601227~
		    3.8694479048601227~
		    -3.1769991619799560~
		    3.1769991619799560~
		    -2.5462021578474814~
		    2.5462021578474814~
		    -1.951787990916254~
		    1.951787990916254~
		    -1.3802585391988808~
		    1.3802585391988808~
		    -0.8229514491446559~
		    0.8229514491446559~
		    -0.2734810461381525~
		    0.2734810461381525;	


wn = 0.0000000002654807~
		    0.0000000002654807~
		    0.0000002320980845~
		    0.0000002320980845~
		    0.0000271186009254~
		    0.0000271186009254~
		    0.0009322840086242~
		    0.0009322840086242~
		    0.0128803115355100~
		    0.0128803115355100~
		    0.0838100413989858~
		    0.0838100413989858~
		    0.2806474585285337~
		    0.2806474585285337~
		    0.5079294790166137~
		    0.5079294790166137;

if mtype eq 5;
    goto REX;
endif;    


RE = 1;

if rows(stiopREZ) eq 1;    

/*
    prob_all = 0~0;

    for start_rep (0.1,0.9,0.01);

        theta = ((2*start_rep)/(1-start_rep))^0.5;

        prob    = 0;

        r = 1; 
        do until r > cols(xn);

            /* DETERMINISTIC PARTs & PROBABILITIES */

            if RE eq 1;

                xbeta = (x*beta);
                zgama = (z*gama) + (xn[r] .* theta);

            elseif RE eq 2;

                xbeta = (x*beta) + (xn[r] .* theta);
		        zgama = (z*gama);
                
            endif;

            p_ij        = 1-(cdfn(zgama));
            p_ij        = p_ij~(cdfn(muiop[1]-zgama) - cdfn(-zgama));

            if capJ gt 3;

                for jrep2 (2,capJ-2,1);
                        p_ij = p_ij~(cdfn(muiop[jrep2]-zgama) -
                                cdfn(muiop[jrep2-1]-zgama));
                endfor;

            endif;

            p_ij    = p_ij~(1 - cdfn(muiop[capJ-2]-zgama));
            p_aug   = (1-cdfn(xbeta)) + (p_ij[.,index+1] .* (cdfn(xbeta))); 
            p_ij    = p_ij .* ((cdfn(xbeta)) .*. ones(1,capJ));
            p_ij[.,index+1] = p_aug;

        
            /* PRODUCT OVER INDIVIDUALS */

            prob_temp   = (sumc((d_ij .* p_ij)'));
            p_vec       = prodc(selif(prob_temp,idvec .eq 1));

            for i_rep (2,maxc(id),1);
                sel     = idvec .eq i_rep;
                p_vec   = p_vec|prodc(selif(prob_temp,sel));
            endfor;

            prob = prob + (wn[r] .* p_vec);

            r = r+1 ; 

        endo;

        prob        = sumc(ln(prob));
        prob_all    = prob_all|(prob~start_rep);

    endfor;

    prob_all    = prob_all[2:rows(prob_all),.];
    prob_all    = rev(sortc(prob_all,1));



    prob_all    = prob_all[1,2];

    stiopREZ     = iop|prob_all;

*/

    stiopREZ     = iop|0.2;

endif;


cmlset;

if capJ gt 3;
    c           = ((eye(capJ-3) .*-1)~zeros(capJ-3,1)) + (zeros(capJ-3,1)~eye(capJ-3));
    _cml_c      = zeros(capJ-3,cols(z)+cols(x))~c~zeros(capJ-3,1);
    _cml_d      = zeros(rows(_cml_c),1);
endif;


if tol ne -1;
    _cml_dirTol     = tol;
endif;

_cml_maxIters   = 20;
__output        = 1;  
_cml_covpar     = 1;
_cml_algorithm  = 1;            /* 1 = BFGS, 2=DFP, 3= NEWTON, 4=BHHH */
__title                 = "Inflated Ordered Probit with RE in Z only: Quadrature";
_cml_parnames   = xvars|zvars|(mu .*. ones(capJ-2,1))|"panel_rho_Z";  
_cml_bounds     = ((ones(cols(z)+cols(x),1) .* -10000)~(ones(cols(z)+cols(x),1) .* 10000))|
                  ((zeros(capJ-2,1)+0.00001)~(ones(capJ-2,1) .* 10000))|
                  (0~.9999);

et_start    = timeutc;

if skip_RE ge 1;

    iopREZ      = stiopREZ;
    beta        = iopREZ[1:kx];
    gama        = iopREZ[kx+1:kx+kz];     
    muiop       = iopREZ[kx+kz+1:rows(iopREZ)-1]; 
    panel_r_z   = iopREZ[rows(iopREZ)]; 
    sig_z       = sqrt(panel_r_z / (1 - panel_r_z));
       
    goto skip_REZ;

endif;

{ iopREZ,maxfiopREZ,giopREZ,coviopREZ,retiopREZ } = cmlprt(cml(dset,0,&iopb_ml_quad,stiopREZ));

if ismiss(coviopREZ);
    
    outer_giopREZ = giopREZ*giopREZ';

    if det(outer_giopREZ) gt 0;
        coviopREZ = eye(rows(outer_giopREZ))/outer_giopREZ;
    else;
        coviopREZ = 1;
        coviopREZ = miss(coviopREZ,1);
    endif;

endif;

et_iop_REZ   = timeutc;
et_iop_REZ   = (et_iop_REZ - et_start) / 3600;        @ estimation in hours @ 


if ismiss(iopREZ) eq 1;
    iopREZ       = ones(rows(stiopREZ),1).*-999;
    iopREZse     = iopREZ;
    tiopREZ      = iopREZ;
    maxfiopREZ   = -999;
else;
    iopREZse  = sqrt(diag(coviopREZ));
    iopREZse  = sqrt(diag(coviopREZ));
    iopREZse  = missrv(iopREZse,10000);
    if rows(iopREZse) eq 1;
        iopREZse = iopREZse .* ones(rows(stiopREZ),1);
    endif;
    tiopREZ     = abs(iopREZ ./ iopREZse);
    maxfiopREZ  = maxfiopREZ*n;
endif;


if retiopREZ eq 0;
    let retiopREZ = normal convergence;
elseif retiopREZ eq 1;
    let retiopREZ = forced exit;
elseif retiopREZ eq 2;
    let retiopREZ = max iters exceeded;
elseif retiopREZ eq 3;
    let retiopREZ = function failed;
elseif retiopREZ eq 4;
    let retiopREZ = gradient failed;
elseif retiopREZ eq 5;
    let retiopREZ = Hessian failed;
elseif retiopREZ eq 6;
    let retiopREZ = line search failed;
elseif retiopREZ eq 7;
        let retiopREZ = bad starting values;
elseif retiopREZ eq 8;
        let retiopREZ = error with gradient;
elseif retiopREZ eq 9;
        let retiopREZ = error with constraints;
elseif retiopREZ eq 10;
        let retiopREZ = secant update failed;
elseif retiopREZ eq 11;
        let retiopREZ = max time exceeded;
elseif retiopREZ eq 12;
        let retiopREZ = error with weights;
elseif retiopREZ eq 13;
        let retiopREZ = quadratic program failed;
elseif retiopREZ eq 20;
        let retiopREZ = Hessian failed to invert;
elseif retiopREZ eq 34;
        let retiopREZ = couldn't open data set;
else;
        let retiopREZ = unknown;
endif;


                        /* CONSTRUCT INFLATED ORDERED PROBIT PROBABLITIES */

beta        = iopREZ[1:kx];
gama        = iopREZ[kx+1:kx+kz];     
muiop       = iopREZ[kx+kz+1:rows(iopREZ)-1]; 
panel_r_z   = iopREZ[rows(iopREZ)]; 
sig_z       = sqrt(panel_r_z / (1 - panel_r_z));

if rows(iopREZ) ne (rows(beta)+rows(muiop)+rows(gama)+rows(panel_r_z));
   "error line 898";stop;
endif;

/* DETERMINISTIC PARTs & PROBABILITIES */

xbeta = x*beta;
zgama = z*gama; 

piopREZ  = 1-(cdfn(zgama));
piopREZ  = piopREZ~(cdfn(muiop[1]-zgama) - cdfn(-zgama));

if capJ gt 3;

    for jrep2 (2,capJ-2,1);
            piopREZ = piopREZ~(cdfn(muiop[jrep2]-zgama) -
                        cdfn(muiop[jrep2-1]-zgama));
    endfor;

endif;

piopREZ     = piopREZ~(1 - cdfn(muiop[capJ-2]-zgama));
p_aug       = (1-cdfn(xbeta)) + (piopREZ[.,index+1] .* (cdfn(xbeta))); 

p_aug_pred0 = (1-cdfn(xbeta)) .ge (piopREZ[.,index+1] .* (cdfn(xbeta)));

piopREZ     = piopREZ .* ((cdfn(xbeta)) .*. ones(1,capJ));
piopREZ[.,index+1] = p_aug;
p_aug_pred  = (index+1) .eq maxindc(piopREZ'); 

p_aug_pred0 = selif(p_aug_pred~p_aug_pred0,p_aug_pred);
p_aug_pred0 = meanc(prodc(p_aug_pred0'));


if meanc(sumc(piopREZ')) gt 1.0001 or meanc(sumc(piopREZ')) lt .9999;
            errorlog "ERROR IN DEFINING INFLATED ORDERED PROBIT PROBABILITIES; PROGRAM TERMINATED";
                        "mean probablitiy =";;meanc(sumc(piopREZ'));stop;
endif;

?;
"           ****Split of Probabilities for Augmented Outcome****";?;
"   Av Total Prob; Of which from 1st stage; Total % Predicted; % of Total from 1st Stage";
?;
p0_iopREZ = meanc(piopREZ[.,index+1])~meanc(1-cdfn(xbeta))~meanc(p_aug_pred)~p_aug_pred0;
?;
p0_iopREZ;
?;


/* CALL ME PROCEDURE AND CALCULATE INFORMATION CRITERIA */

V_iopREZ     = coviopREZ;
 
AICiopREZ    = (-2*maxfiopREZ) + rows(iopREZ);  
BICiopREZ    = (-2*maxfiopREZ) + (ln(N)*rows(iopREZ));  
CAICiopREZ   = (-2*maxfiopREZ) + ((1+ln(N))*rows(iopREZ));  

let me_model    = iop_REZ;

{me_iopREZ, me_iopREZse, me0_iopREZ, me0se_iopREZ, meWiopREZ, meWiopREZse, me_cond_iopREZ, me_cond_iopREZ_se, piopREZxbar, piopREZ_se} = mes(V_iopREZ, iopREZ, capJ, me_model, meanc(xzall));


if mtype eq 4;
    goto finish;
endif;


skip_REZ:
REX:

        /* ESTIMATE INFLATED ORDERED PROBIT MODEL WITH ONE RANDOM EFFECT IN THE X'S */

RE = 2;

if rows(stiopREX) eq 1;    

/*
    prob_all = 0~0;

    for start_rep (0.1,0.9,0.1);

        theta = ((2*start_rep)/(1-start_rep))^0.5;

        prob    = 0;

        r = 1; 
        do until r > cols(xn);

            /* DETERMINISTIC PARTs & PROBABILITIES */

            if RE eq 1;

                xbeta = (x*beta);
                zgama = (z*gama) + (xn[r] .* theta);

            elseif RE eq 2;

                xbeta = (x*beta) + (xn[r] .* theta);
		        zgama = (z*gama);
                
            endif;

            p_ij        = 1-(cdfn(zgama));
            p_ij        = p_ij~(cdfn(muiop[1]-zgama) - cdfn(-zgama));

            if capJ gt 3;

                for jrep2 (2,capJ-2,1);
                        p_ij = p_ij~(cdfn(muiop[jrep2]-zgama) -
                                cdfn(muiop[jrep2-1]-zgama));
                endfor;

            endif;

            p_ij    = p_ij~(1 - cdfn(muiop[capJ-2]-zgama));
            p_aug   = (1-cdfn(xbeta)) + (p_ij[.,index+1] .* (cdfn(xbeta))); 
            p_ij    = p_ij .* ((cdfn(xbeta)) .*. ones(1,capJ));
            p_ij[.,index+1] = p_aug;

        
            /* PRODUCT OVER INDIVIDUALS */

            prob_temp   = (sumc((d_ij .* p_ij)'));
            p_vec       = prodc(selif(prob_temp,idvec .eq 1));

            for i_rep (2,maxc(id),1);
                sel     = idvec .eq i_rep;
                p_vec   = p_vec|prodc(selif(prob_temp,sel));
            endfor;

            prob = prob + (wn[r] .* p_vec);

            r = r+1 ; 

        endo;

        prob        = sumc(ln(prob+0.00001));
        prob_all    = prob_all|(prob~start_rep);

    endfor;

    prob_all    = prob_all[2:rows(prob_all),.];
    prob_all    = rev(sortc(prob_all,1));

    prob_all    = prob_all[1,2];

    stiopREX     = iop|prob_all;
*/

    stiopREX     = iop|0.2;


endif;


cmlset;

if capJ gt 3;
    c           = ((eye(capJ-3) .*-1)~zeros(capJ-3,1)) + (zeros(capJ-3,1)~eye(capJ-3));
    _cml_c      = zeros(capJ-3,cols(z)+cols(x))~c~zeros(capJ-3,1);
    _cml_d      = zeros(rows(_cml_c),1);
endif;

if tol ne -1;
    _cml_dirTol     = tol;
endif;

_cml_maxIters   = 20;
__output        = 1;  
_cml_covpar     = 1;
_cml_algorithm  = 1;            /* 1 = BFGS, 2=DFP, 3= NEWTON, 4=BHHH */
__title                 = "Inflated Ordered Probit with RE in X only: Quadrature";
_cml_parnames   = xvars|zvars|(mu .*. ones(capJ-2,1))|"panel_rho_X";  
_cml_bounds     = ((ones(cols(X)+cols(z),1) .* -10000)~(ones(cols(X)+cols(z),1) .* 10000))|
                  ((zeros(capJ-2,1)+0.00001)~(ones(capJ-2,1) .* 10000))|
                  (0~.9999);

et_start    = timeutc;

if skip_RE ge 1;

    iopREX = stiopREX;
    beta        = iopREX[1:kx];
    gama        = iopREX[kx+1:kx+kz];     
    muiop       = iopREX[kx+kz+1:rows(iopREX)-1]; 
    panel_r_x   = iopREX[rows(iopREX)]; 
    sig_x       = sqrt(panel_r_x / (1 - panel_r_x));

    goto skip_REX;

endif;


{ iopREX,maxfiopREX,giopREX,coviopREX,retiopREX } = cmlprt(cml(dset,0,&iopb_ml_quad,stiopREX));

if ismiss(coviopREX);
    
    outer_giopREX = giopREX*giopREX';

    if det(outer_giopREX) gt 0;
        coviopREX = eye(rows(outer_giopREX))/outer_giopREX;
    else;
        coviopREX = 1;
        coviopREX = miss(coviopREX,1);
    endif;

endif;

et_iop_REX   = timeutc;
et_iop_REX   = (et_iop_REX - et_start) / 3600;        @ estimation in hours @ 


if ismiss(iopREX) eq 1;
        iopREX       = ones(rows(stiopREX),1).*-999;
        iopREXse     = iopREX;
        tiopREX      = iopREX;
        maxfiopREX   = -999;
else;
        iopREXse  = sqrt(diag(coviopREX));
        iopREXse  = sqrt(diag(coviopREX));
        iopREXse  = missrv(iopREXse,10000);
        if rows(iopREXse) eq 1;
                iopREXse = iopREXse .* ones(rows(stiopREX),1);
        endif;
        tiopREX     = abs(iopREX ./ iopREXse);
        maxfiopREX  = maxfiopREX*n;
endif;


if retiopREX eq 0;
        let retiopREX = normal convergence;
elseif retiopREX eq 1;
        let retiopREX = forced exit;
elseif retiopREX eq 2;
        let retiopREX = max iters exceeded;
elseif retiopREX eq 3;
        let retiopREX = function failed;
elseif retiopREX eq 4;
        let retiopREX = gradient failed;
elseif retiopREX eq 5;
        let retiopREX = Hessian failed;
elseif retiopREX eq 6;
        let retiopREX = line search failed;
elseif retiopREX eq 7;
        let retiopREX = bad starting values;
elseif retiopREX eq 8;
        let retiopREX = error with gradient;
elseif retiopREX eq 9;
        let retiopREX = error with constraints;
elseif retiopREX eq 10;
        let retiopREX = secant update failed;
elseif retiopREX eq 11;
        let retiopREX = max time exceeded;
elseif retiopREX eq 12;
        let retiopREX = error with weights;
elseif retiopREX eq 13;
        let retiopREX = quadratic program failed;
elseif retiopREX eq 20;
        let retiopREX = Hessian failed to invert;
elseif retiopREX eq 34;
        let retiopREX = couldn't open data set;
else;
        let retiopREX = unknown;
endif;


                        /* CONSTRUCT INFLATED ORDERED PROBIT PROBABLITIES */

beta        = iopREX[1:kx];
gama        = iopREX[kx+1:kx+kz];     
muiop       = iopREX[kx+kz+1:rows(iopREX)-1]; 
panel_r_x   = iopREX[rows(iopREX)]; 
sig_x       = sqrt(panel_r_x / (1 - panel_r_x));

if rows(iopREX) ne (rows(beta)+rows(muiop)+rows(gama)+1);
   "error line 1122";stop;
endif;

/* DETERMINISTIC PARTs & PROBABILITIES */

xbeta = x*beta;
zgama = z*gama; 

piopREX  = 1-(cdfn(zgama));
piopREX  = piopREX~(cdfn(muiop[1]-zgama) - cdfn(-zgama));

if capJ gt 3;

    for jrep2 (2,capJ-2,1);
            piopREX = piopREX~(cdfn(muiop[jrep2]-zgama) -
                        cdfn(muiop[jrep2-1]-zgama));
    endfor;

endif;

piopREX     = piopREX~(1 - cdfn(muiop[capJ-2]-zgama));
p_aug       = (1-cdfn(xbeta)) + (piopREX[.,index+1] .* (cdfn(xbeta))); 

p_aug_pred0 = (1-cdfn(xbeta)) .ge (piopREX[.,index+1] .* (cdfn(xbeta)));

piopREX     = piopREX .* ((cdfn(xbeta)) .*. ones(1,capJ));
piopREX[.,index+1] = p_aug;
p_aug_pred  = (index+1) .eq maxindc(piopREX'); 

p_aug_pred0 = selif(p_aug_pred~p_aug_pred0,p_aug_pred);
p_aug_pred0 = meanc(prodc(p_aug_pred0'));


if meanc(sumc(piopREX')) gt 1.0001 or meanc(sumc(piopREX')) lt .9999;
            errorlog "ERROR IN DEFINING INFLATED ORDERED PROBIT PROBABILITIES; PROGRAM TERMINATED";
                        "mean probablitiy =";;meanc(sumc(piopREX'));stop;
endif;

?;
"           ****Split of Probabilities for Augmented Outcome****";?;
"   Av Total Prob; Of which from 1st stage; Total % Predicted; % of Total from 1st Stage";
?;
p0_iopREX = meanc(piopREX[.,index+1])~meanc(1-cdfn(xbeta))~meanc(p_aug_pred)~p_aug_pred0;
?;
p0_iopREX;
?;


/* CALL ME PROCEDURE AND CALCULATE INFORMATION CRITERIA */

V_iopREX     = coviopREX;
 
AICiopREX    = (-2*maxfiopREX) + rows(iopREX);  
BICiopREX    = (-2*maxfiopREX) + (ln(N)*rows(iopREX));  
CAICiopREX   = (-2*maxfiopREX) + ((1+ln(N))*rows(iopREX));  

let me_model    = iop_REX;

{me_iopREX, me_iopREXse, me0_iopREX, me0se_iopREX, meWiopREX, meWiopREXse, me_cond_iopREX, me_cond_iopREX_se, piopREXxbar, piopREX_se} = mes(V_iopREX, iopREX, capJ, me_model, meanc(xzall));

skip_REX:

if mtype eq 5;
    goto finish;
endif;


        /* ESTIMATE INFLATED ORDERED PROBIT MODEL WITH RANDOM EFFECTS */

cmlset;

if capJ gt 3;
    c               = ((eye(capJ-3) .*-1)~zeros(capJ-3,1)) + (zeros(capJ-3,1)~eye(capJ-3));
    _cml_c          = zeros(capJ-3,cols(z)+cols(x))~c~zeros(capJ-3,2);
    _cml_d          = zeros(rows(_cml_c),1);
endif;

_cml_bounds     = ((ones(cols(z)+cols(x),1) .* -10000)~(ones(cols(z)+cols(x),1) .* 10000))|        
                    ((zeros(capJ-2,1)+0.00001)~(ones(capJ-2,1) .* 10000))|
                    ((0 * -10000)~(1 * 10000))|
                    ((0 * -10000)~(1 * 10000));
_cml_parnames   = xvars|zvars|(mu .*. ones(capJ-2,1))|"SIG_REZ"|"SIG_REX";  

if tol ne -1;
    _cml_dirTol     = tol;
endif;

_cml_maxIters   = 10;
__output        = 1;  
_cml_covpar     = 1;
_cml_algorithm  = 1;            /* 1 = BFGS, 2=DFP, 3= NEWTON, 4=BHHH */
__title                 = "Inflated Ordered Probit with Random Effects";

if rows(stiopRE) eq 1;
    stiopRE = ((iopREZ[1:rows(iopREZ)-1]+iopREX[1:rows(iopREX)-1]))./2|sig_z|sig_x;
endif;

if not saved(yxz~ai_mat_Z~ai_mat_X,"sae_dat",0);
    errorlog "Disk full";stop;
    end;
endif;

et_start    = timeutc;

if skip_RE eq 2;

    iopRE = stiopRE;
    beta    = iopRE[1:kx];
    gama    = iopRE[kx+1:kx+kz];     
    muiop   = iopRE[kx+kz+1:rows(iopRE)-2];
    sig_zRE = iopRE[rows(iopRE)-1];
    sig_xRE = iopRE[rows(iopRE)]; 

    goto skip_REXZ;

endif;

{ iopRE,maxfiopRE,giopRE,coviopRE,retiopRE } = cmlprt(cml("sae_dat",0,&iopbsae_ml,stiopRE));

if ismiss(coviopRE);
    
    outer_giopRE = giopRE*giopRE';

    if det(outer_giopRE) gt 0;
        coviopRE = eye(rows(outer_giopRE))/outer_giopRE;
    else;
        coviopRE = 1;
        coviopRE = miss(coviopRE,1);
    endif;

endif;

if retiopRE eq 0;
    let retiopRE = normal convergence;
else;
    let retiopRE = abnormal convergence;
endif;


et_iop_RE   = timeutc;
et_iop_RE   = (et_iop_RE - et_start) / 3600;        @ estimation in hours @ 


if ismiss(iopRE) eq 1;
        iopRE       = ones(rows(stiopRE),1).*-999;
        iopREse     = iopRE;
        tiopRE      = iopRE;
        maxfiopRE   = -999;
else;
        iopREse  = sqrt(diag(coviopRE));
        iopREse  = missrv(iopREse,10000);
        if rows(iopREse) eq 1;
                iopREse = iopREse .* ones(rows(stiopRE),1);
        endif;
        tiopRE   = abs(iopRE ./ iopREse);
        maxfiopRE= maxfiopRE*N;
endif;


                        /* CONSTRUCT INFLATED ORDERED PROBIT PROBABLITIES */

beta    = iopRE[1:kx];
gama    = iopRE[kx+1:kx+kz];     
muiop   = iopRE[kx+kz+1:rows(iopRE)-2];
sig_zRE = iopRE[rows(iopRE)-1];
sig_xRE = iopRE[rows(iopRE)]; 

if rows(iopRE) ne (rows(beta)+rows(muiop)+rows(gama)+2);
   "error line 1243";stop;
endif;

/* DETERMINISTIC PARTs & PROBABILITIES */

xbeta = x*beta;
zgama = z*gama; 

piopRE = 1-(cdfn(zgama));
piopRE = piopRE~(cdfn(muiop[1]-zgama) - cdfn(-zgama));

if capJ gt 3;

    for jrep2 (2,capJ-2,1);
            piopRE = piopRE~(cdfn(muiop[jrep2]-zgama) -
                        cdfn(muiop[jrep2-1]-zgama));
    endfor;

endif;

piopRE  = piopRE~(1 - cdfn(muiop[capJ-2]-zgama));
p_aug   = (1-cdfn(xbeta)) + (piopRE[.,index+1] .* (cdfn(xbeta))); 

p_aug_pred0 = (1-cdfn(xbeta)) .ge (piopRE[.,index+1] .* (cdfn(xbeta)));

piopRE  = piopRE .* ((cdfn(xbeta)) .*. ones(1,capJ));
piopRE[.,index+1] = p_aug;
p_aug_pred  = (index+1) .eq maxindc(piopRE'); 

p_aug_pred0 = selif(p_aug_pred~p_aug_pred0,p_aug_pred);
p_aug_pred0 = meanc(prodc(p_aug_pred0'));


if meanc(sumc(piopRE')) gt 1.0001 or meanc(sumc(piopRE')) lt .9999;
            errorlog "ERROR IN DEFINING INFLATED ORDERED PROBIT PROBABILITIES; PROGRAM TERMINATED";
                        "mean probablitiy =";;meanc(sumc(piopRE'));stop;
endif;

?;
"           ****Split of Probabilities for Augmented Outcome****";?;
"   Av Total Prob; Of which from 1st stage; Total % Predicted; % of Total from 1st Stage";
?;
p0_iopRE = meanc(piopRE[.,index+1])~meanc(1-cdfn(xbeta))~meanc(p_aug_pred)~p_aug_pred0;
?;
p0_iopRE;
?;


/* CALL ME PROCEDURE AND CALCULATE INFORMATION CRITERIA */

V_iopRE   = coviopRE;

AICiopRE  = (-2*maxfiopRE) + rows(iopRE);  
BICiopRE  = (-2*maxfiopRE) + (ln(N)*rows(iopRE));  
CAICiopRE = (-2*maxfiopRE) + ((1+ln(N))*rows(iopRE));  


if mtype eq 6 and sim_ME eq 1;

    for i (1,N_panel,1);

        sel_i   = i .eq idvec;
        xz_it   = meanc(selif(xzall,sel_i));

        for mrep (1,M,1);

            ai_Z    = ai_mat_Z[i,mrep];
            ai_X    = ai_mat_X[i,mrep];


            {me_iopRE, me_iopREse, me0_iopRE, me0se_iopRE, meWiopRE, meWiopREse, me_cond_iopRE, me_cond_iopRE_se, piopRExbar, piopRE_se} = 
                        mes(V_iopRE, iopRE, capJ, me_model, xz_it);


            if i eq 1 and mrep eq 1;

                me_sim      = me_iopRE;
                me_sim_se   = me_iopREse;
                me0_sim     = me0_iopRE;
                me0_sim_se  = me0se_iopRE;
                meW_sim     = meWiopRE;
                meW_sim_se  = meWiopREse;

            else;

                me_sim      = me_sim+me_iopRE;
                me_sim_se   = me_sim_se+me_iopREse;
                me0_sim     = me0_sim+me0_iopRE;
                me0_sim_se  = me0_sim_se+me0se_iopRE;
                meW_sim     = meW_sim+meWiopRE;
                meW_sim_se  = meW_sim_se+meWiopREse;

            endif;
                
        endfor;
        
    endfor;

    me_iopRE    = me_sim ./ (M*N_panel);
    me_iopREse  = me_sim_se ./ (M*N_panel);
    me0_iopRE   = me0_sim ./ (M*N_panel);
    me0se_iopRE = me0_sim_se ./ (M*N_panel);
    meWiopRE    = meW_sim ./ (M*N_panel);
    meWiopREse  = meW_sim_se ./ (M*N_panel);

else;

    let me_model = iop_RE;

    {me_iopRE, me_iopREse, me0_iopRE, me0se_iopRE, meWiopRE, meWiopREse, me_cond_iopRE, me_cond_iopRE_se, piopRExbar, piopRE_se} = mes(V_iopRE, iopRE, capJ, me_model, meanc(xzall));


endif;


/* IMPLIED COVARIANCE MATRIX AND APPROPRIATE STANDARD ERRORS */ 

{v_cov_RE}  = v_cov(iopRE);
G_cov       = gradp(&v_cov,iopRE)';
cov_se      = G_cov'V_iopRE*G_cov;
v_cov_RE    = v_cov_RE~(sqrt(diag(cov_se)))~abs(v_cov_RE ./ (sqrt(diag(cov_se))));

skip_REXZ:

if mtype eq 6;
    goto finish;
endif;    


if mtype eq 9;
    goto correlated;
endif;    


        /* ESTIMATE INFLATED ORDERED PROBIT MODEL WITH FULL SET OF RANDOM EFFECTS */

cmlset;

if capJ gt 3;
    c               = ((eye(capJ-3) .*-1)~zeros(capJ-3,1)) + (zeros(capJ-3,1)~eye(capJ-3));
    _cml_c          = zeros(capJ-3,cols(z)+cols(x))~c~zeros(capJ-3,3);
    _cml_d          = zeros(rows(_cml_c),1);
endif;
_cml_bounds     = ((ones(cols(z)+cols(x),1) .* -10000)~(ones(cols(z)+cols(x),1) .* 10000))|        
                    ((zeros(capJ-2,1)+0.00001)~(ones(capJ-2,1) .* 10000))|
                    ((1 * -10)~(1 * 10))|
                    ((1 * -10)~(1 * 10))|
                    ((1 * -10)~(1 * 10));
_cml_parnames   = xvars|zvars|(mu .*. ones(capJ-2,1))|"CHOL(Z)"|"CHOL(X)"|"CHOL(ZX)";  

if tol ne -1;
    _cml_dirTol     = tol;
endif;

_cml_maxIters   = 100;
__output        = 1;  
_cml_covpar     = 1;
_cml_algorithm  = 1;            /* 1 = BFGS, 2=DFP, 3= NEWTON, 4=BHHH */
__title                 = "Inflated Ordered Probit with Full Random Effects";

if rows(stiopREfull) eq 1;

    logL = zeros(1,3);

    sig_rep = -1;

    do while sig_rep le 1;

        chol_cov    = eye(2);
        sig_ae      = sig_rep;     

        ai_Z = 0;    
        ai_X = 0; 

        prob = 0;

        r = 1; 
        do until r > M;

            ai_Z   = ai_mat_Z[.,r];
            ai_X   = ai_mat_X[.,r];

            chol_21     = sig_ae/sig_zRE;

            if (sig_xRE^2) le (sig_ae^2)/(sig_zRE^2);
                goto next_sig_rep;
            endif;

            chol_22     = sqrt((sig_xRE^2) - (sig_ae^2)/(sig_zRE^2));


            chol_check = zeros(2,2);
            chol_check[1,1] = sig_z;
            chol_check[2,2] = chol_22;
            chol_check[2,1] = chol_21;


            /* DETERMINISTIC PARTs & PROBABILITIES */

            zgama = (z*gama) + (ai_Z .* sig_zRE);     
            xbeta = (x*beta) + ((ai_X .* chol_22) + (ai_Z .* chol_21));


            p_ij        = 1-(cdfn(zgama));
            p_ij        = p_ij~(cdfn(muiop[1]-zgama) - cdfn(-zgama));

            if capJ gt 3;

                for jrep2 (2,capJ-2,1);
                    p_ij = p_ij~(cdfn(muiop[jrep2]-zgama) -
                                cdfn(muiop[jrep2-1]-zgama));
                endfor;

            endif;

            p_ij    = p_ij~(1 - cdfn(muiop[capJ-2]-zgama));
            p_aug   = (1-cdfn(xbeta)) + (p_ij[.,index+1] .* (cdfn(xbeta))); 
            p_ij    = p_ij .* ((cdfn(xbeta)) .*. ones(1,capJ));
            p_ij[.,index+1] = p_aug;


            /* PRODUCT OVER INDIVIDUALS */

            prob_temp   = (sumc((d_ij .* p_ij)'));
            p_vec       = prodc(selif(prob_temp,idvec .eq 1));

            for i_rep (2,maxc(idvec),1);
                sel     = idvec .eq i_rep;
                p_vec   = p_vec|prodc(selif(prob_temp,sel));
            endfor;

            prob = prob + p_vec;

            r = r+1 ; 

        endo;
    
        prob = prob ./ M;

        logL = logL|(sumc(ln(prob))~chol_22~chol_21);

        next_sig_rep:
        sig_rep = sig_rep + 0.1;

    endo;

    if rows(logL) gt 1;

        logL = logL[2:rows(logL),.];
        logL = rev(sortc(logL,1));
        logL = delif(logL,logL[.,2] .eq 0);

        stiopREfull = iop|sig_zRE|logL[1,2]|logL[1,3];

    else;

        stiopREfull = iop|sig_zRE|0|0;

    endif;

endif;

et_start    = timeutc;

{ iopREfull,maxfiopREfull,giopREfull,coviopREfull,retiopREfull } = cmlprt(cml("sae_dat",0,&iopbREfull_ml,stiopREfull));

if ismiss(coviopREfull);
    
    outer_giopREfull = giopREfull*giopREfull';

    if det(outer_giopREfull) gt 0;
        coviopREfull = eye(rows(outer_giopREfull))/outer_giopREfull;
    else;
        coviopREfull = 1;
        coviopREfull = miss(coviopREfull,1);
    endif;

endif;


if retiopREfull eq 0;
    let retiopREfull = normal convergence;
else;
    let retiopREfull = abnormal convergence;
endif;


et_iop_REfull   = timeutc;
et_iop_REfull   = (et_iop_REfull - et_start) / 3600;        @ estimation in hours @ 


if ismiss(iopREfull) eq 1;

        iopREfull       = ones(rows(stiopREfull),1).*-999;
        iopREfullse     = iopREfull;
        tiopREfull      = iopREfull;
        maxfiopREfull   = -999;

else;

        iopREfullse  = sqrt(diag(coviopREfull));
        iopREfullse  = missrv(iopREfullse,10000);
        if rows(iopREfullse) eq 1;
                iopREfullse = iopREfullse .* ones(rows(stiopREfull),1);
        endif;
        tiopREfull   = abs(iopREfull ./ iopREfullse);
        maxfiopREfull= maxfiopREfull*N;

endif;


                        /* CONSTRUCT INFLATED ORDERED PROBIT PROBABLITIES */

beta    = iopREfull[1:kx];
gama    = iopREfull[kx+1:kx+kz];     
muiop   = iopREfull[kx+kz+1:rows(iopREfull)-3];
sig_z   = iopREfull[rows(iopREfull)-2];
sig_x   = iopREfull[rows(iopREfull)-1]; 
sig_zx  = iopREfull[rows(iopREfull)];

if rows(iopREfull) ne (rows(beta)+rows(muiop)+rows(gama)+3);
   "error line 1477";stop;
endif;

/* DETERMINISTIC PARTs & PROBABILITIES */

xbeta = x*beta;
zgama = z*gama; 

piopREfull = 1-(cdfn(zgama));
piopREfull = piopREfull~(cdfn(muiop[1]-zgama) - cdfn(-zgama));

if capJ gt 3;

    for jrep2 (2,capJ-2,1);
            piopREfull = piopREfull~(cdfn(muiop[jrep2]-zgama) -
                        cdfn(muiop[jrep2-1]-zgama));
    endfor;

endif;

piopREfull = piopREfull~(1 - cdfn(muiop[capJ-2]-zgama));
p_aug   = (1-cdfn(xbeta)) + (piopREfull[.,index+1] .* (cdfn(xbeta))); 

p_aug_pred0 = (1-cdfn(xbeta)) .ge (piopREfull[.,index+1] .* (cdfn(xbeta)));

piopREfull = piopREfull .* ((cdfn(xbeta)) .*. ones(1,capJ));
piopREfull[.,index+1] = p_aug;
p_aug_pred  = (index+1) .eq maxindc(piopREfull'); 

p_aug_pred0 = selif(p_aug_pred~p_aug_pred0,p_aug_pred);
p_aug_pred0 = meanc(prodc(p_aug_pred0'));


if meanc(sumc(piopREfull')) gt 1.0001 or meanc(sumc(piopREfull')) lt .9999;
            errorlog "ERROR IN DEFINING INFLATED ORDERED PROBIT PROBABILITIES; PROGRAM TERMINATED";
                        "mean probablitiy =";;meanc(sumc(piopREfull'));stop;
endif;

?;
"           ****Split of Probabilities for Augmented Outcome****";?;
"   Av Total Prob; Of which from 1st stage; Total % Predicted; % of Total from 1st Stage";
?;
p0_iopREfull = meanc(piopREfull[.,index+1])~meanc(1-cdfn(xbeta))~meanc(p_aug_pred)~p_aug_pred0;
?;
p0_iopREfull;
?;

/* CALL ME PROCEDURE AND CALCULATE INFORMATION CRITERIA */

V_iopREfull   = coviopREfull;

AICiopREfull  = (-2*maxfiopREfull) + rows(iopREfull);  
BICiopREfull  = (-2*maxfiopREfull) + (ln(N)*rows(iopREfull));  
CAICiopREfull = (-2*maxfiopREfull) + ((1+ln(N))*rows(iopREfull));  


//let mtype = 6.iop_RE 7.iop_REfull 8.iopc 9.iopc_RE 10.iopc_REfull 11.giopc_REfull; 

if mtype eq 7 and sim_ME eq 1;

    for i (1,N_panel,1);

        sel_i   = i .eq idvec;
        xz_it   = meanc(selif(xzall,sel_i));

        for mrep (1,M,1);

            ai_Z    = ai_mat_Z[i,mrep];
            ai_X    = ai_mat_X[i,mrep];


            {me_iopREfull, me_iopREfullse, me0_iopREfull, me0se_iopREfull, meWiopREfull, meWiopREfullse, me_cond_iopREfull, me_cond_iopREfull_se,
                              piopREfullxbar, piopREfull_se} = 
                                                        mes(V_iopREfull, iopREfull, capJ, me_model, xz_it);


            if i eq 1 and mrep eq 1;

                me_sim      = me_iopREfull;
                me_sim_se   = me_iopREfullse;
                me0_sim     = me0_iopREfull;
                me0_sim_se  = me0se_iopREfull;
                meW_sim     = meWiopREfull;
                meW_sim_se  = meWiopREfullse;

            else;

                me_sim      = me_sim+me_iopREfull;
                me_sim_se   = me_sim_se+me_iopREfullse;
                me0_sim     = me0_sim+me0_iopREfull;
                me0_sim_se  = me0_sim_se+me0se_iopREfull;
                meW_sim     = meW_sim+meWiopREfull;
                meW_sim_se  = meW_sim_se+meWiopREfullse;

            endif;
                
        endfor;
        
    endfor;

    me_iopREfull    = me_sim ./ (M*N_panel);
    me_iopREfullse  = me_sim_se ./ (M*N_panel);
    me0_iopREfull   = me0_sim ./ (M*N_panel);
    me0se_iopREfull = me0_sim_se ./ (M*N_panel);
    meWiopREfull    = meW_sim ./ (M*N_panel);
    meWiopREfullse  = meW_sim_se ./ (M*N_panel);

else;

    let me_model = iop_REfull;

    {me_iopREfull, me_iopREfullse, me0_iopREfull, me0se_iopREfull, meWiopREFULL, meWiopREFULLse, me_cond_iopREfull, me_cond_iopREfull_se,
                                   piopREfullxbar, piopREfull_se} = 
                                                            mes(V_iopREfull, iopREfull, capJ, me_model, meanc(xzall));


endif;


/* IMPLIED COVARIANCE MATRIX AND APPROPRIATE STANDARD ERRORS */ 

{v_cov_REfull}  = v_cov(iopREfull);
G_cov           = gradp(&v_cov,iopREfull)';
cov_se          = G_cov'V_iopREfull*G_cov;
v_cov_REfull    = v_cov_REfull~(sqrt(diag(cov_se)))~abs(v_cov_REfull ./ (sqrt(diag(cov_se))));


if mtype eq 7;
    goto finish;
endif;


correlated:

                        /* ESTIMATE CORRELATED INFLATED ORDERED PROBIT MODEL */


/* CONSTRUCT START VALUES FOR RHO */

if rows(stiopc) eq 1;

    beta    = iop[1:kx];
    gama    = iop[kx+1:kx+kz];     
    muiop   = iop[kx+kz+1:rows(iop)]; 

    logL = zeros(1,2);

    for rho (-0.75,0.75,0.1);

        /* DETERMINISTIC PARTs & PROBABILITIES */


        xbeta = (x*beta);
        zgama = (z*gama);     

        p_ij        = cdfbvn(xbeta,-zgama,-rho);
        p_ij        = p_ij~(cdfbvn(xbeta,muiop[1]-zgama,-rho) - cdfbvn(xbeta,-zgama,-rho));

        if capJ gt 3;

            for jrep2 (2,capJ-2,1);
                p_ij = p_ij~(cdfbvn(xbeta,muiop[jrep2]-zgama,-rho) -
                            cdfbvn(xbeta,muiop[jrep2-1]-zgama,-rho));
            endfor;

        endif;
    
        p_ij    = p_ij~(cdfbvn(xbeta,zgama-muiop[capJ-2],rho));
        p_aug   = 1-cdfn(xbeta);
        p_ij[.,index+1] = p_ij[.,index+1] + p_aug;

        prob    = (sumc((d_ij .* p_ij)'));

        logL = logL|(sumc(ln(prob))~rho);

    endfor;

    logL = logL[2:rows(logL),.];
    logL = rev(sortc(logL,1));
    logL = delif(logL,abs(logL[.,2]) .lt 0.1);

    stiopc = beta|gama|muiop|logL[1,2];    

endif;

cmlset;

if no_con eq 0;
	
	if capJ gt 3;
		c               = ((eye(capJ-3) .*-1)~zeros(capJ-3,1)) + (zeros(capJ-3,1)~eye(capJ-3));
		_cml_c          = zeros(capJ-3,cols(z)+cols(x))~c~zeros(capJ-3,1);
		_cml_d          = zeros(rows(_cml_c),1);
	endif;

	_cml_bounds     = ((ones(cols(z)+cols(x),1) .* -10000)~(ones(cols(z)+cols(x),1) .* 10000))|
                            ((zeros(capJ-2,1)+0.00001)~(ones(capJ-2,1) .* 10000))|
							(-0.9999~.9999);
	_cml_parnames   = xvars|zvars|(mu .*. ones(capJ-2,1))|"RHO";  

elseif no_con eq 1;

	if capJ gt 3;
		c               = ((eye(capJ-2) .*-1)~zeros(capJ-2,1)) + (zeros(capJ-2,1)~eye(capJ-2));
		_cml_c          = zeros(capJ-2,cols(z)+cols(x))~c~zeros(capJ-2,1);
		_cml_d          = zeros(rows(_cml_c),1);
	endif;

		_cml_parnames   = xvars|zvars|(mu .*. ones(capJ-1,1))|"RHO";  

		_cml_bounds = ((ones(cols(z)+cols(x),1) .* -1000)~(ones(cols(z)+cols(x),1) .* 1000))|
                    ((zeros(capJ-1,1)+0.0001)~(ones(capJ-1,1) .* 1000))|
                	(-0.9999~.9999);
endif;



/*
if capJ gt 3;
    c         	= ((eye(capJ-3) .*-1)~zeros(capJ-3,1)) + (zeros(capJ-3,1)~eye(capJ-3));
    _cml_c      = zeros(capJ-3,cols(z)+cols(x))~c~zeros(capJ-3,1);
    _cml_d      = zeros(rows(_cml_c),1);
endif;

_cml_bounds = ((ones(cols(z)+cols(x),1) .* -1000)~(ones(cols(z)+cols(x),1) .* 1000))|
                    ((zeros(capJ-2,1)+0.0001)~(ones(capJ-2,1) .* 1000))|
                	(-0.9999~.9999);
_cml_parnames   = xvars|zvars|(mu .*. ones(capJ-2,1))|"RHO";  

*/

if tol ne -1;
    _cml_dirTol     = tol;
endif;

_cml_maxIters   = 150;
__output        = 0;  
_cml_covpar     = 2;
_cml_algorithm  = 1;            /* 1 = BFGS, 2=DFP, 3= NEWTON, 4=BHHH */
__title         = "Correlated Inflated Ordered Probit";
@_cml_active     = ones(rows(stiop),1)|0; @

et_start    = timeutc;

{ iopc,maxfiopc,giopc,coviopc,retiopc } = cmlprt(cml(dset,0,&iopbc_ml,stiopc));
//{ iopc,maxfiopc,giopc,coviopc,retiopc } = cml(dset,0,&iopbc_ml,stiopc);

//?;sqrt(diag(coviopc));

beta    = iopc[1:kx];
gama    = iopc[kx+1:kx+kz];       
muiopc  = iopc[kx+kz+1:rows(iopc)-1];
rho     = iopc[rows(iopc)];
op_b    = iopc[1:kx];

/* CLUSTER THE STANDARD ERRORS */
            
if cluster_se;

    struct PV pIOPC_cluster;
    pIOPC_cluster = pvCreate;
    pIOPC_cluster = pvPack(pIOPC_cluster,gama,"gama");    
    pIOPC_cluster = pvPack(pIOPC_cluster,op_b,"op_b");
    pIOPC_cluster = pvPack(pIOPC_cluster,muiop,"muiop");
    pIOPC_cluster = pvPack(pIOPC_cluster,rho,"rho");

    struct DS dIOPC_cluster;
    dIOPC_cluster = reshape(dsCreate,3,1);
    dIOPC_cluster[1].DataMatrix = d_ij;
    dIOPC_cluster[2].DataMatrix = x;
    dIOPC_cluster[3].DataMatrix = z;

    G = gradMT(&IOPC_se_proc,pIOPC_cluster,dIOPC_cluster);
    H = hessMT(&IOPC_se_proc,pIOPC_cluster,dIOPC_cluster);

    {coviopc} = _cluster_se(G,-H,idvec);

endif;

//?;sqrt(diag(coviopc));wait;

if ismiss(coviopc);
    
    outer_giopc = giopc*giopc';

    if det(outer_giopc) gt 0;
        coviopc = eye(rows(outer_giopc))/outer_giopc;
    else;
        coviopc = 1;
        coviopc = miss(coviopc,1);
    endif;

endif;

if retiopc eq 0;
    let retiopc = normal convergence;
else;
    let retiopc = abnormal convergence;
endif;


et_iopc     = timeutc;
et_iopc     = (et_iopc - et_start) / 3600;        @ estimation in hours @ 

if ismiss(iopc) eq 1;
    iopc       = ones(rows(stiopc),1).*-999;
    iopcse     = iopc;
    tiopc      = iopc;
    maxfiopc   = -999;
else;
    iopcse         = sqrt(diag(coviopc));
    iopcse         = missrv(iopcse,10000);
    if rows(iopcse) eq 1;
        iopcse = iopcse .* ones(rows(stiopc),1);
    endif;
    tiopc      = abs(iopc ./ iopcse);
    maxfiopc   = maxfiopc*N;
endif;

if retiopc eq 0;
        let retiopc = normal convergence;
elseif retiopc eq 1;
        let retiopc = forced exit;
elseif retiopc eq 2;
        let retiopc = max iters exceeded;
elseif retiopc eq 3;
        let retiopc = function failed;
elseif retiopc eq 4;
        let retiopc = gradient failed;
elseif retiopc eq 5;
        let retiopc = Hessian failed;
elseif retiopc eq 6;
        let retiopc = line search failed;
elseif retiopc eq 7;
        let retiopc = bad starting values;
elseif retiopc eq 8;
        let retiopc = error with gradient;
elseif retiopc eq 9;
        let retiopc = error with constraints;
elseif retiopc eq 10;
        let retiopc = secant update failed;
elseif retiopc eq 11;
        let retiopc = max time exceeded;
elseif retiopc eq 12;
        let retiopc = error with weights;
elseif retiopc eq 13;
        let retiopc = quadratic program failed;
elseif retiopc eq 20;
        let retiopc = Hessian failed to invert;
elseif retiopc eq 34;
        let retiopc = couldn't open data set;
endif;


/* DEFINE CORRELATED PROBABILITIES */

/* DEFINE PARAMETERS */
        
beta    = iopc[1:kx];
gama    = iopc[kx+1:kx+kz];       
muiopc  = iopc[kx+kz+1:rows(iopc)-1];
rho     = iopc[rows(iopc)];


/* DETERMINISTIC PARTs & PROBABILITIES */

xbeta = x*beta;
zgama = z*gama;     

piopc   = cdfbvn(xbeta,-zgama,-rho);
piopc   = piopc~(cdfbvn(xbeta,muiopc[1]-zgama,-rho) - cdfbvn(xbeta,-zgama,-rho));

if capJ gt 3;
    for jrep2 (2,capJ-2,1);
        piopc = piopc~(cdfbvn(xbeta,muiopc[jrep2]-zgama,-rho) -
                                cdfbvn(xbeta,muiopc[jrep2-1]-zgama,-rho));
    endfor;
endif;
    
piopc    = piopc~(cdfbvn(xbeta,zgama-muiopc[capJ-2],rho));
p_aug   = 1-cdfn(xbeta);

p_aug_pred0 = (1-cdfn(xbeta)) .ge (piopc[.,index+1]);

piopc[.,index+1] = piopc[.,index+1] + p_aug;
p_aug_pred  = (index+1) .eq maxindc(piopc'); 

p_aug_pred0 = selif(p_aug_pred~p_aug_pred0,p_aug_pred);
p_aug_pred0 = meanc(prodc(p_aug_pred0'));

if meanc(sumc(piopc')) gt 1.0001 or meanc(sumc(piopc')) lt .9999;
            errorlog "ERROR IN DEFINING INFLATED ORDERED PROBIT PROBABILITIES; PROGRAM TERMINATED";
                        "mean probablitiy =";;meanc(sumc(piopc'));stop;
endif;

?;
"           ****Split of Probabilities for Augmented Outcome****";?;
"   Av Total Prob; Of which from 1st stage; Total % Predicted; % of Total from 1st Stage";
?;
p0_iopc = meanc(piopc[.,index+1])~meanc(1-cdfn(xbeta))~meanc(p_aug_pred)~p_aug_pred0;
?;
p0_iopc;
?;


/* CALL ME PROCEDURE AND CALCULATE INFORMATION CRITERIA */

V_iopc   = coviopc;

AICiopc  = (-2*maxfiopc) + rows(iopc);  
BICiopc  = (-2*maxfiopc) + (ln(N)*rows(iopc));  
CAICiopc = (-2*maxfiopc) + ((1+ln(N))*rows(iopc));  

let me_model = iopc;

{me_iopc,me_iopcse,me0_iopc, me0se_iopc, meWiopc, meWiopcse, me_cond_iopc, me_cond_iopc_se, piopcxbar, piopc_se} = mes(V_iopc,iopc,capJ,me_model,meanc(xzall));

if rho ge 0.9;
	rho = 0.75;
endif;	

if rho le -0.9;
	rho = -0.75;
endif;	


if mtype eq 8;
    goto finish;
endif;    


                        /* ESTIMATE FULL RANDOM EFFECTS CORRELATED INFLATED ORDERED PROBIT MODEL */


if rows(stiopcRE) eq 1;
    stiopcRE = iopc[1:rows(iopc)-1]|sig_zRE|sig_xRE|rho;    
endif;

cmlset;

if capJ gt 3;
    c         	= ((eye(capJ-3) .*-1)~zeros(capJ-3,1)) + (zeros(capJ-3,1)~eye(capJ-3));
    _cml_c      = zeros(capJ-3,cols(z)+cols(x))~c~zeros(capJ-3,3);
    _cml_d      = zeros(rows(_cml_c),1);
endif;
_cml_bounds = ((ones(cols(z)+cols(x),1) .* -1000)~(ones(cols(z)+cols(x),1) .* 1000))|
                    ((zeros(capJ-2,1)+0.0001)~(ones(capJ-2,1) .* 1000))|
                    ((1 * 0)~(1 * 10))|
                    ((1 * 0)~(1 * 10))|
                	(-0.9999~.9999);
_cml_parnames   = xvars|zvars|(mu .*. ones(capJ-2,1))|"CHOL(Z)"|"CHOL(X)"|"RHO";  

if tol ne -1;
    _cml_dirTol     = tol;
endif;

_cml_maxIters   = 150;
__output        = 1;  
_cml_covpar     = 2;
_cml_algorithm  = 3;            /* 1 = BFGS, 2=DFP, 3= NEWTON, 4=BHHH */
__title         = "Random Effects Correlated Inflated Ordered Probit";

et_start    = timeutc;

if skip_RE eq 2;

    iopcRE  = stiopcRE;
    iopcREse= iopcRE;
    tiopcRE = iopcRE;
    beta    = iopcRE[1:kx];
    gama    = iopcRE[kx+1:kx+kz];       
    muiopc  = iopcRE[kx+kz+1:rows(iopcRE)-3];
    sig_z   = iopcRE[rows(iopcRE)-2];      
    sig_x   = iopcRE[rows(iopcRE)-1];           
    rho     = iopcRE[rows(iopcRE)];

    goto skip_REXZc;

endif;

{ iopcRE,maxfiopcRE,giopcRE,coviopcRE,retiopcRE } = cmlprt(cml("sae_dat",0,&iopbcRE_ml,stiopcRE));

if ismiss(coviopcRE);
    
    outer_giopcRE = giopcRE*giopcRE';

    if det(outer_giopcRE) gt 0;
        coviopcRE = eye(rows(outer_giopcRE))/outer_giopcRE;
    else;
        coviopcRE = 1;
        coviopcRE = miss(coviopcRE,1);
    endif;

endif;

if retiopcRE eq 0;
    let retiopcRE = normal convergence;
else;
    let retiopcRE = abnormal convergence;
endif;


et_iopcRE     = timeutc;
et_iopcRE     = (et_iopcRE - et_start) / 3600;        @ estimation in hours @ 

if ismiss(iopcRE) eq 1;
    iopcRE       = ones(rows(stiopcRE),1).*-999;
    iopcREse     = iopcRE;
    tiopcRE      = iopcRE;
    maxfiopcRE   = -999;
else;
    iopcREse         = sqrt(diag(coviopcRE));
    iopcREse         = missrv(iopcREse,10000);
    if rows(iopcREse) eq 1;
        iopcREse = iopcREse .* ones(rows(stiopcRE),1);
    endif;
    tiopcRE      = abs(iopcRE ./ iopcREse);
    maxfiopcRE   = maxfiopcRE*N;
endif;

if retiopcRE eq 0;
        let retiopcRE = normal convergence;
elseif retiopc eq 1;
        let retiopcRE = forced exit;
elseif retiopcRE eq 2;
        let retiopcRE = max iters exceeded;
elseif retiopcRE eq 3;
        let retiopcRE = function failed;
elseif retiopcRE eq 4;
        let retiopcRE = gradient failed;
elseif retiopcRE eq 5;
        let retiopcRE = Hessian failed;
elseif retiopcRE eq 6;
        let retiopcRE = line search failed;
elseif retiopcRE eq 7;
        let retiopcRE = bad starting values;
elseif retiopcRE eq 8;
        let retiopcRE = error with gradient;
elseif retiopcRE eq 9;
        let retiopcRE = error with constraints;
elseif retiopcRE eq 10;
        let retiopcRE = secant update failed;
elseif retiopcRE eq 11;
        let retiopcRE = max time exceeded;
elseif retiopcRE eq 12;
        let retiopcRE = error with weights;
elseif retiopcRE eq 13;
        let retiopcRE = quadratic program failed;
elseif retiopcRE eq 20;
        let retiopcRE = Hessian failed to invert;
elseif retiopcRE eq 34;
        let retiopcRE = couldn't open data set;
endif;


/* DEFINE CORRELATED PROBABILITIES */

/* DEFINE PARAMETERS */
        
beta    = iopcRE[1:kx];
gama    = iopcRE[kx+1:kx+kz];       
muiopc  = iopcRE[kx+kz+1:rows(iopcRE)-3];
sig_z   = iopcRE[rows(iopcRE)-2];      
sig_x   = iopcRE[rows(iopcRE)-1];           
rho     = iopcRE[rows(iopcRE)];


/* DETERMINISTIC PARTs & PROBABILITIES */

xbeta = x*beta;
zgama = z*gama;     

piopcRE   = cdfbvn(xbeta,-zgama,-rho);
piopcRE   = piopcRE~(cdfbvn(xbeta,muiopc[1]-zgama,-rho) - cdfbvn(xbeta,-zgama,-rho));

if capJ gt 3;
    for jrep2 (2,capJ-2,1);
        piopcRE = piopcRE~(cdfbvn(xbeta,muiopc[jrep2]-zgama,-rho) -
                                cdfbvn(xbeta,muiopc[jrep2-1]-zgama,-rho));
    endfor;
endif;
    
piopcRE = piopcRE~(cdfbvn(xbeta,zgama-muiopc[capJ-2],rho));
p_aug   = 1-cdfn(xbeta);

p_aug_pred0 = (1-cdfn(xbeta)) .ge (piopcRE[.,index+1]);

piopcRE[.,index+1] = piopcRE[.,index+1] + p_aug;
p_aug_pred  = (index+1) .eq maxindc(piopcRE'); 

p_aug_pred0 = selif(p_aug_pred~p_aug_pred0,p_aug_pred);
p_aug_pred0 = meanc(prodc(p_aug_pred0'));

if meanc(sumc(piopcRE')) gt 1.0001 or meanc(sumc(piopcRE')) lt .9999;
            errorlog "ERROR IN DEFINING INFLATED ORDERED PROBIT PROBABILITIES; PROGRAM TERMINATED";
                        "mean probablitiy =";;meanc(sumc(piopcRE'));stop;
endif;

?;
"           ****Split of Probabilities for Augmented Outcome****";?;
"   Av Total Prob; Of which from 1st stage; Total % Predicted; % of Total from 1st Stage";
?;
p0_iopcRE = meanc(piopcRE[.,index+1])~meanc(1-cdfn(xbeta))~meanc(p_aug_pred)~p_aug_pred0;
?;
p0_iopcRE;
?;


/* CALL ME PROCEDURE AND CALCULATE INFORMATION CRITERIA */

V_iopcRE   = coviopcRE;

AICiopcRE  = (-2*maxfiopcRE) + rows(iopcRE);  
BICiopcRE  = (-2*maxfiopcRE) + (ln(N)*rows(iopcRE));  
CAICiopcRE = (-2*maxfiopcRE) + ((1+ln(N))*rows(iopcRE));  


//let mtype = 6.iop_RE 7.iop_REfull 8.iopc 9.iopc_RE 10.iopc_REfull 11.giopc_REfull; 

if mtype eq 9 and sim_ME eq 1;

    for i (1,N_panel,1);

        sel_i   = i .eq idvec;
        xz_it   = meanc(selif(xzall,sel_i));

        for mrep (1,M,1);

            ai_Z    = ai_mat_Z[i,mrep];
            ai_X    = ai_mat_X[i,mrep];


            {me_iopcRE, me_iopcREse, me0_iopcRE, me0se_iopcRE, meWiopcRE, meWiopcREse, me_cond_iopcRE, me_cond_iopcRE_se, piopcRExbar, piopcRE_se} 
                                                = mes(V_iopcRE, iopcRE, capJ, me_model, xz_it);


            if i eq 1 and mrep eq 1;

                me_sim      = me_iopcRE;
                me_sim_se   = me_iopcREse;
                me0_sim     = me0_iopcRE;
                me0_sim_se  = me0se_iopcRE;
                meW_sim     = meWiopcRE;
                meW_sim_se  = meWiopcREse;

            else;

                me_sim      = me_sim+me_iopcRE;
                me_sim_se   = me_sim_se+me_iopcREse;
                me0_sim     = me0_sim+me0_iopcRE;
                me0_sim_se  = me0_sim_se+me0se_iopcRE;
                meW_sim     = meW_sim+meWiopcRE;
                meW_sim_se  = meW_sim_se+meWiopcREse;

            endif;
                
        endfor;
        
    endfor;

    me_iopcRE    = me_sim ./ (M*N_panel);
    me_iopcREse  = me_sim_se ./ (M*N_panel);
    me0_iopcRE   = me0_sim ./ (M*N_panel);
    me0se_iopcRE = me0_sim_se ./ (M*N_panel);
    meWiopcRE    = meW_sim ./ (M*N_panel);
    meWiopcREse  = meW_sim_se ./ (M*N_panel);

else;

    let me_model = iopc_RE;

    {me_iopcRE, me_iopcREse, me0_iopcRE, me0se_iopcRE, meWiopcRE, meWiopcREse, me_cond_iopcRE, me_cond_iopcRE_se, piopcRExbar, piopcRE_se} 
                                                    = mes(V_iopcRE, iopcRE, capJ, me_model, meanc(xzall));


endif;



/* IMPLIED COVARIANCE MATRIX AND APPROPRIATE STANDARD ERRORS */ 

{v_cov_REc} = v_cov(iopcRE);
G_cov       = gradp(&v_cov,iopcRE)';
covcRE_se   = G_cov'V_iopcRE*G_cov;
v_cov_REc   = v_cov_REc~(sqrt(diag(covcRE_se)))~abs(v_cov_REc ./ (sqrt(diag(covcRE_se))));


skip_REXZc:

if mtype eq 9;
    goto finish;
endif;    


                        /* ESTIMATE FULL CORRELATED RANDOM EFFECTS CORRELATED INFLATED ORDERED PROBIT MODEL */


if rows(stiopcREfull) eq 1;
    
    if sig_z le 0.1;
        sig_z = 0.1;
    endif;      

    if sig_x le 0.1;
        sig_x = 0.1;
    endif;      

    logL = zeros(1,3);

    sig_rep = -1;

    do while sig_rep le 1;

        chol_cov    = eye(2);
        sig_ae      = sig_rep;     

        ai_X = 0; 
        ai_Z = 0;    

        prob = 0;

        r = 1; 
        do until r > M;

            ai_Z   = ai_mat_Z[.,r];
            ai_X   = ai_mat_X[.,r];

            chol_21     = sig_ae/sig_z;

            if (sig_x^2) le (sig_ae^2)/(sig_z^2);
                goto next_sig_rep_cor;
            endif;

            chol_22     = sqrt((sig_x^2) - (sig_ae^2)/(sig_z^2));


            /* DETERMINISTIC PARTs & PROBABILITIES */

            zgama = (z*gama) + (ai_Z .* sig_z);     
            xbeta = (x*beta) + ((ai_X .* chol_22) + (ai_Z .* chol_21));


            p_ij   = cdfbvn(xbeta,-zgama,-rho);
            p_ij   = p_ij~(cdfbvn(xbeta,muiopc[1]-zgama,-rho) - cdfbvn(xbeta,-zgama,-rho));

            if capJ gt 3;
                for jrep2 (2,capJ-2,1);
                    p_ij = p_ij~(cdfbvn(xbeta,muiopc[jrep2]-zgama,-rho) -
                                cdfbvn(xbeta,muiopc[jrep2-1]-zgama,-rho));
                endfor;
            endif;
    
            p_ij = p_ij~(cdfbvn(xbeta,zgama-muiopc[capJ-2],rho));
            p_aug   = 1-cdfn(xbeta);
            p_ij[.,index+1] = p_ij[.,index+1] + p_aug;

            /* PRODUCT OVER INDIVIDUALS */

            prob_temp   = (sumc((d_ij .* p_ij)'));
            p_vec       = prodc(selif(prob_temp,idvec .eq 1));

            for i_rep (2,maxc(idvec),1);
                sel     = idvec .eq i_rep;
                p_vec   = p_vec|prodc(selif(prob_temp,sel));
            endfor;

            prob = prob + p_vec;

            r = r+1 ; 

        endo;
    
        prob = prob ./ M;

        logL = logL|(sumc(ln(prob))~chol_22~chol_21);

        next_sig_rep_cor:
        sig_rep = sig_rep + 0.1;

    endo;

    logL = logL[2:rows(logL),.];
    logL = rev(sortc(logL,1));
    logL = delif(logL,logL[.,2] .eq 0);

    stiopcREfull = iopcRE[1:rows(iopcRE)-3]|sig_z|logL[1,2]|logL[1,3]|rho;
  
endif;


cmlset;

if capJ gt 3;
    c         	= ((eye(capJ-3) .*-1)~zeros(capJ-3,1)) + (zeros(capJ-3,1)~eye(capJ-3));
    _cml_c      = zeros(capJ-3,cols(z)+cols(x))~c~zeros(capJ-3,4);
    _cml_d      = zeros(rows(_cml_c),1);
endif;
_cml_bounds = ((ones(cols(z)+cols(x),1) .* -1000)~(ones(cols(z)+cols(x),1) .* 1000))|
                    ((zeros(capJ-2,1)+0.0001)~(ones(capJ-2,1) .* 1000))|
                    ((1 * -10)~(1 * 10))|
                    ((1 * -10)~(1 * 10))|
                    ((1 * -10)~(1 * 10))|
                	(-0.9999~.9999);
_cml_parnames   = xvars|zvars|(mu .*. ones(capJ-2,1))|"CHOL(Z)"|"CHOL(X)"|"CHOL(ZX)"|"RHO";  

if tol ne -1;
    _cml_dirTol     = tol;
endif;

_cml_maxIters   = 100;
__output        = 1;  
_cml_covpar     = 2;
_cml_algorithm  = 3;            /* 1 = BFGS, 2=DFP, 3= NEWTON, 4=BHHH */
__title         = "Full Correlated Random Effects Correlated Inflated Ordered Probit";
@_cml_active     = ones(rows(stiop),1)|0; @

et_start    = timeutc;


{ iopcREfull,maxfiopcREfull,g_iopcREfull,coviopcREfull,retiopcREfull } = cmlprt(cml("sae_dat",0,&iopbcREfull_ml,stiopcREfull));

if ismiss(coviopcREfull);
    
    outer_g_iopcREfull = g_iopcREfull*g_iopcREfull';

    if det(outer_g_iopcREfull) gt 0;
        coviopcREfull = eye(rows(outer_g_iopcREfull))/outer_g_iopcREfull;
    else;
        coviopcREfull = 1;
        coviopcREfull = miss(coviopcREfull,1);
    endif;

endif;

if retiopcREfull eq 0;
    let retiopcREfull = normal convergence;
else;
    let retiopcREfull = abnormal convergence;
endif;


et_iopcREfull     = timeutc;
et_iopcREfull     = (et_iopcREfull - et_start) / 3600;        @ estimation in hours @ 

if ismiss(iopcREfull) eq 1;
    iopcREfull       = ones(rows(stiopcREfull),1).*-999;
    iopcREfullse     = iopcREfull;
    tiopcREfull      = iopcREfull;
    maxfiopcREfull   = -999;
else;
    iopcREfullse         = sqrt(diag(coviopcREfull));
    iopcREfullse         = missrv(iopcREfullse,10000);
    if rows(iopcREfullse) eq 1;
        iopcREfullse = iopcREfullse .* ones(rows(stiopcREfull),1);
    endif;
    tiopcREfull      = abs(iopcREfull ./ iopcREfullse);
    maxfiopcREfull   = maxfiopcREfull*N;
endif;

if retiopcREfull eq 0;
        let retiopcREfull = normal convergence;
elseif retiopcREfull eq 1;
        let retiopcREfull = forced exit;
elseif retiopcREfull eq 2;
        let retiopcREfull = max iters exceeded;
elseif retiopcREfull eq 3;
        let retiopcREfull = function failed;
elseif retiopcREfull eq 4;
        let retiopcREfull = gradient failed;
elseif retiopcREfull eq 5;
        let retiopcREfull = Hessian failed;
elseif retiopcREfull eq 6;
        let retiopcREfull = line search failed;
elseif retiopcREfull eq 7;
        let retiopcREfull = bad starting values;
elseif retiopcREfull eq 8;
        let retiopcREfull = error with gradient;
elseif retiopcREfull eq 9;
        let retiopcREfull = error with constraints;
elseif retiopcREfull eq 10;
        let retiopcREfull = secant update failed;
elseif retiopcREfull eq 11;
        let retiopcREfull = max time exceeded;
elseif retiopcREfull eq 12;
        let retiopcREfull = error with weights;
elseif retiopcREfull eq 13;
        let retiopcREfull = quadratic program failed;
elseif retiopcREfull eq 20;
        let retiopcREfull = Hessian failed to invert;
elseif retiopcREfull eq 34;
        let retiopcREfull = couldn't open data set;
endif;


/* DEFINE CORRELATED PROBABILITIES */

/* DEFINE PARAMETERS */
        
beta    = iopcREfull[1:kx];
gama    = iopcREfull[kx+1:kx+kz];       
muiopc  = iopcREfull[kx+kz+1:rows(iopcREfull)-4];
sig_z   = iopcREfull[rows(iopcREfull)-3];      
sig_x   = iopcREfull[rows(iopcREfull)-2];      
sig_zx  = iopcREfull[rows(iopcREfull)-1];      
rho     = iopcREfull[rows(iopcREfull)];


/* DETERMINISTIC PARTs & PROBABILITIES */

xbeta = x*beta;
zgama = z*gama;     

piopcREfull   = cdfbvn(xbeta,-zgama,-rho);
piopcREfull   = piopcREfull~(cdfbvn(xbeta,muiopc[1]-zgama,-rho) - cdfbvn(xbeta,-zgama,-rho));

if capJ gt 3;
    for jrep2 (2,capJ-2,1);
        piopcREfull = piopcREfull~(cdfbvn(xbeta,muiopc[jrep2]-zgama,-rho) -
                                cdfbvn(xbeta,muiopc[jrep2-1]-zgama,-rho));
    endfor;
endif;
    
piopcREfull = piopcREfull~(cdfbvn(xbeta,zgama-muiopc[capJ-2],rho));
p_aug   = 1-cdfn(xbeta);

p_aug_pred0 = (1-cdfn(xbeta)) .ge (piopcREfull[.,index+1]);

piopcREfull[.,index+1] = piopcREfull[.,index+1] + p_aug;
p_aug_pred  = (index+1) .eq maxindc(piopcREfull'); 

p_aug_pred0 = selif(p_aug_pred~p_aug_pred0,p_aug_pred);
p_aug_pred0 = meanc(prodc(p_aug_pred0'));

if meanc(sumc(piopcREfull')) gt 1.0001 or meanc(sumc(piopcREfull')) lt .9999;
            errorlog "ERROR IN DEFINING INFLATED ORDERED PROBIT PROBABILITIES; PROGRAM TERMINATED";
                        "mean probablitiy =";;meanc(sumc(piopcREfull'));stop;
endif;

?;
"           ****Split of Probabilities for Augmented Outcome****";?;
"   Av Total Prob; Of which from 1st stage; Total % Predicted; % of Total from 1st Stage";
?;
p0_iopcREfull = meanc(piopcREfull[.,index+1])~meanc(1-cdfn(xbeta))~meanc(p_aug_pred)~p_aug_pred0;
?;
p0_iopcREfull;
?;


/* CALL ME PROCEDURE AND CALCULATE INFORMATION CRITERIA */

V_iopcREfull   = coviopcREfull;

save V_iopcREfull, beta, gama, muiopc, sig_z, sig_x, sig_zx, rho;

AICiopcREfull  = (-2*maxfiopcREfull) + rows(iopcREfull);  
BICiopcREfull  = (-2*maxfiopcREfull) + (ln(N)*rows(iopcREfull));  
CAICiopcREfull = (-2*maxfiopcREfull) + ((1+ln(N))*rows(iopcREfull));  


//let mtype = 6.iop_RE 7.iop_REfull 8.iopc 9.iopc_RE 10.iopc_REfull 11.giopc_REfull; 

if mtype eq 10 and sim_ME eq 1;

    for i (1,N_panel,1);

        sel_i   = i .eq idvec;
        xz_it   = meanc(selif(xzall,sel_i));

        for mrep (1,M,1);

            ai_Z    = ai_mat_Z[i,mrep];
            ai_X    = ai_mat_X[i,mrep];


            {me_iopcREfull, me_iopcREfullse, me0_iopcREfull, me0se_iopcREfull, meWiopcREfull, meWiopcREfullse, me_cond_iopcREfull, me_cond_iopcREfull_se, piopcREfullxbar, piopcREfull_se} 
                                                = mes(V_iopcREfull, iopcREfull, capJ, me_model, xz_it);


            if i eq 1 and mrep eq 1;

                me_sim      = me_iopcREfull;
                me_sim_se   = me_iopcREfullse;
                me0_sim     = me0_iopcREfull;
                me0_sim_se  = me0se_iopcREfull;
                meW_sim     = meWiopcREfull;
                meW_sim_se  = meWiopcREfullse;

            else;

                me_sim      = me_sim+me_iopcREfull;
                me_sim_se   = me_sim_se+me_iopcREfullse;
                me0_sim     = me0_sim+me0_iopcREfull;
                me0_sim_se  = me0_sim_se+me0se_iopcREfull;
                meW_sim     = meW_sim+meWiopcREfull;
                meW_sim_se  = meW_sim_se+meWiopcREfullse;

            endif;
                
        endfor;
        
    endfor;

    me_iopcREfull    = me_sim ./ (M*N_panel);
    me_iopcREfullse  = me_sim_se ./ (M*N_panel);
    me0_iopcREfull   = me0_sim ./ (M*N_panel);
    me0se_iopcREfull = me0_sim_se ./ (M*N_panel);
    meWiopcREfull    = meW_sim ./ (M*N_panel);
    meWiopcREfullse  = meW_sim_se ./ (M*N_panel);

else;

    let me_model = iopc_REfull;

    {me_iopcREfull, me_iopcREfullse, me0_iopcREfull, me0se_iopcREfull, meWiopcREFULL, meWiopcREFULLse, me_cond_iopcREfull, me_cond_iopcREfull_se, piopcREfullxbar, piopcREfull_se} 
                                                    = mes(V_iopcREfull, iopcREfull, capJ, me_model, meanc(xzall));

endif;


/* IMPLIED COVARIANCE MATRIX AND APPROPRIATE STANDARD ERRORS */ 

{v_cov_REcfull} = v_cov(iopcREfull);
G_cov           = gradp(&v_cov,iopcREfull)';
covcREfull_se   = G_cov'V_iopcREfull*G_cov;
v_cov_REcfull   = v_cov_REcfull~(sqrt(diag(covcREfull_se)))~abs(v_cov_REcfull ./ (sqrt(diag(covcREfull_se))));

if mtype eq 10;
    goto finish;
endif;


            /* ESTIMATE FULL GENERALISED CORRELATED RANDOM EFFECTS CORRELATED INFLATED ORDERED PROBIT MODEL */


if rows(stgiopcREfull) eq 1;
    stgiopcREfull = beta|gama|mu_param|sig_z|sig_x|sig_zx|rho;
endif;


cmlset;

if capJ gt 3;
    c         	= ((eye(capJ-3) .*-1)~zeros(capJ-3,1)) + (zeros(capJ-3,1)~eye(capJ-3));
    _cml_c      = zeros(capJ-3,cols(z)+cols(x))~c~zeros(capJ-3,kw-1+4);
    _cml_d      = zeros(rows(_cml_c),1);
endif;
_cml_bounds = ((ones(cols(z)+cols(x)+cols(w)-1+capJ-2,1) .* -1000)~(ones(cols(z)+cols(x)+cols(w)-1+capJ-2,1) .* 1000))|
                    ((1 * -10)~(1 * 10))|
                    ((1 * -10)~(1 * 10))|
                    ((1 * -10)~(1 * 10))|
                	(-0.9999~.9999);

_cml_parnames   = xvars|zvars|theta|wvars[2:rows(wvars)]|"CHOL(Z)"|"CHOL(X)"|"CHOL(ZX)"|"RHO";  

if tol ne -1;
    _cml_dirTol     = tol;
endif;

_cml_maxIters   = 150;
__output        = 1;  
_cml_covpar     = 2;
_cml_algorithm  = 3;            /* 1 = BFGS, 2=DFP, 3= NEWTON, 4=BHHH */
__title         = "Full Correlated Random Effects Correlated Generalised Inflated Ordered Probit";

et_start    = timeutc;

{ giopcREfull,maxfgiopcREfull,ggiopcREfull,covgiopcREfull,retgiopcREfull } = cmlprt(cml("sae_dat",0,&giopbcREfull_ml,stgiopcREfull));

if ismiss(covgiopcREfull);
    
    outer_ggiopcREfull = ggiopcREfull*ggiopcREfull';

    if det(outer_ggiopcREfull) gt 0;
        covgiopcREfull = eye(rows(outer_ggiopcREfull))/outer_ggiopcREfull;
    else;
        covgiopcREfull = 1;
        covgiopcREfull = miss(covgiopcREfull,1);
    endif;

endif;

if retgiopcREfull eq 0;
    let retgiopcREfull = normal convergence;
else;
    let retgiopcREfull = abnormal convergence;
endif;

et_giopcREfull     = timeutc;
et_giopcREfull     = (et_giopcREfull - et_start) / 3600;        @ estimation in hours @ 

if ismiss(giopcREfull) eq 1;
    giopcREfull       = ones(rows(stgiopcREfull),1).*-999;
    giopcREfullse     = giopcREfull;
    tgiopcREfull      = giopcREfull;
    maxfgiopcREfull   = -999;
else;
    giopcREfullse         = sqrt(diag(covgiopcREfull));
    giopcREfullse         = missrv(giopcREfullse,10000);
    if rows(giopcREfullse) eq 1;
        giopcREfullse = giopcREfullse .* ones(rows(stgiopcREfull),1);
    endif;
    tgiopcREfull      = abs(giopcREfull ./ giopcREfullse);
    maxfgiopcREfull   = maxfgiopcREfull*N;
endif;

if retgiopcREfull eq 0;
    let retgiopcREfull = normal convergence;
else;
    let retgiopcREfull = normal convergence;
endif;


/* DEFINE CORRELATED PROBABILITIES */

/* DEFINE PARAMETERS */
        
beta        = giopcREfull[1:kx];
gama        = giopcREfull[kx+1:kx+kz];       
mu_param    = giopcREfull[kx+kz+1:rows(giopcREfull)-4];
mugiopg     = _mu_ij(mu_param,w,capJ);     
sig_z       = giopcREfull[rows(giopcREfull)-3];      
sig_x       = giopcREfull[rows(giopcREfull)-2];      
sig_zx      = giopcREfull[rows(giopcREfull)-1];      
rho         = giopcREfull[rows(giopcREfull)];


/* DETERMINISTIC PARTs & PROBABILITIES */

xbeta = x*beta;
zgama = z*gama;     

pgiopcREfull   = cdfbvn(xbeta,-zgama,-rho);
pgiopcREfull   = pgiopcREfull~(cdfbvn(xbeta,mugiopg[.,1]-zgama,-rho) - cdfbvn(xbeta,-zgama,-rho));

if capJ gt 3;
    for jrep2 (2,capJ-2,1);
        pgiopcREfull = pgiopcREfull~(cdfbvn(xbeta,mugiopg[.,jrep2]-zgama,-rho) -
                                cdfbvn(xbeta,mugiopg[.,jrep2-1]-zgama,-rho));
    endfor;
endif;
    
pgiopcREfull = pgiopcREfull~(cdfbvn(xbeta,zgama-mugiopg[.,capJ-2],rho));
p_aug   = 1-cdfn(xbeta);

p_aug_pred0 = (1-cdfn(xbeta)) .ge (pgiopcREfull[.,index+1]);

pgiopcREfull[.,index+1] = pgiopcREfull[.,index+1] + p_aug;
p_aug_pred  = (index+1) .eq maxindc(pgiopcREfull'); 

p_aug_pred0 = selif(p_aug_pred~p_aug_pred0,p_aug_pred);
p_aug_pred0 = meanc(prodc(p_aug_pred0'));

if meanc(sumc(pgiopcREfull')) gt 1.0001 or meanc(sumc(pgiopcREfull')) lt .9999;
            errorlog "ERROR IN DEFINING INFLATED ORDERED PROBIT PROBABILITIES; PROGRAM TERMINATED";
                        "mean probablitiy =";;meanc(sumc(pgiopcREfull'));stop;
endif;

?;
"           ****Split of Probabilities for Augmented Outcome****";?;
"   Av Total Prob; Of which from 1st stage; Total % Predicted; % of Total from 1st Stage";
?;
p0_giopcREfull = meanc(pgiopcREfull[.,index+1])~meanc(1-cdfn(xbeta))~meanc(p_aug_pred)~p_aug_pred0;
?;
p0_giopcREfull;
?;


/* CALL ME PROCEDURE AND CALCULATE INFORMATION CRITERIA */

V_giopcREfull   = covgiopcREfull;

AICgiopcREfull  = (-2*maxfgiopcREfull) + rows(giopcREfull);  
BICgiopcREfull  = (-2*maxfgiopcREfull) + (ln(N)*rows(giopcREfull));  
CAICgiopcREfull = (-2*maxfgiopcREfull) + ((1+ln(N))*rows(giopcREfull));  


//let mtype = 6.iop_RE 7.iop_REfull 8.iopc 9.iopc_RE 10.iopc_REfull 11.giopc_REfull; 

if mtype eq 11 and sim_ME eq 1;

    for i (1,N_panel,1);

        sel_i   = i .eq idvec;
        xz_it   = meanc(selif(xzall,sel_i));

        xbar_me = selif(xz_it,xvec')'; 
        zbar_me = selif(xz_it,zvec')'; 

        for mrep (1,M,1);

            ai_Z    = ai_mat_Z[i,mrep];
            ai_X    = ai_mat_X[i,mrep];


            {me_giopcREfull, me_giopcREfullse, me0_giopcREfull, me0se_giopcREfull, meWgiopcREfull, meWgiopcREfullse, me_cond_giopcREfull, me_cond_giopcREfull_se, pgiopcREfullxbar, pgiopcREfull_se} 
                                                = mes(V_giopcREfull, giopcREfull, capJ, me_model, xz_it);

            if i eq 1 and mrep eq 1;

                me_sim      = me_giopcREfull;
                me_sim_se   = me_giopcREfullse;
                me0_sim     = me0_giopcREfull;
                me0_sim_se  = me0se_giopcREfull;
                meW_sim     = meWgiopcREfull;
                meW_sim_se  = meWgiopcREfullse;

            else;

                me_sim      = me_sim+me_giopcREfull;
                me_sim_se   = me_sim_se+me_giopcREfullse;
                me0_sim     = me0_sim+me0_giopcREfull;
                me0_sim_se  = me0_sim_se+me0se_giopcREfull;
                meW_sim     = meW_sim+meWgiopcREfull;
                meW_sim_se  = meW_sim_se+meWgiopcREfullse;

            endif;
                
        endfor;
        
    endfor;

    me_giopcREfull    = me_sim ./ (M*N_panel);
    me_giopcREfullse  = me_sim_se ./ (M*N_panel);
    me0_giopcREfull   = me0_sim ./ (M*N_panel);
    me0se_giopcREfull = me0_sim_se ./ (M*N_panel);
    meWgiopcREfull    = meW_sim ./ (M*N_panel);
    meWgiopcREfullse  = meW_sim_se ./ (M*N_panel);

else;

    let me_model = giopc_REfull;

    {me_giopcREfull, me_giopcREfullse, me0_giopcREfull, me0se_giopcREfull, meWgiopcREfull, meWgiopcREfullse, me_cond_giopcREfull, me_cond_giopcREfull_se, pgiopcREfullxbar, pgiopcREfull_se} 
                                                    = mes(V_giopcREfull, giopcREfull, capJ, me_model, meanc(xzall));

endif;


/* IMPLIED COVARIANCE MATRIX AND APPROPRIATE STANDARD ERRORS */ 

{v_cov_gREcfull} = v_cov(giopcREfull);
G_cov            = gradp(&v_cov,giopcREfull)';
covgcREfull_se   = G_cov'V_giopcREfull*G_cov;
v_cov_gREcfull   = v_cov_gREcfull~(sqrt(diag(covgcREfull_se)))~abs(v_cov_gREcfull ./ (sqrt(diag(covgcREfull_se))));


finish:


if skip_RE eq 1;

    clear iopREZ, iopREZse, tiopREZ, me_iopREZ, me_iopREZse, me0_iopREZ, me0se_iopREZ, V_iopREZ, maxfiopREZ, AICiopREZ, BICiopREZ, CAICiopREZ, 
            piopREZ, retiopREZ, et_iop_REZ,
            iopREX, iopREXse, tiopREX, me_iopREX, me_iopREXse, me0_iopREX, me0se_iopREX, V_iopREX, maxfiopREX, AICiopREX, BICiopREX, CAICiopREX, 
            piopREX, retiopREX, et_iop_REX;
          
endif;

if skip_RE eq 2;

    clear iopREZ, iopREZse, tiopREZ, me_iopREZ, me_iopREZse, me0_iopREZ, me0se_iopREZ, V_iopREZ, maxfiopREZ, AICiopREZ, BICiopREZ, CAICiopREZ, 
            piopREZ, retiopREZ, et_iop_REZ,
            iopREX, iopREXse, tiopREX, me_iopREX, me_iopREXse, me0_iopREX, me0se_iopREX, V_iopREX, maxfiopREX, AICiopREX, BICiopREX, CAICiopREX, 
            piopREX, retiopREX, et_iop_REX,
            iopRE, iopREse, tiopRE, v_cov_RE, me_iopRE, me_iopREse, me0_iopRE, me0se_iopRE, V_iopRE, maxfiopRE, AICiopRE, BICiopRE, CAICiopRE, 
            piopRE, retiopRE, et_iop_RE;

endif;


                        /* RETURN OUTPUTS */

retp(gamp~probitse~tprobit, me_probit, me_probitse, V_probit, maxfprobit, AICprobit, BICprobit, CAICprobit, pprobit, retprobit, et_probit,
    ordpbt~opbse~topb, me_op, me_opse, V_op, maxfopb, AICop, BICop, CAICop, pordp, retopb, et_op,
    iop~iopse~tiop, me_iop, me_iopse, me0_iop, me0se_iop, me_cond_iop, me_cond_iop_se, V_iop, maxfiop, AICiop, BICiop, CAICiop, piop, p0_iop, retiop, et_iop, 
    giop~giopse~tgiop, me_giop, me_giopse, me0_giop, me0se_giop, meWgiop, meWgiopse, me_cond_giop, me_cond_giop_se, V_giop, maxfgiop, AICgiop, BICgiop, CAICgiop, pgiop, p0_giop, retgiop, et_giop, 
    iopREZ~iopREZse~tiopREZ, me_iopREZ, me_iopREZse, me0_iopREZ, me0se_iopREZ, me_cond_iopREZ, me_cond_iopREZ_se, V_iopREZ, maxfiopREZ, AICiopREZ, BICiopREZ, CAICiopREZ, 
            piopREZ, p0_iopREZ, retiopREZ, et_iop_REZ,
    iopREX~iopREXse~tiopREX, me_iopREX, me_iopREXse, me0_iopREX, me0se_iopREX, me_cond_iopREX, me_cond_iopREX_se, V_iopREX, maxfiopREX, AICiopREX, BICiopREX, CAICiopREX, 
            piopREX, p0_iopREX, retiopREX, et_iop_REX,
    iopRE~iopREse~tiopRE, v_cov_RE, me_iopRE, me_iopREse, me0_iopRE, me0se_iopRE, me_cond_iopRE, me_cond_iopRE_se, V_iopRE, maxfiopRE, AICiopRE, BICiopRE, CAICiopRE, 
        piopRE, p0_iopRE, retiopRE, et_iop_RE,
    iopREfull~iopREfullse~tiopREfull, v_cov_REfull, me_iopREfull, me_iopREfullse, me0_iopREfull, me0se_iopREfull, me_cond_iopREfull, me_cond_iopREfull_se, V_iopREfull, maxfiopREfull, 
            AICiopREfull, BICiopREfull, CAICiopREfull, piopREfull, p0_iopREfull, retiopREfull, et_iop_REfull,
    iopc~iopcse~tiopc, me_iopc, me_iopcse, me0_iopc, me0se_iopc, me_cond_iopc, me_cond_iopc_se, V_iopc, maxfiopc, AICiopc, BICiopc, CAICiopc, piopc, p0_iopc, retiopc, et_iopc,
    iopcRE~iopcREse~tiopcRE, v_cov_REc, me_iopcRE, me_iopcREse, me0_iopcRE, me0se_iopcRE, me_cond_iopcRE, me_cond_iopcRE_se, V_iopcRE, maxfiopcRE, AICiopcRE, BICiopcRE, CAICiopcRE, 
            piopcRE, p0_iopcRE, retiopcRE, et_iopcRE,
    iopcREfull~iopcREfullse~tiopcREfull, v_cov_REcfull, me_iopcREfull, me_iopcREfullse, me0_iopcREfull, me0se_iopcREfull, me_cond_iopcREfull, me_cond_iopcREfull_se, V_iopcREfull, maxfiopcREfull, 
        AICiopcREfull, BICiopcREfull, CAICiopcREfull, piopcREfull, p0_iopcREfull, retiopcREfull, et_iopcREfull,
    giopcREfull~giopcREfullse~tgiopcREfull, v_cov_gREcfull, me_giopcREfull, me_giopcREfullse, me0_giopcREfull, me0se_giopcREfull, meWgiopcREfull, meWgiopcREfullse, me_cond_giopcREfull, me_cond_giopcREfull_se,
            V_giopcREfull, maxfgiopcREfull, AICgiopcREfull, BICgiopcREfull, CAICgiopcREfull, pgiopcREfull, p0_giopcREfull, retgiopcREfull, et_giopcREfull);
endp;


        /* PROCEDURE FOR CLUSTERING COVARIANCE MATRIX */

proc 1 = _cluster_se(G,Hessian,ID);
local B, sel_i, g_i, clustered;
    
    B = 0;
        
    for i (minc(ID),maxc(ID),1);
        
        sel_i   = i .eq ID;
        g_i     = selif(G,sel_i);
        B       = (g_i'g_i) + B; 
        
    endfor;
    
    clustered = inv(-Hessian)*B*inv(-Hessian);
	
retp(clustered);
endp;


                        /* ORDERED PROBIT MODEL */

proc oprobit(params,data);
local y, z, k, n, jrep, jrep2, d_ij, gama, mu, zgama, p_i1, p_icapj, p_irest, p_ij, logl, bands;

    /* DEFINE DATA */

    y = data[.,1];
    z = data[.,3:cols(data)];
    z = selif(z',zvec')';    

    k   = cols(z);
    //y   = y - minc(y);                                          @ run y from 0 to J-1 @
    n   = rows(data);

    //"minc(y)";;minc(y);


    /* CONSTRUCT INDICATOR VARIABLE FOR j=J */

    d_ij        = zeros(n,1);

    for jrep (0,capJ-1,1);
            d_ij = d_ij~(y .eq jrep);
    endfor;

    d_ij = d_ij[.,2:capJ+1];


    /* DEFINE PARAMETERS */ 

    gama        = params[1:k];
    mu          = params[k+1:rows(params)]; 

    if rows(params) ne (rows(gama)+rows(mu));
        "error line 1917";stop;
    endif;

    /* DETERMINISTIC PART & PROBABILITIES */

    zgama = z*gama;

    if no_con eq 0;

        p_ij        = 1-(cdfn(zgama));
        p_ij        = p_ij~(cdfn(mu[1]-zgama) - cdfn(-zgama));

        for jrep2 (2,capJ-2,1);
            p_ij = p_ij~(cdfn(mu[jrep2]-zgama) -
                            cdfn(mu[jrep2-1]-zgama));
        endfor;

        p_ij = p_ij~(1 - cdfn(mu[capJ-2]-zgama));

    elseif no_con eq 1;

        p_ij	= cdfn(mu[1]-zgama);

        for jrep2 (2,capJ-1,1);
	        p_ij = p_ij~(cdfn(mu[jrep2]-zgama) -
                        cdfn(mu[jrep2-1]-zgama));
        endfor;

        p_ij = p_ij~(1 - cdfn(mu[capJ-1]-zgama));

    endif;

    logl = sumr(d_ij .* ln(p_ij));

retp(logl);
endp;

		/* ORDERED PROBIT MODEL; PROCEEDURE FOR CLUSTER SE'S */

proc OPROBIT_se_proc(struct PV p, struct DS d);
local d_ij, z, b_probit, op_mu, zgama, p_ij, logL;

    /* DEFINE DATA */

    d_ij	= d[1].dataMatrix;    
    z 	    = d[2].dataMatrix;    

    /* DEFINE PARAMETERS */ 

    b_probit    = pvUnpack(p,"op_b");
    op_mu       = pvUnpack(p,"op_mu");

    zgama = z*b_probit;

    if no_con eq 0;

        p_ij        = 1-(cdfn(zgama));
        p_ij        = p_ij~(cdfn(op_mu[1]-zgama) - cdfn(-zgama));

        for jrep2 (2,capJ-2,1);
            p_ij = p_ij~(cdfn(op_mu[jrep2]-zgama) -
                            cdfn(op_mu[jrep2-1]-zgama));
        endfor;

        p_ij = p_ij~(1 - cdfn(op_mu[capJ-2]-zgama));

    elseif no_con eq 1;

        p_ij	= cdfn(op_mu[1]-zgama);

        for jrep2 (2,capJ-1,1);
	        p_ij = p_ij~(cdfn(op_mu[jrep2]-zgama) -
                        cdfn(op_mu[jrep2-1]-zgama));
        endfor;

        p_ij = p_ij~(1 - cdfn(op_mu[capJ-1]-zgama));

    endif;

    logL = sumr(d_ij .* ln(p_ij));

retp(logL);
endp;




                       /* GENERALISED ORDERED PROBIT MODEL */

proc gopMLE(params,data);
local y, zw, z, kz, w, kw, n, jrep, jrep2, d_ij, gama, mu, zgama, p_i1, p_icapj, p_irest, p_ij, logl, bands;
local theta, delta, mu_ij;

    /* DEFINE DATA */

    y   = data[.,1];
    zw  = data[.,3:cols(data)];
    z   = selif(zw',zvec')';   
    kz  = cols(z);
    w   = selif(zw',wvec')';   
    kw  = cols(w);
    y   = y - minc(y);                                          @ run y from 0 to J-1 @
    n   = rows(data);

    /* CONSTRUCT INDICATOR VARIABLE FOR j=J */

    d_ij        = zeros(n,1);

    for jrep (0,capJ-1,1);
            d_ij = d_ij~(y .eq jrep);
    endfor;

    d_ij = d_ij[.,2:capJ+1];
    

    /* DEFINE PARAMETERS */ 

    gama        = params[1:kz];
    
    if no_con eq 0;
 
        if gop_flex eq 0;

            theta   = params[kz+1:kz+capJ-2];   
            delta   = params[kz+capJ-2+1:rows(params)];

            mu_ij   = _mu_ij(theta|delta,w,capJ);

        elseif gop_flex eq 1;

            delta   = params[kz+1:rows(params)];
            mu_ij   = _mu_ij(delta,w,capJ); 

        endif;

    elseif no_con eq 1;

        if gop_flex eq 0;

            theta   = params[kz+1:kz+capJ-1];   
            delta   = params[kz+capJ-1+1:rows(params)];
            mu_ij   = _mu_ij(theta|delta,w,capJ); 

        elseif gop_flex eq 1;

            delta   = params[kz+1:rows(params)];
            mu_ij   = _mu_ij(delta,w,capJ); 

        endif;

    endif;


    /* DETERMINISTIC PART & PROBABILITIES */

    zgama = z*gama;

    if no_con eq 0;

        p_ij        = 1-(cdfn(zgama));
        p_ij        = p_ij~(cdfn(mu_ij[.,1]-zgama) - cdfn(-zgama));

        for jrep2 (2,capJ-2,1);
            p_ij = p_ij~(cdfn(mu_ij[.,jrep2]-zgama) -
                            cdfn(mu_ij[.,jrep2-1]-zgama));
        endfor;

        p_ij = p_ij~(1 - cdfn(mu_ij[.,capJ-2]-zgama));

    elseif no_con eq 1;

        p_ij	= cdfn(mu_ij[.,1]-zgama);

        for jrep2 (2,capJ-1,1);
	        p_ij = p_ij~(cdfn(mu_ij[.,jrep2]-zgama) -
                        cdfn(mu_ij[.,jrep2-1]-zgama));
        endfor;

        p_ij = p_ij~(1 - cdfn(mu_ij[.,capJ-1]-zgama));

    endif;

    if meanc(sumc(p_ij')) gt 1.0001 or meanc(sumc(p_ij')) lt .9999;
            errorlog "ERROR IN DEFINING ORDERED PROBIT PROBABILITIES; PROGRAM TERMINATED";
                        "mean probablitiy =";;meanc(sumc(p_ij'));stop;
    endif;

    logl = ln(sumc((d_ij .* p_ij)'));

retp(logl);
endp;




          /* MLE PROCEDURE FOR PROBIT EQUATION */

proc probml(beta,data1);
local infile2, f2, infile3, f3, x, xbeta, logl, y, rowsy;

    y = data1[.,1] .eq index;
    x = data1[.,3:cols(data1)];
    x = selif(x',xvec')';

    xbeta = x*beta;

    logl = y.*ln(cdfn(xbeta)) + ((1-y).*(ln(1-cdfn(xbeta))));

retp(logl);
endp;


                        /* INFLATED ORDERED PROBIT MODEL */

proc iopb_ml(params,data);
local y, xz, x, kx, z, kz, n, jrep, jrep2, d_ij, beta, muiop, xbeta, p_i1, p_icapj, p_irest, p_ij, logl, bands;
local gama, zgama, p_aug;

    /* DEFINE DATA */

    y       = data[.,1];
    xz      = data[.,3:cols(data)];
    x       = selif(xz',xvec')'; 
    kx      = cols(x);
    z       = selif(xz',zvec')';
    kz      = cols(z);
    n       = rows(y);


    /* DEFINE PARAMETERS */
        
    beta    = params[1:kx];
    gama    = params[kx+1:kx+kz];       
    muiop   = params[kx+kz+1:rows(params)]; 

    if rows(params) ne (rows(beta)+rows(muiop)+rows(gama));
            "ERROR: rows don't match - line 1992";stop;
    endif;


    /* CONSTRUCT INDICATOR VARIABLE FOR j=J */

    d_ij        = zeros(n,1);

    for jrep (0,capJ-1,1);
            d_ij = d_ij~(y .eq jrep);
    endfor;

    d_ij = d_ij[.,2:capJ+1];
    

    /* DETERMINISTIC PARTs & PROBABILITIES */

    xbeta = x*beta;
    zgama = z*gama;     

	if no_con eq 0;

		p_ij        = 1-(cdfn(zgama));
		p_ij        = p_ij~(cdfn(muiop[1]-zgama) - cdfn(-zgama));

		if capJ gt 3;

			for jrep2 (2,capJ-2,1);
					p_ij = p_ij~(cdfn(muiop[jrep2]-zgama) -
                            cdfn(muiop[jrep2-1]-zgama));
			endfor;

		endif;

		p_ij    = p_ij~(1 - cdfn(muiop[capJ-2]-zgama));

	else;
		
        p_ij	= cdfn(muiop[1]-zgama);

        for jrep2 (2,capJ-1,1);
	        p_ij = p_ij~(cdfn(muiop[jrep2]-zgama) -
                        cdfn(muiop[jrep2-1]-zgama));
        endfor;

        p_ij = p_ij~(1 - cdfn(muiop[capJ-1]-zgama));
		
	endif;	

	p_aug   = (1-cdfn(xbeta)) + (p_ij[.,index+1] .* (cdfn(xbeta))); 
	p_ij    = p_ij .* ((cdfn(xbeta)) .*. ones(1,capJ));
	p_ij[.,index+1] = p_aug;		

    if meanc(sumc(p_ij')) gt 1.0001 or meanc(sumc(p_ij')) lt .9999;
            errorlog "ERROR IN DEFINING ORDERED PROBIT PROBABILITIES; PROGRAM TERMINATED";
                        "mean probablitiy =";;meanc(sumc(p_ij'));stop;
    endif;

    logl = ln(sumc((d_ij .* p_ij)'));

retp(logl);
endp;


		/* INFLATED ORDERED PROBIT MODEL; PROCEEDURE FOR CLUSTER SE'S */

proc IOP_se_proc(struct PV p, struct DS d);
local d_ij, x, z, gama, op_b, muiop, xbeta, zgama, p_ij, p_aug, logL;

    /* DEFINE DATA */

    d_ij	= d[1].dataMatrix;    
    x 	    = d[2].dataMatrix;    
    z 	    = d[3].dataMatrix;    

    /* DEFINE PARAMETERS */ 

    gama    = pvUnpack(p,"gama");
    op_b    = pvUnpack(p,"op_b");
    muiop   = pvUnpack(p,"muiop");

    /* DETERMINISTIC PARTs & PROBABILITIES */

    xbeta = x*op_b;
    zgama = z*gama;     

	if no_con eq 0;

		p_ij        = 1-(cdfn(zgama));
		p_ij        = p_ij~(cdfn(muiop[1]-zgama) - cdfn(-zgama));

		if capJ gt 3;

			for jrep2 (2,capJ-2,1);
					p_ij = p_ij~(cdfn(muiop[jrep2]-zgama) -
                            cdfn(muiop[jrep2-1]-zgama));
			endfor;

		endif;

		p_ij    = p_ij~(1 - cdfn(muiop[capJ-2]-zgama));

	else;
		
        p_ij	= cdfn(muiop[1]-zgama);

        for jrep2 (2,capJ-1,1);
	        p_ij = p_ij~(cdfn(muiop[jrep2]-zgama) -
                        cdfn(muiop[jrep2-1]-zgama));
        endfor;

        p_ij = p_ij~(1 - cdfn(muiop[capJ-1]-zgama));
		
	endif;	

	p_aug   = (1-cdfn(xbeta)) + (p_ij[.,index+1] .* (cdfn(xbeta))); 
	p_ij    = p_ij .* ((cdfn(xbeta)) .*. ones(1,capJ));
	p_ij[.,index+1] = p_aug;		

    logL = ln(sumc((d_ij .* p_ij)'));
    
retp(logL);
endp;




                        /* GENERALISED ZERO INFLATED ORDERED PROBIT MODEL */

proc giopb_ml(params,data);
local y, xz, x, z, w, n, jrep, jrep2, d_ij, beta, mugiop, xbeta, p_i1, p_icapj, p_irest, p_ij, logl, bands;
local gama, zgama, p_aug, mu_param;

    /* DEFINE DATA */

    y       = data[.,1];
    xz      = data[.,3:cols(data)];
    x       = selif(xz',xvec')'; 
    z       = selif(xz',zvec')';
    w       = selif(xz',wvec')';

    n       = rows(y);

    /* DEFINE PARAMETERS */
        
    beta        = params[1:kx];
    gama        = params[kx+1:kx+kz];       
    mu_param    = params[kx+kz+1:rows(params)];
    mugiop      = _mu_ij(mu_param,w,capJ);     

    if rows(params) ne (rows(beta)+rows(mu_param)+rows(gama));
            "ERROR: rows don't match - line 577";stop;
    endif;


    /* CONSTRUCT INDICATOR VARIABLE FOR j=J */

    d_ij        = zeros(n,1);

    for jrep (0,capJ-1,1);
            d_ij = d_ij~(y .eq jrep);
    endfor;

    d_ij = d_ij[.,2:capJ+1];
    

    /* DETERMINISTIC PARTs & PROBABILITIES */

    xbeta = x*beta;
    zgama = z*gama;     

    p_ij        = 1-(cdfn(zgama));
    p_ij        = p_ij~(cdfn(mugiop[.,1]-zgama) - cdfn(-zgama));

    if capJ gt 3;

        for jrep2 (2,capJ-2,1);
                p_ij = p_ij~(cdfn(mugiop[.,jrep2]-zgama) -
                            cdfn(mugiop[.,jrep2-1]-zgama));
        endfor;

    endif;

    p_ij    = p_ij~(1 - cdfn(mugiop[.,capJ-2]-zgama));
    p_aug   = (1-cdfn(xbeta)) + (p_ij[.,index+1] .* (cdfn(xbeta))); 
    p_ij    = p_ij .* ((cdfn(xbeta)) .*. ones(1,capJ));
    p_ij[.,index+1] = p_aug;

    if meanc(sumc(p_ij')) gt 1.0001 or meanc(sumc(p_ij')) lt .9999;
            errorlog "ERROR IN DEFINING ORDERED PROBIT PROBABILITIES; PROGRAM TERMINATED";
                        "mean probablitiy =";;meanc(sumc(p_ij'));stop;
    endif;

    logl = ln(sumc((d_ij .* p_ij)'));

retp(logl);
endp;



                        /* INFLATED ORDERED PROBIT MODEL: RANDOM EFFECTS BY QUADRATURE */

proc iopb_ml_quad(params,data);
local id, y, xz, x, kx, z, kz, n, jrep, jrep2, d_ij, beta, muiop, xbeta, p_i1, p_icapj, p_irest, p_ij, logl, bands;
local gama, zgama, p_aug, panel_r, prob, r, prob_temp, p_vec, sel;
local rate_1, dummies, a_star, a, r_diff, b_rest, quad, xn, wn, theta;


    /* DEFINE DATA */

    y       = data[.,1];
    id      = data[.,2];
    xz      = data[.,3:cols(data)];
    x       = selif(xz',xvec')'; 
    kx      = cols(x);
    z       = selif(xz',zvec')';
    kz      = cols(z);
    n       = rows(y);


    /* DEFINE PARAMETERS */
        
    beta    = params[1:kx];
    gama    = params[kx+1:kx+kz];
    muiop   = params[kx+kz+1:rows(params)-1];
    panel_r = params[rows(params)];


    /* CONSTRUCT INDICATOR VARIABLE FOR j=J */

    d_ij        = zeros(n,1);

    for jrep (0,capJ-1,1);
        d_ij = d_ij~(y .eq jrep);
    endfor;

    d_ij = d_ij[.,2:capJ+1];
    
    xn = -4.4688738939305818~
	        4.4688738939305818~
		    -3.8694479048601227~
		    3.8694479048601227~
		    -3.1769991619799560~
		    3.1769991619799560~
		    -2.5462021578474814~
		    2.5462021578474814~
		    -1.951787990916254~
		    1.951787990916254~
		    -1.3802585391988808~
		    1.3802585391988808~
		    -0.8229514491446559~
		    0.8229514491446559~
		    -0.2734810461381525~
		    0.2734810461381525;	


    wn = 0.0000000002654807~
		    0.0000000002654807~
		    0.0000002320980845~
		    0.0000002320980845~
		    0.0000271186009254~
		    0.0000271186009254~
		    0.0009322840086242~
		    0.0009322840086242~
		    0.0128803115355100~
		    0.0128803115355100~
		    0.0838100413989858~
		    0.0838100413989858~
		    0.2806474585285337~
		    0.2806474585285337~
		    0.5079294790166137~
		    0.5079294790166137;

    theta = ((2*panel_r)/(1-panel_r))^0.5;

    prob    = 0;

    r = 1; 
    do until r > cols(xn);


        /* DETERMINISTIC PARTs & PROBABILITIES */

        if RE eq 1;

            xbeta = (x*beta);
		    zgama = (z*gama) + (xn[r] .* theta);

        elseif RE eq 2;

            xbeta = (x*beta) + (xn[r] .* theta);
		    zgama = (z*gama);

        endif;

        p_ij        = 1-(cdfn(zgama));
        p_ij        = p_ij~(cdfn(muiop[1]-zgama) - cdfn(-zgama));

        if capJ gt 3;

            for jrep2 (2,capJ-2,1);
                    p_ij = p_ij~(cdfn(muiop[jrep2]-zgama) -
                            cdfn(muiop[jrep2-1]-zgama));
            endfor;

        endif;

        p_ij    = p_ij~(1 - cdfn(muiop[capJ-2]-zgama));
        p_aug   = (1-cdfn(xbeta)) + (p_ij[.,index+1] .* (cdfn(xbeta))); 
        p_ij    = p_ij .* ((cdfn(xbeta)) .*. ones(1,capJ));
        p_ij[.,index+1] = p_aug;

        if meanc(sumc(p_ij')) gt 1.0001 or meanc(sumc(p_ij')) lt .9999;
            errorlog "ERROR IN DEFINING ORDERED PROBIT PROBABILITIES; PROGRAM TERMINATED";
                        "mean probablitiy =";;meanc(sumc(p_ij'));stop;
        endif;

        /* PRODUCT OVER INDIVIDUALS */

        prob_temp   = (sumc((d_ij .* p_ij)'));
        p_vec       = prodc(selif(prob_temp,id .eq minc(id)));

        for i_rep (minc(id)+1,maxc(id),1);
            sel     = id .eq i_rep;
            p_vec   = p_vec|prodc(selif(prob_temp,sel));
        endfor;

        prob = prob + (wn[r] .* p_vec);

        r = r+1 ; 
  
  endo;

retp(ln(prob./sqrt(pi)));
endp;



                        /* INFLATED ORDERED PROBIT MODEL: RANDOM EFFECTS IN BOTH EQUATIONS */

proc iopbsae_ml(params,data);
local y, idvec, xz, x, kx, z, kz, n, jrep, jrep2, d_ij, beta, muiop, xbeta, p_i1, p_icapj, p_irest, p_ij, logl, bands;
local gama, zgama, p_aug, r, sig_z, sig_x, sig_ae, prob, chol_cov, ai_ei, prob_temp, p_vec, sel, ai_matZ, ai_matX, ai_Z, ai_X;

    /* DEFINE DATA */

    y           = data[.,1];
    idvec       = data[.,2];
    xz          = data[.,3:2+cols(xvec)];
    ai_matZ     = data[.,3+cols(xvec):2+cols(xvec)+M];
    ai_matX     = data[.,3+cols(xvec)+M:cols(data)];
    x           = selif(xz',xvec')'; 
    kx          = cols(x);
    z           = selif(xz',zvec')';
    kz          = cols(z);
    n           = rows(y);


    /* CONSTRUCT INDICATOR VARIABLE FOR j=J */

    d_ij        = zeros(n,1);

    for jrep (0,capJ-1,1);
            d_ij = d_ij~(y .eq jrep);
    endfor;

    d_ij = d_ij[.,2:capJ+1];
    

    /* DEFINE PARAMETERS */
        
    beta    = params[1:kx];
    gama    = params[kx+1:kx+kz];
    muiop   = params[kx+kz+1:rows(params)-2];
    sig_z   = abs(params[rows(params)-1]);        
    sig_x   = abs(params[rows(params)]);
           
    if rows(params) ne (rows(beta)+rows(muiop)+rows(gama)+rows(sig_z)+rows(sig_x));
            "ERROR: rows don't match - line 2220";stop; 
    endif;

    ai_Z = 0;    
    ai_X = 0; 

    prob = 0;

    r = 1; 
    do until r > M;

        ai_Z   = ai_matZ[.,r] .* sig_z;
        ai_X   = ai_matX[.,r] .* sig_x;


        /* DETERMINISTIC PARTs & PROBABILITIES */

        zgama = (z*gama) + ai_Z;     
        xbeta = (x*beta) + ai_X;

        p_ij        = 1-(cdfn(zgama));
        p_ij        = p_ij~(cdfn(muiop[1]-zgama) - cdfn(-zgama));

        if capJ gt 3;

            for jrep2 (2,capJ-2,1);
                    p_ij = p_ij~(cdfn(muiop[jrep2]-zgama) -
                                cdfn(muiop[jrep2-1]-zgama));
            endfor;

        endif;

        p_ij    = p_ij~(1 - cdfn(muiop[capJ-2]-zgama));
        p_aug   = (1-cdfn(xbeta)) + (p_ij[.,index+1] .* (cdfn(xbeta))); 
        p_ij    = p_ij .* ((cdfn(xbeta)) .*. ones(1,capJ));
        p_ij[.,index+1] = p_aug;

        if meanc(sumc(p_ij')) gt 1.0001 or meanc(sumc(p_ij')) lt .9999;
                errorlog "ERROR IN DEFINING ORDERED PROBIT PROBABILITIES; PROGRAM TERMINATED";
                        "mean probablitiy =";;meanc(sumc(p_ij'));stop;
        endif;

        /* PRODUCT OVER INDIVIDUALS FOR SIMULATED APPROACH */

        prob_temp   = (sumc((d_ij .* p_ij)'));
        p_vec       = prodc(selif(prob_temp,idvec .eq minc(idvec)));

        for i_rep (minc(idvec)+1,maxc(idvec),1);
            sel     = idvec .eq i_rep;
            p_vec   = p_vec|prodc(selif(prob_temp,sel));
        endfor;

        prob = prob + p_vec;

        r = r+1 ; 

    endo;
   
    prob = prob ./ M;

retp(ln(prob));
endp;


                        /* INFLATED ORDERED PROBIT MODEL: FULL RANDOM EFFECTS IN BOTH EQUATIONS */

proc iopbREfull_ml(params,data);
local y, idvec, xz, x, kx, z, kz, n, jrep, jrep2, d_ij, beta, muiop, xbeta, p_i1, p_icapj, p_irest, p_ij, logl, bands;
local gama, zgama, p_aug, r, sig_z, sig_x, sig_ae, prob, prob_temp, p_vec, sel;
local sig_zx, ai_matZ, ai_matX, ai_Z, ai_X;

    /* DEFINE DATA */

    y           = data[.,1];
    idvec       = data[.,2];
    xz          = data[.,3:2+cols(xvec)];
    ai_matZ     = data[.,3+cols(xvec):2+cols(xvec)+M];
    ai_matX     = data[.,3+cols(xvec)+M:cols(data)];
    x           = selif(xz',xvec')'; 
    kx          = cols(x);
    z           = selif(xz',zvec')';
    kz          = cols(z);
    n           = rows(y);


    /* CONSTRUCT INDICATOR VARIABLE FOR j=J */

    d_ij        = zeros(n,1);

    for jrep (0,capJ-1,1);
            d_ij = d_ij~(y .eq jrep);
    endfor;

    d_ij = d_ij[.,2:capJ+1];
    

    /* DEFINE PARAMETERS */
        
    beta    = params[1:kx];
    gama    = params[kx+1:kx+kz];
    muiop   = params[kx+kz+1:rows(params)-3];
    sig_z   = params[rows(params)-2];        
    sig_x   = params[rows(params)-1];
    sig_zx  = params[rows(params)];
           
    if rows(params) ne (rows(beta)+rows(muiop)+rows(gama)+rows(sig_z) + rows(sig_x) + rows(sig_zx));
            "ERROR: rows don't match - line 2327";stop; 
    endif;

    ai_Z         = 0;    
    ai_X         = 0; 

    prob        = 0;

    r = 1; 
    do until r > M;

        ai_Z = ai_matZ[.,r];
        ai_X = ai_matX[.,r];

        /* DETERMINISTIC PARTs & PROBABILITIES */

        zgama = (z*gama) + (ai_Z .* sig_z);     
        xbeta = (x*beta) + ((ai_X .* sig_x) + (ai_Z .* sig_zx));


        p_ij        = 1-(cdfn(zgama));
        p_ij        = p_ij~(cdfn(muiop[1]-zgama) - cdfn(-zgama));

        if capJ gt 3;

            for jrep2 (2,capJ-2,1);
                p_ij = p_ij~(cdfn(muiop[jrep2]-zgama) -
                            cdfn(muiop[jrep2-1]-zgama));
            endfor;

        endif;

        p_ij    = p_ij~(1 - cdfn(muiop[capJ-2]-zgama));
        p_aug   = (1-cdfn(xbeta)) + (p_ij[.,index+1] .* (cdfn(xbeta))); 
        p_ij    = p_ij .* ((cdfn(xbeta)) .*. ones(1,capJ));
        p_ij[.,index+1] = p_aug;


        /* PRODUCT OVER INDIVIDUALS FOR SIMULATED APPROACH */

        prob_temp   = (sumc((d_ij .* p_ij)'));
        p_vec       = prodc(selif(prob_temp,idvec .eq minc(idvec)));

        for i_rep (minc(idvec)+1,maxc(idvec),1);
            sel     = idvec .eq i_rep;
            p_vec   = p_vec|prodc(selif(prob_temp,sel));
        endfor;

        prob = prob + p_vec;

        r = r+1 ; 

    endo;
   
    prob = prob ./ M;

retp(ln(prob));
endp;


                        /* CORRELATED INFLATED ORDERED PROBIT MODEL */

proc iopbc_ml(params,data);
local y, id, xz, idvec, x, kx, z, kz, n, jrep, jrep2, d_ij, beta, muiopc, xbeta, p_i1, p_icapj, p_irest, p_ij, p_aug, logl, bands;
local gama, zgama, rho, prob;

    /* DEFINE DATA */

    y       = data[.,1];
    id      = data[.,2];
    xz      = data[.,3:cols(data)];
    x       = selif(xz',xvec')'; 
    kx      = cols(x);
    z       = selif(xz',zvec')';
    kz      = cols(z);
    n       = rows(y);


    /* CONSTRUCT INDICATOR VARIABLE FOR j=J */

    d_ij        = zeros(n,1);

    for jrep (0,capJ-1,1);
            d_ij = d_ij~(y .eq jrep);
    endfor;

    d_ij = d_ij[.,2:capJ+1];
    

    /* DEFINE PARAMETERS */
        
    beta    = params[1:kx];
    gama    = params[kx+1:kx+kz];       
    muiopc  = params[kx+kz+1:rows(params)-1]; 
    rho     = params[rows(params)];

    if rows(params) ne (rows(beta)+rows(muiopc)+rows(gama)+1);
            "ERROR: rows don't match - MLE for corelated IOP_RE, line 2426";stop;
    endif;

    /* DETERMINISTIC PARTs & PROBABILITIES */

    xbeta = (x*beta);
    zgama = (z*gama);     

    p_ij        = cdfbvn(xbeta,-zgama,-rho);
    p_ij        = p_ij~(cdfbvn(xbeta,muiopc[1]-zgama,-rho) - cdfbvn(xbeta,-zgama,-rho));

    if capJ gt 3;

        for jrep2 (2,capJ-2,1);
            p_ij = p_ij~(cdfbvn(xbeta,muiopc[jrep2]-zgama,-rho) -
                            cdfbvn(xbeta,muiopc[jrep2-1]-zgama,-rho));
        endfor;

    endif;
    
    p_ij    = p_ij~(cdfbvn(xbeta,zgama-muiopc[capJ-2],rho));
    p_aug   = 1-cdfn(xbeta);
    p_ij[.,index+1] = p_ij[.,index+1] + p_aug;

    if meanc(sumc(p_ij')) gt 1.0001 or meanc(sumc(p_ij')) lt .9999;
        errorlog "ERROR IN DEFINING CORRELATED INFLATED ORDERED PROBIT PROBABILITIES IN MLE PROC; PROGRAM TERMINATED";
                 "mean probablitiy =";;meanc(sumc(p_ij'));?;
                 "parameters";params;stop;
    endif;

    logl = ln(sumc((d_ij .* p_ij)'));

retp(logl);
endp;

		/* INFLATED ORDERED PROBIT MODEL; PROCEEDURE FOR CLUSTER SE'S */

proc IOPC_se_proc(struct PV p, struct DS d);
local d_ij, x, z, gama, op_b, muiopc, xbeta, zgama, p_ij, p_aug, logL, rho;

    /* DEFINE DATA */

    d_ij	= d[1].dataMatrix;    
    x 	    = d[2].dataMatrix;    
    z 	    = d[3].dataMatrix;    

    /* DEFINE PARAMETERS */ 

    gama    = pvUnpack(p,"gama");
    op_b    = pvUnpack(p,"op_b");
    muiopc  = pvUnpack(p,"muiopc");
    rho     = pvUnpack(p,"rho");    

    /* DETERMINISTIC PARTs & PROBABILITIES */

    xbeta = (x*op_b);
    zgama = (z*gama);     

    p_ij        = cdfbvn(xbeta,-zgama,-rho);
    p_ij        = p_ij~(cdfbvn(xbeta,muiopc[1]-zgama,-rho) - cdfbvn(xbeta,-zgama,-rho));

    if capJ gt 3;

        for jrep2 (2,capJ-2,1);
            p_ij = p_ij~(cdfbvn(xbeta,muiopc[jrep2]-zgama,-rho) -
                            cdfbvn(xbeta,muiopc[jrep2-1]-zgama,-rho));
        endfor;

    endif;
    
    p_ij    = p_ij~(cdfbvn(xbeta,zgama-muiopc[capJ-2],rho));
    p_aug   = 1-cdfn(xbeta);
    p_ij[.,index+1] = p_ij[.,index+1] + p_aug;

    if meanc(sumc(p_ij')) gt 1.0001 or meanc(sumc(p_ij')) lt .9999;
        errorlog "ERROR IN DEFINING CORRELATED INFLATED ORDERED PROBIT PROBABILITIES IN MLE PROC; PROGRAM TERMINATED";
                 "mean probablitiy =";;meanc(sumc(p_ij'));?;
    endif;

    logl = ln(sumc((d_ij .* p_ij)'));

    
retp(logL);
endp;





                        /* CORRELATED INFLATED ORDERED PROBIT MODEL: FULL RANDOM EFFECTS IN BOTH EQUATIONS */

proc iopbcRE_ml(params,data);
local y, idvec, xz, x, kx, z, kz, n, jrep, jrep2, d_ij, beta, muiopc, xbeta, p_i1, p_icapj, p_irest, p_ij, logl, bands;
local gama, zgama, p_aug, r, sig_z, sig_x, prob, prob_temp, p_vec, sel, ai_matX, ai_matZ, ai_Z, ai_X;
local rho;

    /* DEFINE DATA */

    y           = data[.,1];
    idvec       = data[.,2];
    xz          = data[.,3:2+cols(xvec)];
    ai_matZ     = data[.,3+cols(xvec):2+cols(xvec)+M];
    ai_matX     = data[.,3+cols(xvec)+M:cols(data)];
    x           = selif(xz',xvec')'; 
    kx          = cols(x);
    z           = selif(xz',zvec')';
    kz          = cols(z);
    n           = rows(y);


    /* CONSTRUCT INDICATOR VARIABLE FOR j=J */

    d_ij        = zeros(n,1);

    for jrep (0,capJ-1,1);
            d_ij = d_ij~(y .eq jrep);
    endfor;

    d_ij = d_ij[.,2:capJ+1];
    

    /* DEFINE PARAMETERS */
        
    beta    = params[1:kx];
    gama    = params[kx+1:kx+kz];
    muiopc  = params[kx+kz+1:rows(params)-3];
    sig_z   = params[rows(params)-2];        
    sig_x   = params[rows(params)-1];
    rho     = params[rows(params)];
           
    if rows(params) ne (rows(beta)+rows(muiopc)+rows(gama)+rows(sig_z) + rows(sig_x) + rows(rho));
            "ERROR: rows don't match - line 2751";stop; 
    endif;

   
    ai_Z    = 0;    
    ai_X    = 0;    

    prob    = 0;

    r = 1; 
    do until r > M;

        ai_Z = ai_matZ[.,r];
        ai_X = ai_matX[.,r];

        /* DETERMINISTIC PARTs & PROBABILITIES */

        zgama = (z*gama) + (ai_Z .* sig_z);     
        xbeta = (x*beta) + (ai_X .* sig_x);

        p_ij        = cdfbvn(xbeta,-zgama,-rho);
        p_ij        = p_ij~(cdfbvn(xbeta,muiopc[1]-zgama,-rho) - cdfbvn(xbeta,-zgama,-rho));

        if capJ gt 3;

            for jrep2 (2,capJ-2,1);
                p_ij = p_ij~(cdfbvn(xbeta,muiopc[jrep2]-zgama,-rho) -
                            cdfbvn(xbeta,muiopc[jrep2-1]-zgama,-rho));
            endfor;

        endif;
    
        p_ij    = p_ij~(cdfbvn(xbeta,zgama-muiopc[capJ-2],rho));
        p_aug   = 1-cdfn(xbeta);
        p_ij[.,index+1] = p_ij[.,index+1] + p_aug;


        /* PRODUCT OVER INDIVIDUALS FOR SIMULATED APPROACH */

        prob_temp   = (sumc((d_ij .* p_ij)'));
        p_vec       = prodc(selif(prob_temp,idvec .eq minc(idvec)));

        for i_rep (minc(idvec)+1,maxc(idvec),1);
            sel     = idvec .eq i_rep;
            p_vec   = p_vec|prodc(selif(prob_temp,sel));
        endfor;

        prob = prob + p_vec;

        r = r+1 ; 

    endo;
   
    prob = prob ./ M;

retp(ln(prob));
endp;



                        /* CORRELATED INFLATED ORDERED PROBIT MODEL: FULL CORRELATED RANDOM EFFECTS IN BOTH EQUATIONS */

proc iopbcREfull_ml(params,data);
local y, idvec, xz, x, kx, z, kz, n, jrep, jrep2, d_ij, beta, muiopc, xbeta, p_i1, p_icapj, p_irest, p_ij, logl, bands;
local gama, zgama, p_aug, r, sig_z, sig_x, sig_ae, prob, prob_temp, p_vec, sel;
local sig_zx, rho, ai_matX, ai_matZ, ai_Z, ai_X;

    /* DEFINE DATA */

    y           = data[.,1];
    idvec       = data[.,2];
    xz          = data[.,3:2+cols(xvec)];
    ai_matZ     = data[.,3+cols(xvec):2+cols(xvec)+M];
    ai_matX     = data[.,3+cols(xvec)+M:cols(data)];
    x           = selif(xz',xvec')'; 
    kx          = cols(x);
    z           = selif(xz',zvec')';
    kz          = cols(z);
    n           = rows(y);


    /* CONSTRUCT INDICATOR VARIABLE FOR j=J */

    d_ij        = zeros(n,1);

    for jrep (0,capJ-1,1);
            d_ij = d_ij~(y .eq jrep);
    endfor;

    d_ij = d_ij[.,2:capJ+1];
    

    /* DEFINE PARAMETERS */
        
    beta    = params[1:kx];
    gama    = params[kx+1:kx+kz];
    muiopc  = params[kx+kz+1:rows(params)-4];
    sig_z   = params[rows(params)-3];        
    sig_x   = params[rows(params)-2];
    sig_zx  = params[rows(params)-1];
    rho     = params[rows(params)];
           
    if rows(params) ne (rows(beta)+rows(muiopc)+rows(gama)+rows(sig_z) + rows(sig_x) + rows(sig_zx) + rows(rho));
            "ERROR: rows don't match - line 28557";stop; 
    endif;

    ai_Z    = 0;    
    ai_X    = 0;
 
    prob    = 0;

    r = 1; 
    do until r > M;

        ai_Z = ai_matZ[.,r];
        ai_X = ai_matX[.,r];

        /* DETERMINISTIC PARTs & PROBABILITIES */

        zgama = (z*gama) + (ai_Z .* sig_z);     
        xbeta = (x*beta) + ((ai_X .* sig_x) + (ai_Z .* sig_zx));

        p_ij        = cdfbvn(xbeta,-zgama,-rho);
        p_ij        = p_ij~(cdfbvn(xbeta,muiopc[1]-zgama,-rho) - cdfbvn(xbeta,-zgama,-rho));

        if capJ gt 3;

            for jrep2 (2,capJ-2,1);
                p_ij = p_ij~(cdfbvn(xbeta,muiopc[jrep2]-zgama,-rho) -
                            cdfbvn(xbeta,muiopc[jrep2-1]-zgama,-rho));
            endfor;

        endif;
    
        p_ij    = p_ij~(cdfbvn(xbeta,zgama-muiopc[capJ-2],rho));
        p_aug   = 1-cdfn(xbeta);
        p_ij[.,index+1] = p_ij[.,index+1] + p_aug;


        /* PRODUCT OVER INDIVIDUALS FOR SIMULATED APPROACH */

        prob_temp   = (sumc((d_ij .* p_ij)'));
        p_vec       = prodc(selif(prob_temp,idvec .eq minc(idvec)));

        for i_rep (minc(idvec)+1,maxc(idvec),1);
            sel     = idvec .eq i_rep;
            p_vec   = p_vec|prodc(selif(prob_temp,sel));
        endfor;

        prob = prob + p_vec;

        r = r+1 ; 

    endo;
   
    prob = prob ./ M;

retp(ln(prob));
endp;


        /* CORRELATED GENERALISED INFLATED ORDERED PROBIT MODEL: FULL CORRELATED RANDOM EFFECTS IN BOTH EQUATIONS */

proc giopbcREfull_ml(params,data);
local y, idvec, wxz, x, z, w, n, jrep, jrep2, d_ij, beta, muiopc, xbeta, p_i1, p_icapj, p_irest, p_ij, logl, bands;
local gama, zgama, p_aug, r, sig_z, sig_x, sig_ae, prob, prob_temp, p_vec, sel;
local sig_zx, rho, mu_param, mugiopg, ai_matX, ai_matZ, ai_Z, ai_X;

    /* DEFINE DATA */

    y           = data[.,1];
    idvec       = data[.,2];
    wxz         = data[.,3:2+cols(xvec)];
    ai_matZ     = data[.,3+cols(xvec):2+cols(xvec)+M];
    ai_matX     = data[.,3+cols(xvec)+M:cols(data)];
    x           = selif(wxz',xvec')'; 
    z           = selif(wxz',zvec')';
    w           = selif(wxz',wvec')';
    n           = rows(y);


    /* CONSTRUCT INDICATOR VARIABLE FOR j=J */

    d_ij        = zeros(n,1);

    for jrep (0,capJ-1,1);
            d_ij = d_ij~(y .eq jrep);
    endfor;

    d_ij = d_ij[.,2:capJ+1];
    

    /* DEFINE PARAMETERS */
        
    beta        = params[1:kx];
    gama        = params[kx+1:kx+kz];
    mu_param    = params[kx+kz+1:rows(params)-4];
    mugiopg     = _mu_ij(mu_param,w,capJ);     
    sig_z       = params[rows(params)-3];        
    sig_x       = params[rows(params)-2];
    sig_zx      = params[rows(params)-1];
    rho         = params[rows(params)];
           
    if rows(params) ne (rows(beta)+rows(mu_param)+rows(gama)+rows(sig_z) + rows(sig_x) + rows(sig_zx) + rows(rho));
            "ERROR: rows don't match - line 3319";stop; 
    endif;

    ai_Z    = 0;    
    ai_X    = 0;
 
    prob    = 0;

    r = 1; 
    do until r > M;

        ai_Z = ai_matZ[.,r];
        ai_X = ai_matX[.,r];

        /* DETERMINISTIC PARTs & PROBABILITIES */

        zgama = (z*gama) + (ai_Z .* sig_z);     
        xbeta = (x*beta) + ((ai_X .* sig_x) + (ai_Z .* sig_zx));

        p_ij        = cdfbvn(xbeta,-zgama,-rho);
        p_ij        = p_ij~(cdfbvn(xbeta,mugiopg[.,1]-zgama,-rho) - cdfbvn(xbeta,-zgama,-rho));

        if capJ gt 3;

            for jrep2 (2,capJ-2,1);
                p_ij = p_ij~(cdfbvn(xbeta,mugiopg[.,jrep2]-zgama,-rho) -
                            cdfbvn(xbeta,mugiopg[.,jrep2-1]-zgama,-rho));
            endfor;

        endif;
    
        p_ij    = p_ij~(cdfbvn(xbeta,zgama-mugiopg[.,capJ-2],rho));
        p_aug   = 1-cdfn(xbeta);
        p_ij[.,index+1] = p_ij[.,index+1] + p_aug;


        /* PRODUCT OVER INDIVIDUALS FOR SIMULATED APPROACH */

        prob_temp   = (sumc((d_ij .* p_ij)'));
        p_vec       = prodc(selif(prob_temp,idvec .eq minc(idvec)));

        for i_rep (minc(idvec)+1,maxc(idvec),1);
            sel     = idvec .eq i_rep;
            p_vec   = p_vec|prodc(selif(prob_temp,sel));
        endfor;

        prob = prob + p_vec;

        r = r+1 ; 

    endo;
   
    prob = prob ./ M;

retp(ln(prob));
endp;



                /* PROBABILITY PROCEDURES FOR ME'S AND SE'S(ME'S) */

        /* USE GENERIC METHOD FOR ME'S AND SE'S */

proc 10 = mes(vcov,gama,capJ,me_model,xbar);
local G_ME, G_P, me_ses, p1, p2, h, xbargama, mes, i, g, gp;
local prob, probability, prob_se, me0_np, me0_p, me0_se_np, me0_se_p;
local jloop, G_MEnp, G_MEp, G_Pnp, G_Pp, mes_np, mes_p, prob_np, prob_p; 
local me_np_se, prob_np_se, me_p_se, prob_p_se, mark;
local G_MEw, G_w, mes_w, me_w_se, prob_w, prob_w_se;
local mes_con, mes_con_se;
clear mes_w, me_w_se, mes_con, mes_con_se;

clearg k,kg;

    if rows(xbar) eq 1;
        xbar = xbar';
    endif;

    k  = rows(xbar);
    kg = rows(gama);


    /* STACK THE XBARS AND PARAMETERS*/
    
    xbargama = xbar|gama;

    /* WHICH MODEL? */
 
    let mtype_me = probit ordered op_infl gop_infl 
                    iop_REX iop_REZ iop_RE iop_REfull iopc iopc_RE iopc_REfull giopc_REfull gop; 
    mtype_me = indcv(me_model,mtype_me); 


    /* INITIALISE MATRICES */

    G_ME    = zeros(1,rows(gama));
    G_P     = zeros(1,rows(gama));
    mes     = zeros(1,1);
    prob	= zeros(1,1);

    G_MEnp  = zeros(1,rows(gama));
    G_MEp   = zeros(1,rows(gama));
    G_Pnp   = zeros(1,rows(gama));
    G_Pp    = zeros(1,rows(gama));

    clear mes,me_ses,mes_np,mes_p,me_np_se,me_p_se,prob,prob_se,mes_con,mes_con_se;


    /* CONSTRUCT P1 & P2 FOR EXTRACTING SECOND ORDER DERIVATIVES WRT PARAMETERS */

    p1=k+1;

    for i(rows(xbar)+2,rows(xbargama),1);
         p1=p1|i;
    endfor;

    p2=1;

    for i(2,rows(xbar),1);
        p2=p2|i;
    endfor;

    /* ESTIMATING MEs AND SEs*/

    if mtype_me eq 1;                                  @ BINARY PROBIT @

        h           = hessp(&probit_p,xbargama);
        h           = submat(h,p1',p2')'; 
        g           = gradp(&probit_p,xbargama);
	    probability = probit_p(xbargama);
        gp          = gradp(&probit_p,xbargama);
        gp          = submat(gp',p1,0)';

        G_ME	    = h;
        G_P 	    = gp;

	    mes         = mes|g[1:rows(xbar)]';
        me_ses	    = G_ME*vcov*G_ME';
        me_ses 	    = sqrt(diag(me_ses));
	    prob        = prob~probability';
        mes         = mes[2:rows(mes)];
        prob        = prob[.,2:cols(prob)];
        prob_se	    = G_P*vcov*G_P';
        prob_se  	= sqrt(diag(prob_se));

    else;

        if mtype_me eq 2;                              @ ORDERED PROBIT @

            jj          = 1;

            do while jj le capJ;

                h           = hessp(&ordp_p,xbargama);
                g           = gradp(&ordp_p,xbargama);
	            probability = ordp_p(xbargama);
                gp          = gradp(&ordp_p,xbargama);

                h           = submat(h,p1',p2')'; 
                gp          = submat(gp',p1,0)';

                G_ME        = G_ME|h;
                G_P         = G_P|gp;   
	            mes         = mes|g[1:rows(xbar)]';
	            prob        = prob~probability';

                jj          = jj+1;
    
            endo;

            G_ME	    = G_ME[2:rows(G_ME),.];
            G_P 	    = G_P[2:rows(G_P),.];
            me_ses	    = G_ME*vcov*G_ME';
            me_ses 	    = sqrt(diag(me_ses));
            me_ses 	    = reshape(me_ses,capJ,k)';
            mes         = mes[2:rows(mes)];
            mes         = reshape(mes,capJ,k)';
        
            prob        = prob[.,2:cols(prob)];
            prob_se	    = G_P*vcov*G_P';
            prob_se  	= sqrt(diag(prob_se));

        elseif mtype_me eq 13;                              @ GENERALISED ORDERED PROBIT @

            jj          = 1;

            do while jj le capJ;

                h           = hessp(&gop_p,xbargama);
                g           = gradp(&gop_p,xbargama);
	            probability = ordp_p(xbargama);
                gp          = gradp(&gop_p,xbargama);

                h           = submat(h,p1',p2')'; 
                gp          = submat(gp',p1,0)';

                G_ME        = G_ME|h;
                G_P         = G_P|gp;   
	            mes         = mes|g[1:rows(xbar)]';
	            prob        = prob~probability';

                jj          = jj+1;
    
            endo;

            G_ME	    = G_ME[2:rows(G_ME),.];
            G_P 	    = G_P[2:rows(G_P),.];
            me_ses	    = G_ME*vcov*G_ME';
            me_ses 	    = sqrt(diag(me_ses));
            me_ses 	    = reshape(me_ses,capJ,k)';
            mes         = mes[2:rows(mes)];
            mes         = reshape(mes,capJ,k)';
        
            prob        = prob[.,2:cols(prob)];
            prob_se	    = G_P*vcov*G_P';
            prob_se  	= sqrt(diag(prob_se));


        elseif mtype_me eq 4;      @ GENERALISED INFLATED ORDERED PROBIT @

            jj          = 1;

            do while jj le capJ;

                p_0 = 0;
                
                h           = hessp(&giop_p,xbargama);
                g           = gradp(&giop_p,xbargama);
	            probability = giop_p(xbargama);
                gp          = gradp(&giop_p,xbargama);
                h           = submat(h,p1',p2')'; 
                gp          = submat(gp',p1,0)';

                G_ME        = G_ME|h;
                G_P         = G_P|gp;   
	            mes         = mes|g[1:rows(xbar)]';
	            prob        = prob~probability';
               
                jj          = jj+1;
    
            endo;

            G_ME	    = G_ME[2:rows(G_ME),.];
            G_P 	    = G_P[2:rows(G_P),.];
            me_ses	    = G_ME*vcov*G_ME';
            me_ses 	    = sqrt(diag(me_ses));
            me_ses 	    = reshape(me_ses,capJ,k)';
            mes          = mes[2:rows(mes)];
            mes          = reshape(mes,capJ,k)';
            prob         = prob[.,2:cols(prob)];
            prob_se	    = G_P*vcov*G_P';
            prob_se      = sqrt(diag(prob_se));

            /* reinitialise matrices for w-only MEs */

            G_ME    = zeros(1,rows(gama));
            G_P     = zeros(1,rows(gama));
            mes_w   = zeros(1,1);
            prob_w	= zeros(1,1);

            jj          = 1;

            do while jj le capJ;

                p_0 = 3;
                
                h           = hessp(&giop_p,xbargama);
                g           = gradp(&giop_p,xbargama);
	            probability = giop_p(xbargama);
                gp          = gradp(&giop_p,xbargama);
                h           = submat(h,p1',p2')'; 
                gp          = submat(gp',p1,0)';

                G_ME        = G_ME|h;
                G_P         = G_P|gp;   
	            mes_w       = mes_w|g[1:rows(xbar)]';
	            prob_w      = prob_w~probability';
               
                jj          = jj+1;
    
            endo;

            G_ME	    = G_ME[2:rows(G_ME),.];
            G_P 	    = G_P[2:rows(G_P),.];
            me_w_se     = G_ME*vcov*G_ME';
            me_w_se 	= sqrt(diag(me_w_se));
            me_w_se 	= reshape(me_w_se,capJ,k)';
            mes_w       = mes_w[2:rows(mes_w)];
            mes_w       = reshape(mes_w,capJ,k)';
            prob_w      = prob_w[.,2:cols(prob_w)];
            prob_w_se	= G_P*vcov*G_P';
            prob_w_se  	= sqrt(diag(prob_w_se));


            /* reinitialise matrices for CONDITIONAL ON "PARTICIPATION" MEs */

            G_ME    = zeros(1,rows(gama));
            mes_con = zeros(1,1);

            jj          = 1;

            do while jj le capJ;

                p_0 = -1;
                
                h           = hessp(&giop_p,xbargama);
                g           = gradp(&giop_p,xbargama);
                h           = submat(h,p1',p2')'; 

                G_ME        = G_ME|h;
	         mes_con     = mes_con|g[1:rows(xbar)]';
              
                jj          = jj+1;
    
            endo;

            G_ME	    = G_ME[2:rows(G_ME),.];
            mes_con_se   = G_ME*vcov*G_ME';
            mes_con_se   = sqrt(diag(mes_con_se));
            mes_con_se   = reshape(mes_con_se,capJ,k)';
            mes_con      = mes_con[2:rows(mes_con)];
            mes_con      = reshape(mes_con,capJ,k)';
     
     
            p_0 = 1;            @ DECOMPOSE TOTAL ME OF INFLATED OUTCOME INTO CONSITIUENT PARTS @                                          

            h           = hessp(&giop_p,xbargama);
            g           = gradp(&giop_p,xbargama);
	        prob_np     = giop_p(xbargama);
            gp          = gradp(&giop_p,xbargama);
            h           = submat(h,p1',p2')'; 
            gp          = submat(gp',p1,0)';

            G_MEnp     = h;
            G_Pnp      = gp;   
	        mes_np     = g[1:rows(xbar)]';

            me_np_se	= G_MEnp*vcov*G_MEnp';
            me_np_se 	= sqrt(diag(me_np_se));
            prob_np_se	= G_Pnp*vcov*G_Pnp';
            prob_np_se  = sqrt(diag(prob_np_se));

            p_0 = 2;                @ DECOMPOSE TOTAL ME OF INFLATED OUTCOME INTO CONSITIUENT PARTS @

            h           = hessp(&giop_p,xbargama);
            g           = gradp(&giop_p,xbargama);
	        prob_p      = giop_p(xbargama);
            gp          = gradp(&giop_p,xbargama);
            h           = submat(h,p1',p2')'; 
            gp          = submat(gp',p1,0)';

            G_MEp       = h;
            G_Pp        = gp;   
	        mes_p       = g[1:rows(xbar)]';

            me_p_se	    = G_MEp*vcov*G_MEp';
            me_p_se 	= sqrt(diag(me_p_se));
            prob_p_se	= G_Pp*vcov*G_Pp';
            prob_p_se   = sqrt(diag(prob_p_se));


            //let mtype_me = 1.probit 2.ordered 3.op_infl 4.gop_infl 5.iop_REX 6.iop_REZ 7.iop_RE 8.iop_REfull 9.iopc 10.iopc_RE 11.iopc_REfull 12.giopc_REfull;

        elseif mtype_me eq 3 or mtype_me eq 5 or mtype_me eq 6 or mtype_me eq 7 or mtype_me eq 8;      @ INFLATED ORDERED PROBIT; INCLUDES RE VERSIONS @

            jj          = 1;

            do while jj le capJ;

                p_0 = 0;
                
                h           = hessp(&iop_p,xbargama);
                g           = gradp(&iop_p,xbargama);
	         probability = iop_p(xbargama);
                gp          = gradp(&iop_p,xbargama);
                h           = submat(h,p1',p2')'; 
                gp          = submat(gp',p1,0)';

                G_ME        = G_ME|h;
                G_P         = G_P|gp;   
	            mes         = mes|g[1:rows(xbar)]';
	            prob        = prob~probability';
               
                jj          = jj+1;
    
            endo;

            G_ME	    = G_ME[2:rows(G_ME),.];
            G_P 	    = G_P[2:rows(G_P),.];
            me_ses	    = G_ME*vcov*G_ME';
            me_ses 	    = sqrt(diag(me_ses));
            me_ses 	    = reshape(me_ses,capJ,k)';
            mes         = mes[2:rows(mes)];
            mes         = reshape(mes,capJ,k)';
            prob        = prob[.,2:cols(prob)];
            prob_se	    = G_P*vcov*G_P';
            prob_se  	= sqrt(diag(prob_se));


            /* reinitialise matrices for CONDITIONAL ON "PARTICIPATION" MEs */

            G_ME    = zeros(1,rows(gama));
            mes_con = zeros(1,1);

            jj          = 1;

            do while jj le capJ;

                p_0 = -1;
                
                h           = hessp(&iop_p,xbargama);
                g           = gradp(&iop_p,xbargama);
                h           = submat(h,p1',p2')'; 

                G_ME        = G_ME|h;
	         mes_con     = mes_con|g[1:rows(xbar)]';
              
                jj          = jj+1;
    
            endo;

            G_ME	    = G_ME[2:rows(G_ME),.];
            mes_con_se   = G_ME*vcov*G_ME';
            mes_con_se   = sqrt(diag(mes_con_se));
            mes_con_se   = reshape(mes_con_se,capJ,k)';
            mes_con      = mes_con[2:rows(mes_con)];
            mes_con      = reshape(mes_con,capJ,k)';


            p_0 = 1;        @ DECOMPOSE TOTAL ME OF INFLATED OUTCOME INTO CONSITIUENT PARTS @
            
            h           = hessp(&iop_p,xbargama);
            g           = gradp(&iop_p,xbargama);
	     prob_np     = iop_p(xbargama);
            gp          = gradp(&iop_p,xbargama);
            h           = submat(h,p1',p2')'; 
            gp          = submat(gp',p1,0)';

            G_MEnp     = h;
            G_Pnp      = gp;   
	     mes_np     = g[1:rows(xbar)]';

            me_np_se	  = G_MEnp*vcov*G_MEnp';
            me_np_se   = sqrt(diag(me_np_se));
            prob_np_se = G_Pnp*vcov*G_Pnp';
            prob_np_se = sqrt(diag(prob_np_se));

            p_0 = 2;        @ DECOMPOSE TOTAL ME OF INFLATED OUTCOME INTO CONSITIUENT PARTS @

            h           = hessp(&iop_p,xbargama);
            g           = gradp(&iop_p,xbargama);
	     prob_p      = iop_p(xbargama);
            gp          = gradp(&iop_p,xbargama);
            h           = submat(h,p1',p2')'; 
            gp          = submat(gp',p1,0)';

            G_MEp       = h;
            G_Pp        = gp;   
	     mes_p       = g[1:rows(xbar)]';

            me_p_se	    = G_MEp*vcov*G_MEp';
            me_p_se 	    = sqrt(diag(me_p_se));
            prob_p_se    = G_Pp*vcov*G_Pp';
            prob_p_se    = sqrt(diag(prob_p_se));

    // let mtype_me = 1.probit 2.ordered 3.op_infl 4.gop_infl 5.iop_REX 6.iop_REZ 7.iop_RE 8.iop_REfull 9.iopc 10.iopc_RE 11.iopc_REfull 12.giopc_REfull; 

        elseif mtype_me eq 9 or mtype_me eq 10 or mtype_me eq 11;                          @ CORRELATED INFLATED ORDERED PROBIT: INCLUDES RANDOM EFFECTS VERSIONS @

            jj          = 1;

            do while jj le capJ;

                p_0 = 0;
                
                h           = hessp(&iopc_p,xbargama);
                g           = gradp(&iopc_p,xbargama);
	            probability = iopc_p(xbargama);
                gp          = gradp(&iopc_p,xbargama);
                h           = submat(h,p1',p2')'; 
                gp          = submat(gp',p1,0)';

                G_ME        = G_ME|h;
                G_P         = G_P|gp;   
	            mes         = mes|g[1:rows(xbar)]';

	            prob        = prob~probability';
                
                jj          = jj+1;
    
            endo;

            G_ME	    = G_ME[2:rows(G_ME),.];
            G_P 	    = G_P[2:rows(G_P),.];
            me_ses	    = G_ME*vcov*G_ME';
            me_ses 	    = sqrt(diag(me_ses));
            me_ses 	    = reshape(me_ses,capJ,k)';
            mes         = mes[2:rows(mes)];
            mes         = reshape(mes,capJ,k)';
            prob        = prob[.,2:cols(prob)];
            prob_se	    = G_P*vcov*G_P';
            prob_se  	= sqrt(diag(prob_se));


            /* reinitialise matrices for CONDITIONAL ON "PARTICIPATION" MEs */

            G_ME    = zeros(1,rows(gama));
            mes_con = zeros(1,1);

            jj          = 1;

            do while jj le capJ;

                p_0 = -1;
                
                h           = hessp(&iopc_p,xbargama);
                g           = gradp(&iopc_p,xbargama);
                h           = submat(h,p1',p2')'; 

                G_ME        = G_ME|h;
	         mes_con     = mes_con|g[1:rows(xbar)]';
              
                jj          = jj+1;
    
            endo;

            G_ME	    = G_ME[2:rows(G_ME),.];
            mes_con_se   = G_ME*vcov*G_ME';
            mes_con_se   = sqrt(diag(mes_con_se));
            mes_con_se   = reshape(mes_con_se,capJ,k)';
            mes_con      = mes_con[2:rows(mes_con)];
            mes_con      = reshape(mes_con,capJ,k)';


            p_0 = 1;        @ DECOMPOSE TOTAL ME OF INFLATED OUTCOME INTO CONSITIUENT PARTS @

            h           = hessp(&iopc_p,xbargama);
            g           = gradp(&iopc_p,xbargama);
			prob_np     = iopc_p(xbargama);
            gp          = gradp(&iopc_p,xbargama);
            h           = submat(h,p1',p2')'; 
            gp          = submat(gp',p1,0)';

            G_MEnp     = h;
            G_Pnp      = gp;   
	        mes_np     = g[1:rows(xbar)]';

            me_np_se	= G_MEnp*vcov*G_MEnp';
            me_np_se 	= sqrt(diag(me_np_se));
            prob_np_se	= G_Pnp*vcov*G_Pnp';
            prob_np_se  = sqrt(diag(prob_np_se));

            p_0 = 2;        @ DECOMPOSE TOTAL ME OF INFLATED OUTCOME INTO CONSITIUENT PARTS @

            h           = hessp(&iopc_p,xbargama);
            g           = gradp(&iopc_p,xbargama);
	        prob_p      = iopc_p(xbargama);
            gp          = gradp(&iopc_p,xbargama);
            h           = submat(h,p1',p2')'; 
            gp          = submat(gp',p1,0)';

            G_MEp       = h;
            G_Pp        = gp;   
			mes_p       = g[1:rows(xbar)]';

            me_p_se	    = G_MEp*vcov*G_MEp';
            me_p_se 	    = sqrt(diag(me_p_se));
            prob_p_se    = G_Pp*vcov*G_Pp';
            prob_p_se    = sqrt(diag(prob_p_se));

        elseif mtype_me eq 12;      @ FULL RANDOM CORRELATED EFFECTS CORRELATED GENERALISED INFLATED ORDERED PROBIT @

            jj          = 1;

            do while jj le capJ;

                p_0 = 0;
                
                h           = hessp(&giopcfullRE_p,xbargama);
                g           = gradp(&giopcfullRE_p,xbargama);
	            probability = giopcfullRE_p(xbargama);
                gp          = gradp(&giopcfullRE_p,xbargama);
                h           = submat(h,p1',p2')'; 
                gp          = submat(gp',p1,0)';

                G_ME        = G_ME|h;
                G_P         = G_P|gp;   
	         mes         = mes|g[1:rows(xbar)]';
	         prob        = prob~probability';
               
                jj          = jj+1;
    
            endo;

            G_ME	    = G_ME[2:rows(G_ME),.];
            G_P 	    = G_P[2:rows(G_P),.];
            me_ses	    = G_ME*vcov*G_ME';
            me_ses 	    = sqrt(diag(me_ses));
            me_ses 	    = reshape(me_ses,capJ,k)';
            mes         = mes[2:rows(mes)];
            mes         = reshape(mes,capJ,k)';
            prob        = prob[.,2:cols(prob)];
            prob_se	   = G_P*vcov*G_P';
            prob_se     = sqrt(diag(prob_se));


            /* reinitialise matrices for CONDITIONAL ON "PARTICIPATION" MEs */

            G_ME    = zeros(1,rows(gama));
            mes_con = zeros(1,1);

            jj          = 1;

            do while jj le capJ;

                p_0 = -1;
                
                h           = hessp(&giopcfullRE_p,xbargama);
                g           = gradp(&giopcfullRE_p,xbargama);
                h           = submat(h,p1',p2')'; 

                G_ME        = G_ME|h;
	         mes_con     = mes_con|g[1:rows(xbar)]';
              
                jj          = jj+1;
    
            endo;

            G_ME	    = G_ME[2:rows(G_ME),.];
            mes_con_se   = G_ME*vcov*G_ME';
            mes_con_se   = sqrt(diag(mes_con_se));
            mes_con_se   = reshape(mes_con_se,capJ,k)';
            mes_con      = mes_con[2:rows(mes_con)];
            mes_con      = reshape(mes_con,capJ,k)';


            /* reinitialise matrices for w-only MEs */

            G_ME    = zeros(1,rows(gama));
            G_P     = zeros(1,rows(gama));
            mes_w   = zeros(1,1);
            prob_w	= zeros(1,1);

            jj          = 1;

            do while jj le capJ;

                p_0 = 3;
                
                h           = hessp(&giopcfullRE_p,xbargama);
                g           = gradp(&giopcfullRE_p,xbargama);
	            probability = giopcfullRE_p(xbargama);
                gp          = gradp(&giopcfullRE_p,xbargama);
                h           = submat(h,p1',p2')'; 
                gp          = submat(gp',p1,0)';

                G_ME        = G_ME|h;
                G_P         = G_P|gp;   
	            mes_w       = mes_w|g[1:rows(xbar)]';
	            prob_w      = prob_w~probability';
               
                jj          = jj+1;
    
            endo;

            G_ME	    = G_ME[2:rows(G_ME),.];
            G_P 	    = G_P[2:rows(G_P),.];
            me_w_se     = G_ME*vcov*G_ME';
            me_w_se 	= sqrt(diag(me_w_se));
            me_w_se 	= reshape(me_w_se,capJ,k)';
            mes_w       = mes_w[2:rows(mes_w)];
            mes_w       = reshape(mes_w,capJ,k)';
            prob_w      = prob_w[.,2:cols(prob_w)];
            prob_w_se	= G_P*vcov*G_P';
            prob_w_se  	= sqrt(diag(prob_w_se));

            p_0 = 1;        @ DECOMPOSE TOTAL ME OF INFLATED OUTCOME INTO CONSITIUENT PARTS @

            h           = hessp(&giopcfullRE_p,xbargama);
            g           = gradp(&giopcfullRE_p,xbargama);
	        prob_np     = giopcfullRE_p(xbargama);
            gp          = gradp(&giopcfullRE_p,xbargama);
            h           = submat(h,p1',p2')'; 
            gp          = submat(gp',p1,0)';

            G_MEnp     = h;
            G_Pnp      = gp;   
	        mes_np     = g[1:rows(xbar)]';

            me_np_se	= G_MEnp*vcov*G_MEnp';
            me_np_se 	= sqrt(diag(me_np_se));
            prob_np_se	= G_Pnp*vcov*G_Pnp';
            prob_np_se  = sqrt(diag(prob_np_se));

            p_0 = 2;        @ DECOMPOSE TOTAL ME OF INFLATED OUTCOME INTO CONSITIUENT PARTS @

            h           = hessp(&giopcfullRE_p,xbargama);
            g           = gradp(&giopcfullRE_p,xbargama);
	        prob_p      = giopcfullRE_p(xbargama);
            gp          = gradp(&giopcfullRE_p,xbargama);
            h           = submat(h,p1',p2')'; 
            gp          = submat(gp',p1,0)';

            G_MEp       = h;
            G_Pp        = gp;   
	        mes_p       = g[1:rows(xbar)]';

            me_p_se	    = G_MEp*vcov*G_MEp';
            me_p_se 	= sqrt(diag(me_p_se));
            prob_p_se	= G_Pp*vcov*G_Pp';
            prob_p_se   = sqrt(diag(prob_p_se));

        endif;

    endif;     
    
retp(mes,me_ses,mes_np~mes_p,me_np_se~me_p_se,mes_w,me_w_se,mes_con,mes_con_se,prob,prob_se);
endp;


proc 1 = probit_p(xbargama);                /* CONSTRUCT PROBIT PROBABILITIES */
local probs, gama;

    xbar    = xbargama[1:k];
    gama    = xbargama[k+1:rows(xbargama)];
	probs	= cdfn(xbar'*gama);

retp(probs);
endp;


	/* CONSTRUCT ORDERED PROBIT PROBABILITIES */

proc 1 = ordp_p(xbargama);
local jrep, jrep2, beta, mu, xbeta, p_ij,check;
local pord, i, p_a, p_b, gama;

    xbar        = xbargama[1:k];
    gama        = xbargama[k+1:k+kg];
    beta		= gama[1:k];
    mu		    = gama[k+1:rows(gama)]; 

    if rows(gama) ne (rows(beta)+rows(mu));
	    "error line 4192";stop;
    endif;

    xbeta = xbar'*beta;

    if no_con eq 0;

        p_ij        = 1-(cdfn(xbeta));
        p_ij        = p_ij~(cdfn(mu[1]-xbeta) - cdfn(-xbeta));

        for jrep2 (2,capJ-2,1);
            p_ij = p_ij~(cdfn(mu[jrep2]-xbeta) -
                            cdfn(mu[jrep2-1]-xbeta));
        endfor;

        pord = p_ij~(1 - cdfn(mu[capJ-2]-xbeta));

    elseif no_con eq 1;

        p_ij	= cdfn(mu[1]-xbeta);

        for jrep2 (2,capJ-1,1);
	        p_ij = p_ij~(cdfn(mu[jrep2]-xbeta) -
                        cdfn(mu[jrep2-1]-xbeta));
        endfor;

        pord = p_ij~(1 - cdfn(mu[capJ-1]-xbeta));

    endif;

    check = meanc(sumc(pord'));
    if check gt 1.0001 or check lt .9999;
	    errorlog "ERROR IN DEFINING ORDERED PROBIT PROBABILITIES; PROGRAM TERMINATED";
			"mean probablitiy =";;check;stop;
    endif;

retp(pord[.,jj]);
endp;


	/* CONSTRUCT GENERALISED ORDERED PROBIT PROBABILITIES */

proc 1 = gop_p(xbargama);
local y, zw, z, w, n, jrep, jrep2, d_ij, gama, beta, mu, zgama, p_i1, p_icapj, p_irest, p_ij, logl, bands;
local mtype, theta, delta, mu_ij, pgop, check, x_only,wvec_gop,xvec_gop;

    /* DEFINE PARAMETERS */ 

    xbar        = xbargama[1:k];
    gama        = xbargama[k+1:k+kg];

    if cols(xbar) eq 1;
        xbar = xbar';
    endif;



    w       = selif(xbar',wvec')'; 
    z       = selif(xbar',zvec')';

    if no_con eq 0;
 
        theta   = gama[kz+1:kz+capJ-2];   
        delta   = gama[kz+capJ-2+1:rows(gama)];

        mu_ij   = _mu_ij(theta|delta,w,capJ);

    elseif no_con eq 1;

        if gop_flex eq 0;

            theta   = gama[kz+1:kz+capJ-1];   
            delta   = gama[kz+capJ-1+1:rows(gama)];
            mu_ij   = _mu_ij(theta|delta,w,capJ); 

        elseif gop_flex eq 1;

            delta   = gama[kz+1:rows(gama)];
            mu_ij   = _mu_ij(delta,w,capJ); 

        endif;

    endif;

    gama        = gama[1:kz];


    /* DETERMINISTIC PART & PROBABILITIES */

    zgama = z*gama;

    if no_con eq 0;

        p_ij        = 1-(cdfn(zgama));
        p_ij        = p_ij~(cdfn(mu_ij[.,1]-zgama) - cdfn(-zgama));

        for jrep2 (2,capJ-2,1);
            p_ij = p_ij~(cdfn(mu_ij[.,jrep2]-zgama) -
                            cdfn(mu_ij[.,jrep2-1]-zgama));
        endfor;

        pgop = p_ij~(1 - cdfn(mu_ij[.,capJ-2]-zgama));

    elseif no_con eq 1;

        p_ij	= cdfn(mu_ij[.,1]-zgama);

        for jrep2 (2,capJ-1,1);
	        p_ij = p_ij~(cdfn(mu_ij[.,jrep2]-zgama) -
                        cdfn(mu_ij[.,jrep2-1]-zgama));
        endfor;

        pgop = p_ij~(1 - cdfn(mu_ij[.,capJ-1]-zgama));

    endif;

    check = meanc(sumc(pgop'));
    if check gt 1.0001 or check lt .9999;
	    errorlog "ERROR IN DEFINING ORDERED PROBIT PROBABILITIES; PROGRAM TERMINATED";
			"mean probablitiy =";;check;stop;
    endif;

retp(pgop[.,jj]);
endp;




                 /* CONSTRUCT INFLATED ORDERED PROBIT PROBABLITIES: INCLUDES PANEL VARIANTS */

proc iop_p(xbargama);
local xz, x, z, w, jrep, jrep2, beta, mu, xbeta, p_i1, p_icapj, p_irest, p_ij, p_aug, bands;
local gama, zgama, phi, rho, params, sig_z, sig_x, sig_zx, simulate, ai_X, ai_Z, p_cond;
clear sig_z, sig_x, sig_zx, ai_X, ai_Z;


    xz          = xbargama[1:kall];
    params      = xbargama[kall+1:rows(xbargama)];

    x 	= selif(xz,xvec')';
    z	= selif(xz,zvec')';

    /* DEFINE PARAMETERS */

    // let mtype_me = 3.op_infl 4.gop_infl 5.iop_REX 6.iop_REZ 7.iop_RE 8.iop_REfull 9.iopc 10.iopc_RE 11.iopc_REfull 12.giopc_REfull; 
    // let mtype = 2.iop 3.giop 4.iop_REZ 5.iop_REX 6.iop_RE 7.iop_REfull 8.iopc 9.iopc_RE 10.iopc_REfull 11.giopc_REfull; 

    simulate =  sim_ME * (mtype .eq (mtype_me-1)); 

    if mtype_me eq 3;
        
        beta    = params[1:kx];        
        gama    = params[kx+1:kx+kz];       
        mu      = params[kx+kz+1:rows(params)]; 

        if rows(params) ne (rows(beta)+rows(mu)+rows(gama));
            "ERROR: rows don't match in proc iop_p";stop;
        endif;
    
    elseif mtype_me eq 5 or mtype_me eq 6;

        beta    = params[1:kx];        
        gama    = params[kx+1:kx+kz];       
        mu      = params[kx+kz+1:rows(params)-1]; 

        if rows(params) ne (rows(beta)+rows(mu)+rows(gama)+1);
            "ERROR: rows don't match in proc iop_p";stop;
        endif;

    elseif mtype_me eq 7;

        beta    = params[1:kx];        
        gama    = params[kx+1:kx+kz];       
        mu      = params[kx+kz+1:rows(params)-2];

        if simulate eq 1; 

            sig_z   = params[rows(params)-1];        
            sig_x   = params[rows(params)];
            sig_zx  0;

        endif;

        if rows(params) ne (rows(beta)+rows(mu)+rows(gama)+2);
            "ERROR: rows don't match in proc iop_p";stop;
        endif;

    elseif mtype_me eq 8;

        beta    = params[1:kx];        
        gama    = params[kx+1:kx+kz];       
        mu      = params[kx+kz+1:rows(params)-3]; 

        if simulate eq 1;
 
            sig_z   = params[rows(params)-2];        
            sig_x   = params[rows(params)-1];
            sig_zx  = params[rows(params)];

        endif;

        if rows(params) ne (rows(beta)+rows(mu)+rows(gama)+3);
            "ERROR: rows don't match in proc iop_p";stop;
        endif;

    endif;


    /* DETERMINISTIC PARTs & PROBABILITIES */

    if simulate eq 0;

        zgama = (z*gama);     
        xbeta = (x*beta);

    elseif simulate eq 1;

        zgama = (z*gama) + (ai_Z .* sig_z);     
        xbeta = (x*beta) + ((ai_X .* sig_x) + (ai_Z .* sig_zx));

    endif;

    p_ij        = 1-(cdfn(zgama));
    p_ij        = p_ij~(cdfn(mu[1]-zgama) - cdfn(-zgama));

    if capJ gt 3;

        for jrep2 (2,capJ-2,1);
                p_ij = p_ij~(cdfn(mu[jrep2]-zgama) -
                            cdfn(mu[jrep2-1]-zgama));
        endfor;

    endif;

    p_ij            = p_ij~(1 - cdfn(mu[capJ-2]-zgama));
    p_aug           = (1-cdfn(xbeta)) + (p_ij[.,index+1] .* (cdfn(xbeta)));
    p_cond          = p_ij; 
    p_ij            = p_ij .* ((cdfn(xbeta)) .*. ones(1,capJ));
    p_ij[.,index+1] = p_aug;

    if p_0 eq 0;
        retp(p_ij[jj]);
    elseif p_0 eq 1;
        retp((1-cdfn(xbeta)));
    elseif p_0 eq 2;
        retp(p_aug - (1-cdfn(xbeta)));
    elseif p_0 eq -1;
        retp(p_cond[jj]);
    endif;

endp;


                 /* CONSTRUCT GENERALISED INFLATED ORDERED PROBIT PROBABLITIES */

proc giop_p(xbargama);
local wxz, x, z, w, jrep, jrep2, beta, mu_param, mugiop, xbeta, p_i1, p_icapj, p_irest, p_ij, p_aug, bands;
local gama, zgama, phi, params, simulate, p_cond;


    wxz         = xbargama[1:kall];
    params      = xbargama[kall+1:rows(xbargama)];

    if p_0 lt 3;
        x       = selif(wxz,xvec')'; 
        z       = selif(wxz,zvec')';
    else;
        x       = xbar_me;
        z       = zbar_me;
    endif;

    w       = selif(wxz,wvec')';

    if rows(x) ne 1;
        x = x';
    endif; 

    if rows(z) ne 1;
        z = z';
    endif; 

    if rows(w) ne 1;
        w = w';
    endif; 


    /* DEFINE PARAMETERS */

    // let mtype_me = 3.op_infl 4.gop_infl 5.iop_REX 6.iop_REZ 7.iop_RE 8.iop_REfull 9.iopc 10.iopc_RE 11.iopc_REfull 12.giopc_REfull; 
    // let mtype = 2.iop 3.giop 4.iop_REZ 5.iop_REX 6.iop_RE 7.iop_REfull 8.iopc 9.iopc_RE 10.iopc_REfull 11.giopc_REfull; 

    simulate =  sim_ME * (mtype .eq (mtype_me-1)); 
        
    beta        = params[1:kx];
    gama        = params[kx+1:kx+kz];       
    mu_param    = params[kx+kz+1:rows(params)];
    mugiop      = _mu_ij(mu_param,w,capJ);     

    if rows(params) ne (rows(beta)+rows(mu_param)+rows(gama));
            "ERROR: rows don't match - line 3682";stop;
    endif;
   

    /* DETERMINISTIC PARTs & PROBABILITIES */

    xbeta   = x*beta;
    zgama   = z*gama;     

    p_ij        = 1-(cdfn(zgama));
    p_ij        = p_ij~(cdfn(mugiop[.,1]-zgama) - cdfn(-zgama));

    if capJ gt 3;

        for jrep2 (2,capJ-2,1);
                p_ij = p_ij~(cdfn(mugiop[.,jrep2]-zgama) -
                            cdfn(mugiop[.,jrep2-1]-zgama));
        endfor;

    endif;

    p_ij            = p_ij~(1 - cdfn(mugiop[.,capJ-2]-zgama));
    p_aug           = (1-cdfn(xbeta)) + (p_ij[.,index+1] .* (cdfn(xbeta)));
    p_cond          = p_ij; 
    p_ij            = p_ij .* ((cdfn(xbeta)) .*. ones(1,capJ));
    p_ij[.,index+1] = p_aug;

    if p_0 eq 0 or p_0 eq 3;
        retp(p_ij[jj]);
    elseif p_0 eq 1;
        retp((1-cdfn(xbeta)));
    elseif p_0 eq 2;
        retp(p_aug - (1-cdfn(xbeta)));
    elseif p_0 eq -1;
        retp(p_cond[jj]);
    endif;

endp;


                 /* CONSTRUCT GENERALISED INFLATED ORDERED PROBIT PROBABLITIES: FULL PANEL VARIANT */

proc giopcfullRE_p(xbargama);
local wxz, x, z, w, jrep, jrep2, beta, mu_param, mugiopg, xbeta, p_i1, p_icapj, p_irest, p_ij, p_aug, bands;
local gama, zgama, phi, params, sig_z, sig_x, sig_zx, rho, simulate, ai_X, ai_Z, p_cond;
clear sig_z, sig_x, sig_zx;

    wxz         = xbargama[1:kall];
    params      = xbargama[kall+1:rows(xbargama)];

    if p_0 lt 3;
        x       = selif(wxz,xvec')'; 
        z       = selif(wxz,zvec')';
    else;
        x       = xbar_me;
        z       = zbar_me;
    endif;

    w       = selif(wxz,wvec')';

    if rows(x) ne 1;
        x = x';
    endif; 

    if rows(z) ne 1;
        z = z';
    endif; 

    if rows(w) ne 1;
        w = w';
    endif; 


    /* DEFINE PARAMETERS */
        
    beta        = params[1:kx];
    gama        = params[kx+1:kx+kz];       
    mu_param    = params[kx+kz+1:rows(params)-4];
    mugiopg     = _mu_ij(mu_param,w,capJ);     
    sig_z       = params[rows(params)-3];        
    sig_x       = params[rows(params)-2];
    sig_zx      = params[rows(params)-1];
    rho         = params[rows(params)];


    if rows(params) ne (rows(beta)+rows(mu_param)+rows(gama)+4);
            "ERROR: rows don't match - line 4018";stop;
    endif;
   

    /* DETERMINISTIC PARTs & PROBABILITIES */

    // let mtype_me = 3.op_infl 4.gop_infl 5.iop_REX 6.iop_REZ 7.iop_RE 8.iop_REfull 9.iopc 10.iopc_RE 11.iopc_REfull 12.giopc_REfull; 
    // let mtype = 2.iop 3.giop 4.iop_REZ 5.iop_REX 6.iop_RE 7.iop_REfull 8.iopc 9.iopc_RE 10.iopc_REfull 11.giopc_REfull; 

    simulate =  sim_ME * (mtype .eq (mtype_me-1)); 

    zgama = (z*gama) + (ai_Z .* sig_z);     
    xbeta = (x*beta) + ((ai_X .* sig_x) + (ai_Z .* sig_zx));

    p_ij        = 1-(cdfn(zgama));
    p_ij        = p_ij~(cdfn(mugiopg[.,1]-zgama) - cdfn(-zgama));

    if capJ gt 3;

        for jrep2 (2,capJ-2,1);
                p_ij = p_ij~(cdfn(mugiopg[.,jrep2]-zgama) -
                            cdfn(mugiopg[.,jrep2-1]-zgama));
        endfor;

    endif;

    p_ij            = p_ij~(1 - cdfn(mugiopg[.,capJ-2]-zgama));
    p_aug           = (1-cdfn(xbeta)) + (p_ij[.,index+1] .* (cdfn(xbeta))); 
    p_ij            = p_ij .* ((cdfn(xbeta)) .*. ones(1,capJ));
    p_ij[.,index+1] = p_aug;

    if p_0 eq 0 or p_0 eq 3;
        retp(p_ij[jj]);
    elseif p_0 eq 1;
        retp((1-cdfn(xbeta)));
    elseif p_0 eq 2;
        retp(p_aug - (1-cdfn(xbeta)));
    endif;

endp;




                 /* CONSTRUCT CORRELATED INFLATED ORDERED PROBIT PROBABLITIES */

proc iopc_p(xbargama);
local xz, x, z, jrep, jrep2, beta, mu, xbeta, p_aug, p_icapj, p_irest, p_ij, rho, bands; 
local gama, zgama, phi, wphi, params, sig_z, sig_x, sig_zx, simulate, ai_X, ai_Z, p_cond;
clear sig_z, sig_x, sig_zx;

    xz      = xbargama[1:kall];
    params  = xbargama[kall+1:rows(xbargama)];

    x 	= selif(xz,xvec')';
    z	= selif(xz,zvec')';

    beta    = params[1:kx];
    gama    = params[kx+1:kx+kz];       
    rho     = params[rows(params)];

    simulate =  sim_ME * (mtype .eq (mtype_me-1)); 

    // let mtype_me = 3.op_infl 4.gop_infl 5.iop_REX 6.iop_REZ 7.iop_RE 8.iop_REfull 9.iopc 10.iopc_RE 11.iopc_REfull 12.giopc_REfull; 

    if mtype_me eq 9;

        mu      = params[kx+kz+1:rows(params)-1];

        if rows(params) ne (rows(beta)+rows(mu)+rows(gama)+1);
            "ERROR: rows don't match in proc iopc_p";stop;
        endif;

    elseif mtype_me eq 10;

        mu      = params[kx+kz+1:rows(params)-3]; 
        sig_z   = params[rows(params)-2];        
        sig_x   = params[rows(params)-1];              
        sig_zx  = 0;

        if rows(params) ne (rows(beta)+rows(mu)+rows(gama)+3);
            "ERROR: rows don't match in proc iopc_p";stop;
        endif;

    elseif mtype_me eq 11;

        mu      = params[kx+kz+1:rows(params)-4]; 
        sig_z   = params[rows(params)-3];        
        sig_x   = params[rows(params)-2];
        sig_zx  = params[rows(params)-1];              

        if rows(params) ne (rows(beta)+rows(mu)+rows(gama)+4);
            "ERROR: rows don't match in proc iopc_p";stop;
        endif;

    endif;


    /* DETERMINISTIC PARTs & PROBABILITIES */

    if simulate eq 1;

        zgama = (z*gama) + (ai_Z .* sig_z);     
        xbeta = (x*beta) + ((ai_X .* sig_x) + (ai_Z .* sig_zx));

    else;

        zgama = (z*gama);     
        xbeta = (x*beta);

    endif;

    p_ij        = cdfbvn(xbeta,-zgama,-rho);
    p_ij        = p_ij~(cdfbvn(xbeta,mu[1]-zgama,-rho) - cdfbvn(xbeta,-zgama,-rho));

    if capJ gt 3;

        for jrep2 (2,capJ-2,1);
                p_ij = p_ij~(cdfbvn(xbeta,mu[jrep2]-zgama,-rho) -
                                cdfbvn(xbeta,mu[jrep2-1]-zgama,-rho));
        endfor;

    endif;
    
    p_ij            = p_ij~(cdfbvn(xbeta,zgama-mu[capJ-2],rho));
    p_cond          = p_ij ./ ((cdfn(xbeta)) .*. ones(1,capJ));
    p_aug           = 1-cdfn(xbeta);
    p_ij[.,index+1] = p_ij[.,index+1] + p_aug;

    if p_0 eq 0;
        retp(p_ij[jj]);
    elseif p_0 eq 1;
        retp(1-cdfn(xbeta));
    elseif p_0 eq 2;
        retp(p_ij[.,index+1] - p_aug);
    elseif p_0 eq -1;
        retp(p_cond[jj]);
    endif;

endp;

        /* PROCEDURE TO TURN CHOLESKY ELEMENTS INTO COVARIANCE MATRIX */

proc v_cov(params);
local chol_cov, cov_var;

//let mtype_me = 5.iop_REX 6.iop_REZ 7.iop_RE 8.iop_REfull 9.iopc 10.iopc_RE 11.iopc_REfull 12.giopc_REfull; 

    chol_cov      = eye(2);

    if mtype_me eq 7;

        cov_var = abs(params[rows(params)-1])|abs(params[rows(params)]);
        cov_var = (cov_var).^2;

    elseif mtype_me eq 10;

        cov_var = abs(params[rows(params)-2])|abs(params[rows(params)-1]);
        cov_var = (cov_var).^2;
        
    elseif mtype_me eq 8;

        chol_cov[1,1] = params[rows(params)-2];
        chol_cov[2,2] = params[rows(params)-1];
        chol_cov[1,2] = params[rows(params)];    

        cov_var = chol_cov'chol_cov;
        cov_var = vec(cov_var);
        
        cov_var = vec(cov_var);
        cov_var = cov_var[1]|cov_var[4]|cov_var[2];         @ in order s1, s2, s12 @

    elseif mtype_me eq 11;

        chol_cov[1,1] = params[rows(params)-3];
        chol_cov[2,2] = params[rows(params)-2];
        chol_cov[1,2] = params[rows(params)-1];    

        cov_var = chol_cov'chol_cov;
        cov_var = vec(cov_var);
        cov_var = cov_var[1]|cov_var[4]|cov_var[2];         @ in order s1, s2, s12 @

    elseif mtype_me eq 12;

        chol_cov[1,1] = params[rows(params)-3];
        chol_cov[2,2] = params[rows(params)-2];
        chol_cov[1,2] = params[rows(params)-1];    

        cov_var = chol_cov'chol_cov;
        cov_var = vec(cov_var);
        cov_var = cov_var[1]|cov_var[4]|cov_var[2];         @ in order s1, s2, s12 @

    endif;

retp(cov_var);
endp;


/*  Proc to create Halton sequences using the pattern described in Train, "Halton Sequences
for Mixed Logit." The integer n is the length of the Halton sequence that is required, and 
s is the prime that is used in creating the sequence. 

Given the length of the sequence n, the integer k is determined such that s^k<n<s^k+1. That is,
a sequence using s1 up to s^k is too short, and a sequence using s1 up to s^(k+1) is too long. 
Using this fact, the proc is divided in two parts to save time and space. 
The first part creates the sequence for s1 up to s^k. The second
part creates only as much as needed of the additional sequence using s^(k+1). */

proc halton(n,s);
local phi,i,j,y,x,k;
k=floor(ln(n+1) ./ ln(s));    @We create n+1 Halton numbers including the initial zero.@
phi={0};
i=1;
do while i .le k;  
  x=phi;
   j=1;
  do while j .lt s;
     y=phi+(j/s^i);
     x=x|y;
     j=j+1;
  endo;
  phi=x;
  i=i+1;
endo;
 
x=phi;
 j=1;
do while j .lt s .and rows(x) .lt (n+1);  
   y=phi+(j/s^i);
   x=x|y;
   j=j+1;
 endo;

phi=x[2:(n+1),1];  @Starting at the second element gets rid of the initial zero.@
retp(phi);
endp;


/* PROCEDURE FOR PARAMETRISING THE BOUNDRAY POINTS */

proc 1 = _mu_ij(params,w,capJ);                
local mu_ij, theta_j, theta_m, delta, wdelta, t_rep, a0, delta0;

    if no_con eq 0;

        if gop_flex eq 0;

            theta_j = params[1:capJ-2];
            theta_m = theta_j[1] .* w[.,1];
            for t_rep (2,capJ-2,1);
                theta_m = theta_m~(theta_j[t_rep] .* w[.,1]);
            endfor;
            delta   = params[capJ-2+1:rows(params)];

            wdelta  = w[.,2:cols(w)]*delta;
            wdelta  = wdelta .*. ones(1,capJ-2);

            theta_j = theta_j' .*. ones(rows(w),1);    
            mu_ij   = exp(theta_j + wdelta);

        elseif gop_flex eq 1;
            
            delta   = reshape(params',capJ-2,cols(w));

            wdelta  = w*delta';

            mu_ij   = exp(wdelta[.,1]);

            for t_rep (2,capJ-2,1);
                mu_ij      = mu_ij~(mu_ij[.,t_rep-1] + exp(wdelta[.,t_rep]));
            endfor;

        endif;

    elseif no_con eq 1;

/*
mu(0) = a0 + exp(c00 + c01'z)
mu(1) = mu(0) + exp(c10 + c11'z)
etc. This preserves the ordering of the thresholds and
allows the sign of mu(0) to change. Two normalizations
needed for identification:
(1) No constant term in beta.
(2) c00 = 0
I fit this model to some real data (health care) and it
works fine. Not without (2), it doesn't work - it clearly
is not identified with nonzero c00.
This allows z to influence all three probabilities.
To get starting values, by the way, run the usual ordered
probit on y. Beta0 is the nonconstant coefficients.
a0 is the negative of the constant term. You can start
the other c's at zero. Starting c10 at log(mu(1)) from
your earlier model might help.
*/

        if gop_flex eq 0;

            a0      = params[1];
            theta_j = params[2:capJ-1];             @ these are the constants for j>0 @
            delta   = params[capJ:rows(params)];    @ these are the Z coeffs j>0: same for each equation @
            wdelta  = w[.,2:cols(w)]*delta;

            mu_ij   = a0 + exp(w[.,2:cols(w)]*delta);

            for t_rep (2,capJ-1,1);
                mu_ij      = mu_ij~(mu_ij[.,t_rep-1] + (exp(theta_j[t_rep-1] + wdelta)));
            endfor;

        else;

            a0      = params[1];
            delta0  = params[2:cols(w)];
            mu_ij   = a0 + exp(w[.,2:cols(w)]*delta0);            
            
            delta   = reshape(params[cols(w)+1:rows(params)]',capJ-2,cols(w));
            wdelta  = w*delta';

            for t_rep (2,capJ-1,1);
                mu_ij      = mu_ij~(mu_ij[.,t_rep-1] + exp(wdelta[.,t_rep-1]));
            endfor;

        endif;


    endif;


retp(mu_ij);
endp;
